%%% EWTEC.cls 23-Jan-2019 version 1.0
%%% 
%%% This is the EWTEC LaTeX class file for authors of the European Wave and Tidal Energy Conference proceedings.
%%%
%%% It is based upon the IEEEtran LaTeX class for authors of the Institute of Electrical and Electronics Engineers (IEEE) Transactions journals and conferences, IEEEtran.cls 2015/08/26 version v1.0b
%%% 
%%% This work is distributed under the LaTeX Project Public License (LPPL)( http://www.latex-project.org/ ) version 1.3, and may be freely used, distributed and modified. A copy of the LPPL, version 1.3, is included in the base LaTeX documentation of all distributions of LaTeX released 2003/12/01 or later.
%%% Retain all contribution notices and credits.
%%% ** Modified files should be clearly indicated as such, including renaming them and changing author support contact information. **
%%%
%%% Contributors to the IEEEtran.cls:
%%%
%%% Gerry Murray (1993), Silvano Balemi (1993),
%%% Jon Dixon (1996), Peter N"uchter (1996),
%%% Juergen von Hagen (2000), and Michael Shell (2001-2014)
%%% Copyright (c) 1993-2000 by Gerry Murray, Silvano Balemi, Jon Dixon, Peter N"uchter, Juergen von Hagen
%%% Copyright (c) 2001-2015 by Michael Shell
%%% Special thanks to Peter Wilson (CUA) and Donald Arseneau for allowing the inclusion of the \@ifmtarg command from their ifmtarg LaTeX package.
%%%
%%% Converted to EWTEC.cls by EWTEC Secretariat (2019)
%%% Current maintainer (v1.0) EWTEC Secretariat (info@ewtec.org)
%%%
%%% 
%%%*************************************************************************
%%% Legal Notice:
%%% This code is offered as-is without any warranty either expressed or implied; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE! User assumes all risk. In no event shall any contributor to this code be liable for any damages or losses, including, but not limited to, incidental, consequential, or any other damages, resulting from the use or misuse of any information contained here.
%%%
%%% All comments are the opinions of their respective authors and are not necessarily endorsed by any organization.
%%%
%%%*************************************************************************
%%
%
% Available class options 
% e.g., \documentclass[10pt,conference]{EWTEC} 
% 
%             *** choose only one from each category ***
%
% 9pt, 10pt, 11pt, 12pt
%    Sets normal font size. The default is 10pt.
% 
% conference, journal, technote, peerreview, peerreviewca
%    determines format mode - conference papers, journal papers,
%    correspondence papers (technotes), or peer review papers. The user
%    should also select 9pt when using technote. peerreview is like
%    journal mode, but provides for a single-column "cover" title page for
%    anonymous peer review. The paper title (without the author names) is
%    repeated at the top of the page after the cover page. For peer review
%    papers, the \EWTECpeerreviewmaketitle command must be executed (will
%    automatically be ignored for non-peerreview modes) at the place the
%    cover page is to end, usually just after the abstract (keywords are
%    not normally used with peer review papers). peerreviewca is like
%    peerreview, but allows the author names to be entered and formatted
%    as with conference mode so that author affiliation and contact
%    information can be easily seen on the cover page.
%    The default is journal.
%
% draft, draftcls, draftclsnofoot, final
%    determines if paper is formatted as a widely spaced draft (for
%    handwritten editor comments) or as a properly typeset final version.
%    draftcls restricts draft mode to the class file while all other LaTeX
%    packages (i.e., \usepackage{graphicx}) will behave as final - allows
%    for a draft paper with visible figures, etc. draftclsnofoot is like
%    draftcls, but does not display the date and the word "DRAFT" at the foot
%    of the pages. If using one of the draft modes, the user will probably
%    also want to select onecolumn.
%    The default is final.
%
% a4paper
%    Only A4 paper size is used for EWTEC
%
% oneside, twoside
%    determines if layout follows single sided or two sided (duplex)
%    printing. The only notable change is with the headings at the top of
%    the pages.
%    The default is twoside.
%
% onecolumn, twocolumn
%    determines if text is organized into one or two columns per page. One
%    column mode is usually used only with draft papers.
%    The default is twocolumn.
%
% romanappendices
%    Use the "Appendix I" convention when numbering appendices. 
%
% captionsoff
%    disables the display of the figure/table captions. Some journals
%    request that captions be removed and figures/tables be put on pages
%    of their own at the end of an initial paper submission. The endfloat
%    package can be used with this class option to achieve this format.
%
% nofonttune
%    turns off tuning of the font interword spacing. Maybe useful to those
%    not using the standard Times fonts or for those who have already "tuned"
%    their fonts.
%    The default is to enable EWTECtran to tune font parameters.
%
%
%----------
% Available CLASSINPUTs provided (all are macros unless otherwise noted):
% \CLASSINPUTbaselinestretch
% \CLASSINPUTinnersidemargin
% \CLASSINPUToutersidemargin
% \CLASSINPUTtoptextmargin
% \CLASSINPUTbottomtextmargin
%
% Available CLASSINFOs provided:
% \ifCLASSINFOpdf                       (TeX if conditional)
% \CLASSINFOpaperwidth                  (macro)
% \CLASSINFOpaperheight                 (macro)
% \CLASSINFOnormalsizebaselineskip      (length)
% \CLASSINFOnormalsizeunitybaselineskip (length)
%
% Available CLASSOPTIONs provided:
% all class option flags (TeX if conditionals) unless otherwise noted,
% e.g., \ifCLASSOPTIONcaptionsoff
% point size options provided as a single macro:
% \CLASSOPTIONpt
% which will be defined as 9, 10, 11, or 12 depending on the document's
% normalsize point size.
% also, class option peerreviewca implies the use of class option peerreview
% and classoption draft implies the use of class option draftcls





\ProvidesClass{EWTEC}[v1.0 March 2018]
\typeout{-- https://ewtec.org/conferences/ewtec-2019/guidelines-for-contribution/}
\typeout{-- Based on IEEEtran v1.0b by Michael Shell.}
\typeout{-- Not endorsed by any person or organization other than EWTEC.}
\NeedsTeXFormat{LaTeX2e}

% EWTEC.cls version numbers
% These values serve as a way a .tex file can
% determine if the new features are provided.
% The version number of this EWTEC.cls can be obtained from 
% these values. i.e., V1.4
% KEEP THESE AS INTEGERS! i.e., NO {4a} or anything like that-
% (no need to enumerate "a" minor changes here)
\def\EWTECtransversionmajor{1}
\def\EWTECtransversionminor{0}


% hook to allow easy changeover to EWTEC.cls/tools.sty error reporting
\def\@EWTECclspkgerror{\ClassError{EWTEC}}


% These do nothing, but provide them like in article.cls
\newif\if@restonecol
\newif\if@titlepage


% class option conditionals
\newif\ifCLASSOPTIONonecolumn       \CLASSOPTIONonecolumnfalse
\newif\ifCLASSOPTIONtwocolumn       \CLASSOPTIONtwocolumntrue

\newif\ifCLASSOPTIONoneside         \CLASSOPTIONonesidefalse
\newif\ifCLASSOPTIONtwoside         \CLASSOPTIONtwosidetrue

\newif\ifCLASSOPTIONfinal           \CLASSOPTIONfinaltrue
\newif\ifCLASSOPTIONdraft           \CLASSOPTIONdraftfalse
\newif\ifCLASSOPTIONdraftcls        \CLASSOPTIONdraftclsfalse
\newif\ifCLASSOPTIONdraftclsnofoot  \CLASSOPTIONdraftclsnofootfalse

\newif\ifCLASSOPTIONpeerreview      \CLASSOPTIONpeerreviewfalse
\newif\ifCLASSOPTIONpeerreviewca    \CLASSOPTIONpeerreviewcafalse

\newif\ifCLASSOPTIONjournal         \CLASSOPTIONjournaltrue

\newif\ifCLASSOPTIONnofonttune      \CLASSOPTIONnofonttunefalse

\newif\ifCLASSOPTIONcaptionsoff     \CLASSOPTIONcaptionsofffalse


\newif\ifCLASSOPTIONromanappendices \CLASSOPTIONromanappendicesfalse


% class info conditionals

% indicates if pdf (via pdflatex) output
\newif\ifCLASSINFOpdf               \CLASSINFOpdffalse


% v1.0b internal flag to show if using a4paper
\newif\if@EWTECusingAfourpaper       \@EWTECusingAfourpapertrue
% v1.0b internal flag to show if using cspaper
\newif\if@EWTECusingcspaper          \@EWTECusingcspaperfalse


% EWTEC class scratch pad registers
% dimen
\newdimen\@EWTECtmpdimenA
\newdimen\@EWTECtmpdimenB
\newdimen\@EWTECtmpdimenC
% count
\newcount\@EWTECtmpcountA
\newcount\@EWTECtmpcountB
\newcount\@EWTECtmpcountC
% token list
\newtoks\@EWTECtmptoksA

% we use \CLASSOPTIONpt so that we can ID the point size (even for 9pt docs)
% as well as LaTeX's \@ptsize to retain some compatability with some
% external packages
\def\@ptsize{0}
% LaTeX does not support 9pt, so we set \@ptsize to 0 - same as that of 10pt
\DeclareOption{9pt}{\def\CLASSOPTIONpt{9}\def\@ptsize{0}}
\DeclareOption{10pt}{\def\CLASSOPTIONpt{10}\def\@ptsize{0}}
\DeclareOption{11pt}{\def\CLASSOPTIONpt{11}\def\@ptsize{1}}
\DeclareOption{12pt}{\def\CLASSOPTIONpt{12}\def\@ptsize{2}}


\DeclareOption{a4paper}{\setlength{\paperwidth}{210mm}%
                        \setlength{\paperheight}{297mm}%
                        \@EWTECusingAfourpapertrue
                        \@EWTECusingcspaperfalse
                        \def\CLASSOPTIONpaper{a4}%
                        \def\CLASSINFOpaperwidth{210mm}%
                        \def\CLASSINFOpaperheight{297mm}}


\DeclareOption{oneside}{\@twosidefalse\@mparswitchfalse
                        \CLASSOPTIONonesidetrue\CLASSOPTIONtwosidefalse}
\DeclareOption{twoside}{\@twosidetrue\@mparswitchtrue
                        \CLASSOPTIONtwosidetrue\CLASSOPTIONonesidefalse}

\DeclareOption{onecolumn}{\CLASSOPTIONonecolumntrue\CLASSOPTIONtwocolumnfalse}
\DeclareOption{twocolumn}{\CLASSOPTIONtwocolumntrue\CLASSOPTIONonecolumnfalse}

% If the user selects draft, then this class AND any packages
% will go into draft mode.
\DeclareOption{draft}{\CLASSOPTIONdrafttrue\CLASSOPTIONdraftclstrue
                      \CLASSOPTIONdraftclsnofootfalse} 
% draftcls is for a draft mode which will not affect any packages
% used by the document.
\DeclareOption{draftcls}{\CLASSOPTIONdraftfalse\CLASSOPTIONdraftclstrue
                         \CLASSOPTIONdraftclsnofootfalse} 
% draftclsnofoot is like draftcls, but without the footer.
\DeclareOption{draftclsnofoot}{\CLASSOPTIONdraftfalse\CLASSOPTIONdraftclstrue
                               \CLASSOPTIONdraftclsnofoottrue} 
\DeclareOption{final}{\CLASSOPTIONdraftfalse\CLASSOPTIONdraftclsfalse
                      \CLASSOPTIONdraftclsnofootfalse}

\DeclareOption{journal}{\CLASSOPTIONpeerreviewfalse\CLASSOPTIONpeerreviewcafalse
                        \CLASSOPTIONjournaltrue}

\DeclareOption{peerreview}{\CLASSOPTIONpeerreviewtrue\CLASSOPTIONpeerreviewcafalse
                           \CLASSOPTIONjournalfalse}

\DeclareOption{peerreviewca}{\CLASSOPTIONpeerreviewtrue\CLASSOPTIONpeerreviewcatrue
                             \CLASSOPTIONjournalfalse}

\DeclareOption{nofonttune}{\CLASSOPTIONnofonttunetrue}

\DeclareOption{captionsoff}{\CLASSOPTIONcaptionsofftrue}

\DeclareOption{romanappendices}{\CLASSOPTIONromanappendicestrue}


% default to A4 paper, 10pt, twocolumn, one sided, final, journal
\ExecuteOptions{a4paper,10pt,twocolumn,oneside,final,journal}
% overrride these defaults per user requests
\ProcessOptions



%% -- Command Argument Scanning Support Functions --

% Sets the category codes for punctuation to their normal values.
% For local use with argument scanning.
\def\EWTECnormalcatcodespunct{\catcode`\!=12 \catcode`\,=12 \catcode`\:=12
\catcode`\;=12 \catcode`\`=12 \catcode`\'=12 \catcode`\"=12 \catcode`\.=12
\catcode`\/=12 \catcode`\?=12 \catcode`\*=12 \catcode`\+=12 \catcode`\-=12
\catcode`\<=12 \catcode`\>=12 \catcode`\(=12 \catcode`\)=12 \catcode`\[=12
\catcode`\]=12 \catcode`\==12 \catcode`\|=12}
% Sets the category codes for numbers to their normal values.
% For local use with argument scanning.
\def\EWTECnormalcatcodesnum{\catcode`\0=12 \catcode`\1=12 \catcode`\2=12
\catcode`\3=12 \catcode`\4=12 \catcode`\5=12 \catcode`\6=12 \catcode`\7=12
\catcode`\8=12 \catcode`\9=12}
% combined action of \EWTECnormalcatcodespunct and \EWTECnormalcatcodesnum
\def\EWTECnormalcatcodes{\EWTECnormalcatcodespunct\EWTECnormalcatcodesnum}


% usage: \@EWTECextracttoken*{}
% \@EWTECextracttoken fully expands its argument (which it then stores in
% \@EWTECextracttokenarg) via \edef and then the meaning of the first
% nonbrace (but including the empty group) token found is assigned via \let
% to \@EWTECextractedtoken as well as stored in the macro
% \@EWTECextractedtokenmacro. Tokens that would otherwise be discarded during
% the acquisition of the first are stored in \@EWTECextractedtokensdiscarded,
% however their original relative brace nesting depths are not guaranteed to
% be preserved.
% If the argument is empty, or if a first nonbrace token does not exist (or
% is an empty group), \@EWTECextractedtoken will be \relax and
% \@EWTECextractedtokenmacro and \@EWTECextractedtokensdiscarded will be empty.
%
% For example:
% \@EWTECextracttoken{{{ab}{cd}}{{ef}g}}
% results in:
%
% \@EWTECextracttokenarg          ==> a macro containing {{ab}{cd}}{{ef}g}
% \@EWTECextractedtoken           ==> the letter a
% \@EWTECextractedtokenmacro      ==> a macro containing a
% \@EWTECextractedtokensdiscarded ==> a macro containing bcd{ef}g
%
% the *-star form, \@EWTECextracttoken*, does not expand its argument
% contents during processing.
\def\@EWTECextracttoken{\@ifstar{\let\@EWTECextracttokendef=\def\@@EWTECextracttoken}{\let\@EWTECextracttokendef=\edef\@@EWTECextracttoken}}

\def\@@EWTECextracttoken#1{\@EWTECextracttokendef\@EWTECextracttokenarg{#1}\relax
\def\@EWTECextractedtokensdiscarded{}\relax % initialize to empty
% if the macro is unchanged after being acquired as a single undelimited argument
% with anything after it being stripped off as a delimited argument
% we know we have one token without any enclosing braces. loop until this is true.
\let\@EWTECextracttokencurgroup\@EWTECextracttokenarg
\loop
  % trap case of an empty argument as this would cause a problem with
  % \@@@EWTECextracttoken's first (nondelimited) argument acquisition
  \ifx\@EWTECextracttokencurgroup\@empty
    \def\@EWTECextractedtokenmacro{}\relax
  \else
    \expandafter\@@@EWTECextracttoken\@EWTECextracttokencurgroup\@EWTECgeneralsequenceDELIMITER\relax
  \fi
  \ifx\@EWTECextractedtokenmacro\@EWTECextracttokencurgroup
  \else
    \let\@EWTECextracttokencurgroup=\@EWTECextractedtokenmacro
\repeat
% we can safely do a \let= here because there should be at most one token
% the relax is needed to handle the case of no token found
\expandafter\let\expandafter\@EWTECextractedtoken\@EWTECextractedtokenmacro\relax}

\def\@@@EWTECextracttoken#1#2\@EWTECgeneralsequenceDELIMITER{\def\@EWTECextractedtokenmacro{#1}\relax
\def\@@EWTECextractedtokensdiscarded{#2}\expandafter\expandafter\expandafter\def\expandafter\expandafter\expandafter
\@EWTECextractedtokensdiscarded\expandafter\expandafter\expandafter
{\expandafter\@@EWTECextractedtokensdiscarded\@EWTECextractedtokensdiscarded}}
%%
%% -- End of Command Argument Scanning Support Functions --







%%% LB 2018: The EWTEC proceedings use Palatino Linotype font, so default to Palatino.
\renewcommand{\sfdefault}{phv}
\renewcommand{\rmdefault}{ppl}
\renewcommand{\ttdefault}{pcr}
%%%


% enable the selected main text font
\normalfont\selectfont





% v1.0 improved paper size setting code.
% Set pdfpage and dvips paper sizes. Conditional tests are similar to that
% of ifpdf.sty. Retain within {} to ensure tested macros are never altered,
% even if only effect is to set them to \relax.
% if \pdfoutput is undefined or equal to relax, output a dvips special
{\@ifundefined{pdfoutput}{\AtBeginDvi{\special{papersize=\CLASSINFOpaperwidth,\CLASSINFOpaperheight}}}{%
% pdfoutput is defined and not equal to \relax
% check for pdfpageheight existence just in case someone sets pdfoutput
% under non-pdflatex. If exists, set them regardless of value of \pdfoutput.
\@ifundefined{pdfpageheight}{\relax}{\global\pdfpagewidth\paperwidth
\global\pdfpageheight\paperheight}%
% if using \pdfoutput=0 under pdflatex, send dvips papersize special
\ifcase\pdfoutput
\AtBeginDvi{\special{papersize=\CLASSINFOpaperwidth,\CLASSINFOpaperheight}}%
\else
% we are using pdf output, set CLASSINFOpdf flag
\global\CLASSINFOpdftrue
\fi}}

% let the user know the selected papersize
\typeout{-- Using \CLASSINFOpaperwidth\space x \CLASSINFOpaperheight\space
(\CLASSOPTIONpaper)\space paper.}

\ifCLASSINFOpdf
\typeout{-- Using PDF output.}
\else
\typeout{-- Using DVI output.}
\fi


% The idea hinted here is for LaTeX to generate markleft{} and markright{}
% automatically for you after you enter \author{}, \journal{},
% \journaldate{}, journalvol{}, \journalnum{}, etc.
% However, there may be some backward compatibility issues here as
% well as some special applications for EWTEC.cls and special issues
% that may require the flexible \markleft{}, \markright{} and/or \markboth{}.
% We'll leave this as an open future suggestion.
%\newcommand{\journal}[1]{\def\@journal{#1}}
%\def\@journal{}



% pointsize values
% used with ifx to determine the document's normal size
\def\@EWTECptsizenine{9}
\def\@EWTECptsizeten{10}
\def\@EWTECptsizeeleven{11}
\def\@EWTECptsizetwelve{12}



% FONT DEFINITIONS (No sizexx.clo file needed) 
% v1.0 revised font sizes, displayskip values and
%      revised normalsize baselineskip to reduce underfull vbox problems
%      on the 58pc = 696pt = 9.5in text height we want
%      normalsize     #lines/column  baselineskip (aka leading)
%             9pt     63             11.0476pt (truncated down)
%            10pt     58             12pt      (exact)
%            11pt     52             13.3846pt (truncated down)
%            12pt     50             13.92pt   (exact)
%

% we need to store the nominal baselineskip for the given font size
% in case baselinestretch ever changes.
% this is a dimen, so it will not hold stretch or shrink
\newdimen\@EWTECnormalsizeunitybaselineskip
\@EWTECnormalsizeunitybaselineskip\baselineskip



%% ******* WARNING! *******
%%
%% Authors should not alter font sizes, baselineskip ("leading"),
%% margins or other spacing values in an attempt to squeeze more
%% material on each page.
%%
%% The original EWTEC style file will restore the correct
%% values when re-typesetting/proofing the submitted document,
%% possibly resulting in unexpected layout changes, or articles over length.
%%
%% ******* WARNING! *******


% 9pt option defaults
\ifx\CLASSOPTIONpt\@EWTECptsizenine
%%% LB 2018:
\typeout{-- This is a 9.5 point document.}
\def\normalsize{\@setfontsize{\normalsize}{9.5}{11.0476pt}}
%%% 
\setlength{\@EWTECnormalsizeunitybaselineskip}{11.0476pt}
\normalsize
\abovedisplayskip 1.5ex plus 3pt minus 1pt
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip 0pt plus 3pt
\belowdisplayshortskip 1.5ex plus 3pt minus 1pt
\def\small{\@setfontsize{\small}{8.5}{10pt}}
\def\footnotesize{\@setfontsize{\footnotesize}{8}{9pt}}
\def\scriptsize{\@setfontsize{\scriptsize}{7}{8pt}}
\def\tiny{\@setfontsize{\tiny}{5}{6pt}}
% sublargesize is the same as large - 10pt
\def\sublargesize{\@setfontsize{\sublargesize}{10}{12pt}}
\def\large{\@setfontsize{\large}{10}{12pt}}
\def\Large{\@setfontsize{\Large}{12}{14pt}}
\def\LARGE{\@setfontsize{\LARGE}{14}{17pt}}
\def\huge{\@setfontsize{\huge}{17}{20pt}}
\def\Huge{\@setfontsize{\Huge}{20}{24pt}}
\fi
%
% 10pt option defaults
\ifx\CLASSOPTIONpt\@EWTECptsizeten
\typeout{-- This is a 10 point document.}
\def\normalsize{\@setfontsize{\normalsize}{10}{12.00pt}}
\setlength{\@EWTECnormalsizeunitybaselineskip}{12pt}
\normalsize
\abovedisplayskip 1.5ex plus 4pt minus 2pt
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip 0pt plus 4pt
\belowdisplayshortskip 1.5ex plus 4pt minus 2pt
\def\small{\@setfontsize{\small}{9}{10pt}}
\def\footnotesize{\@setfontsize{\footnotesize}{8}{9pt}}
\def\scriptsize{\@setfontsize{\scriptsize}{7}{8pt}}
\def\tiny{\@setfontsize{\tiny}{5}{6pt}}
% sublargesize is a tad smaller than large - 11pt
\def\sublargesize{\@setfontsize{\sublargesize}{11}{13.4pt}}
\def\large{\@setfontsize{\large}{12}{14pt}}
\def\Large{\@setfontsize{\Large}{14}{17pt}}
\def\LARGE{\@setfontsize{\LARGE}{17}{20pt}}
\def\huge{\@setfontsize{\huge}{20}{24pt}}
\def\Huge{\@setfontsize{\Huge}{24}{28pt}}
\fi
%
% 11pt option defaults
\ifx\CLASSOPTIONpt\@EWTECptsizeeleven
\typeout{-- This is an 11 point document.}
\def\normalsize{\@setfontsize{\normalsize}{11}{13.3846pt}}
\setlength{\@EWTECnormalsizeunitybaselineskip}{13.3846pt}
\normalsize
\abovedisplayskip 1.5ex plus 5pt minus 3pt
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip 0pt plus 5pt
\belowdisplayshortskip 1.5ex plus 5pt minus 3pt
\def\small{\@setfontsize{\small}{10}{12pt}}
\def\footnotesize{\@setfontsize{\footnotesize}{9}{10.5pt}}
\def\scriptsize{\@setfontsize{\scriptsize}{8}{9pt}}
\def\tiny{\@setfontsize{\tiny}{6}{7pt}}
% sublargesize is the same as large - 12pt
\def\sublargesize{\@setfontsize{\sublargesize}{12}{14pt}}
\def\large{\@setfontsize{\large}{12}{14pt}}
\def\Large{\@setfontsize{\Large}{14}{17pt}}
\def\LARGE{\@setfontsize{\LARGE}{17}{20pt}}
\def\huge{\@setfontsize{\huge}{20}{24pt}}
\def\Huge{\@setfontsize{\Huge}{24}{28pt}}
\fi
%
% 12pt option defaults
\ifx\CLASSOPTIONpt\@EWTECptsizetwelve
\typeout{-- This is a 12 point document.}
\def\normalsize{\@setfontsize{\normalsize}{12}{13.92pt}}
\setlength{\@EWTECnormalsizeunitybaselineskip}{13.92pt}
\normalsize
\abovedisplayskip 1.5ex plus 6pt minus 4pt
\belowdisplayskip \abovedisplayskip
\abovedisplayshortskip 0pt plus 6pt
\belowdisplayshortskip 1.5ex plus 6pt minus 4pt
\def\small{\@setfontsize{\small}{10}{12pt}}
\def\footnotesize{\@setfontsize{\footnotesize}{9}{10.5pt}}
\def\scriptsize{\@setfontsize{\scriptsize}{8}{9pt}}
\def\tiny{\@setfontsize{\tiny}{6}{7pt}}
% sublargesize is the same as large - 14pt
\def\sublargesize{\@setfontsize{\sublargesize}{14}{17pt}}
\def\large{\@setfontsize{\large}{14}{17pt}}
\def\Large{\@setfontsize{\Large}{17}{20pt}}
\def\LARGE{\@setfontsize{\LARGE}{20}{24pt}}
\def\huge{\@setfontsize{\huge}{22}{26pt}}
\def\Huge{\@setfontsize{\Huge}{24}{28pt}}
\fi




% v1.0
% Improved \textunderscore to provide a much better fake _ when used with
% OT1 encoding. Under OT1, detect use of pcr or cmtt \ttfamily and use
% available true _ glyph for those two typewriter fonts.
\def\@EWTECstringptm{ptm} % Times Roman family
\def\@EWTECstringppl{ppl} % Palatino Roman family
\def\@EWTECstringphv{phv} % Helvetica Sans Serif family
\def\@EWTECstringpcr{pcr} % Courier typewriter family
\def\@EWTECstringcmtt{cmtt} % Computer Modern typewriter family
\DeclareTextCommandDefault{\textunderscore}{\leavevmode
\ifx\f@family\@EWTECstringpcr\string_\else
\ifx\f@family\@EWTECstringcmtt\string_\else
\ifx\f@family\@EWTECstringptm\kern 0em\vbox{\hrule\@width 0.5em\@height 0.5pt\kern -0.3ex}\else
\ifx\f@family\@EWTECstringppl\kern 0em\vbox{\hrule\@width 0.5em\@height 0.5pt\kern -0.3ex}\else
\ifx\f@family\@EWTECstringphv\kern -0.03em\vbox{\hrule\@width 0.62em\@height 0.52pt\kern -0.33ex}\kern -0.03em\else
\kern 0.09em\vbox{\hrule\@width 0.6em\@height 0.44pt\kern -0.63pt\kern -0.42ex}\kern 0.09em\fi\fi\fi\fi\fi\relax}




% set the default \baselinestretch
\def\baselinestretch{1}
\ifCLASSOPTIONdraftcls
  \def\baselinestretch{1.5}% default baselinestretch for draft modes
\fi 


% process CLASSINPUT baselinestretch
\ifx\CLASSINPUTbaselinestretch\@EWTECundefined
\else
  \edef\baselinestretch{\CLASSINPUTbaselinestretch} % user CLASSINPUT override
  \typeout{** ATTENTION: Overriding \string\baselinestretch\space to
           \baselinestretch\space via \string\CLASSINPUT.}
\fi

\small\normalsize % make \baselinestretch take affect




% store the normalsize baselineskip
\newdimen\CLASSINFOnormalsizebaselineskip
\CLASSINFOnormalsizebaselineskip=\baselineskip\relax
% and the normalsize unity (baselinestretch=1) baselineskip
% we could save a register by giving the user access to
% \@EWTECnormalsizeunitybaselineskip. However, let's protect
% its read only internal status
\newdimen\CLASSINFOnormalsizeunitybaselineskip
\CLASSINFOnormalsizeunitybaselineskip=\@EWTECnormalsizeunitybaselineskip\relax
% store the nominal value of jot
\newdimen\EWTECnormaljot
\EWTECnormaljot=0.25\baselineskip\relax

% set \jot
\jot=\EWTECnormaljot\relax






% here are the interword spacing ratios we'll use
% for medium (normal weight)
\def\@EWTECinterspaceratioM{0.35}
\def\@EWTECinterspaceMINratioM{0.23}
\def\@EWTECinterspaceMAXratioM{0.50}

% for bold
\def\@EWTECinterspaceratioB{0.375}
\def\@EWTECinterspaceMINratioB{0.23}
\def\@EWTECinterspaceMAXratioB{0.55}





% command to revise the interword spacing for the current font under TeX:
% \fontdimen2 = nominal interword space
% \fontdimen3 = interword stretch
% \fontdimen4 = interword shrink
% since all changes to the \fontdimen are global, we can enclose these commands
% in braces to confine any font attribute or length changes
\def\@@@EWTECsetfontdimens#1#2#3{{%
\setlength{\@EWTECtmpdimenB}{\f@size pt}% grab the font size in pt, could use 1em instead.
\setlength{\@EWTECtmpdimenA}{#1\@EWTECtmpdimenB}%
\fontdimen2\font=\@EWTECtmpdimenA\relax
\addtolength{\@EWTECtmpdimenA}{-#2\@EWTECtmpdimenB}%
\fontdimen3\font=-\@EWTECtmpdimenA\relax
\setlength{\@EWTECtmpdimenA}{#1\@EWTECtmpdimenB}%
\addtolength{\@EWTECtmpdimenA}{-#3\@EWTECtmpdimenB}%
\fontdimen4\font=\@EWTECtmpdimenA\relax}}

% revise the interword spacing for each font weight
\def\@@EWTECsetfontdimens{{%
\mdseries
\@@@EWTECsetfontdimens{\@EWTECinterspaceratioM}{\@EWTECinterspaceMAXratioM}{\@EWTECinterspaceMINratioM}%
\bfseries
\@@@EWTECsetfontdimens{\@EWTECinterspaceratioB}{\@EWTECinterspaceMAXratioB}{\@EWTECinterspaceMINratioB}%
}}

% revise the interword spacing for each font shape
% \slshape is not often used for EWTEC work and is not altered here. The \scshape caps are
% already a tad too large in the free LaTeX fonts (as compared to what the EWTEC uses) so we
% won't alter these either.
\def\@EWTECsetfontdimens{{%
\normalfont
\@@EWTECsetfontdimens
\normalfont\itshape
\@@EWTECsetfontdimens
}}

% command to revise the interword spacing for each font size (and shape
% and weight). Only the \rmfamily is done here as \ttfamily uses a 
% fixed spacing and \sffamily is not used as the main text of EWTEC papers.
\def\@EWTECtunefonts{{\selectfont\rmfamily
\tiny\@EWTECsetfontdimens
\scriptsize\@EWTECsetfontdimens
\footnotesize\@EWTECsetfontdimens
\small\@EWTECsetfontdimens
\normalsize\@EWTECsetfontdimens
\sublargesize\@EWTECsetfontdimens
\large\@EWTECsetfontdimens
\LARGE\@EWTECsetfontdimens
\huge\@EWTECsetfontdimens
\Huge\@EWTECsetfontdimens}}

% if the nofonttune class option is not given, revise the interword spacing
% now - in case EWTEC makes any default length measurements, and make
% sure all the default fonts are loaded
\ifCLASSOPTIONnofonttune\else
\@EWTECtunefonts
\fi

% and again at the start of the document in case the user loaded different fonts
\AtBeginDocument{\ifCLASSOPTIONnofonttune\else\@EWTECtunefonts\fi}





% -- v1.0a page setup commands --

% The default sample text for calculating margins
% Note that EWTEC proceedings use \scriptsize for headers and footers.
\def\EWTECdefaultsampletext{\normalfont\normalsize gT}
\def\EWTECdefaultheadersampletext{\normalfont\scriptsize T}% EWTEC headers default to uppercase
\def\EWTECdefaultfootersampletext{\normalfont\scriptsize gT}



% usage: \EWTECsettextwidth{inner margin}{outer margin}
% Sets \textwidth to allow the specified inner and outer margins
% for the current \paperwidth.
\def\EWTECsettextwidth#1#2{\@EWTECtmpdimenA\paperwidth
\@EWTECtmpdimenB#1\relax
\advance\@EWTECtmpdimenA by -\@EWTECtmpdimenB
\@EWTECtmpdimenB#2\relax
\advance\@EWTECtmpdimenA by -\@EWTECtmpdimenB
\textwidth\@EWTECtmpdimenA}



% usage: \EWTECsetsidemargin{mode: i, o, c, a}{margin/offset}
% Sets \oddsidemargin and \evensidemargin to yield the specified margin
% of the given mode.
% The available modes are:
% i = inner margin
% o = outer margin
% c = centered, with the given offset
% a = adjust the margins using the given offset
% For the offsets, positive values increase the inner margin.
% \textwidth should be set properly for the given margins before calling this
% function.
\def\EWTECsetsidemargin#1#2{\@EWTECtmpdimenA #2\relax
\@EWTECextracttoken{#1}\relax
% check for mode errors
\ifx\@EWTECextractedtokenmacro\@empty
  \@EWTECclspkgerror{Empty mode type in \string\EWTECsetsidemargin\space (line \the\inputlineno).\MessageBreak
  Defaulting to `i'}{Valid modes for \string\EWTECsetsidemargin\space are: i, o, c and a.}\relax
  \let\@EWTECextractedtoken=i\relax
  \def\@EWTECextractedtokenmacro{i}\relax
\else
  \ifx\@EWTECextractedtokensdiscarded\@empty\else
    \typeout{** WARNING: \string\EWTECsetsidemargin\space mode specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
  \fi
\fi
% handle each mode
\if\@EWTECextractedtoken a\relax
  \advance\oddsidemargin by \@EWTECtmpdimenA\relax
\else
\if\@EWTECextractedtoken c\relax
  \oddsidemargin\paperwidth
  \advance\oddsidemargin by -\textwidth
  \divide\oddsidemargin by 2\relax
  \advance\oddsidemargin by -1in\relax
  \advance\oddsidemargin by \@EWTECtmpdimenA\relax
\else
\if\@EWTECextractedtoken o\relax
  \oddsidemargin\paperwidth
  \advance\oddsidemargin by -\textwidth
  \advance\oddsidemargin by -\@EWTECtmpdimenA
  \advance\oddsidemargin by -1in\relax
\else
  \if\@EWTECextractedtoken i\relax
  \else
    \@EWTECclspkgerror{Unknown mode type `\@EWTECextractedtokenmacro' in \string\EWTECsetsidemargin\space (line \the\inputlineno).\MessageBreak
    Defaulting to `i'}%
    {Valid modes for \string\EWTECsetsidemargin\space are: i, o, c  and a.}%
  \fi
  \oddsidemargin\@EWTECtmpdimenA
  \advance\oddsidemargin by -1in\relax
\fi\fi\fi
% odd and even side margins both mean "inner" for single sided pages
\evensidemargin\oddsidemargin
% but are mirrors of each other when twosided is in effect
\if@twoside
  \evensidemargin\paperwidth
  \advance\evensidemargin by -\textwidth
  \advance\evensidemargin by -\oddsidemargin
  % have to compensate for both the builtin 1in LaTex offset
  % and the fact we already subtracted this offset from \oddsidemargin
  \advance\evensidemargin -2in\relax
\fi}



% usage: \EWTECsettextheight[sample text]{top text margin}{bottom text margin}
% Sets \textheight based on the specified top margin and bottom margin.
% Takes into consideration \paperheight, \topskip, and (by default) the
% the actual height and depth of the \EWTECdefaultsampletext text. 
\def\EWTECsettextheight{\@ifnextchar [{\@EWTECsettextheight}{\@EWTECsettextheight[\EWTECdefaultsampletext]}}
\def\@EWTECsettextheight[#1]#2#3{\textheight\paperheight\relax
  \@EWTECtmpdimenA #2\relax
  \advance \textheight by -\@EWTECtmpdimenA% subtract top margin
  \@EWTECtmpdimenA #3\relax
  \advance \textheight by -\@EWTECtmpdimenA% subtract bottom margin
  \advance \textheight by \topskip% add \topskip
  % subtract off everything above the top, and below the bottom, baselines
  \settoheight{\@EWTECtmpdimenA}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance \textheight by -\@EWTECtmpdimenA
  \settodepth{\@EWTECtmpdimenA}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance \textheight by -\@EWTECtmpdimenA}



\newdimen\EWTECquantizedlength
\EWTECquantizedlength 0sp\relax
\newdimen\EWTECquantizedlengthdiff
\EWTECquantizedlengthdiff 0sp\relax
\def\EWTECquantizedlengthint{0}

% usage: \EWTECquantizelength{mode: d, c, i}{base unit}{length}
% Sets the length \EWTECquantizedlength to be an integer multiple of the given
% (nonzero) base unit such that \EWTECquantizedlength approximates the given
% length.
% \EWTECquantizedlengthdiff is a length equal to the difference between the
% \EWTECquantizedlength and the given length.
% \EWTECquantizedlengthint is a macro containing the integer number of base units
% in \EWTECquantizedlength.
% i.e., \EWTECquantizedlength =  \EWTECquantizedlengthint * base unit
% The mode determines how \EWTECquantizedlength is quantized:
% d = always decrease (always round down \EWTECquantizeint)
% c = use the closest match
% i = always increase (always round up \EWTECquantizeint)
% In anycase, if the given length is already quantized,
% \EWTECquantizedlengthdiff will be set to zero.
\def\EWTECquantizelength#1#2#3{\begingroup
% work in isolation so as not to externally disturb the \@EWTECtmp
% variables
% load the argument values indirectly via \EWTECquantizedlengthdiff
% in case the user refers to our \@EWTECtmpdimenX, \EWTECquantizedlength,
% etc. in the arguments. we also will work with these as counters,
% i.e., in sp units
% A has the base unit
\EWTECquantizedlengthdiff #2\relax\relax\relax\relax
\@EWTECtmpcountA\EWTECquantizedlengthdiff
% B has the input length
\EWTECquantizedlengthdiff #3\relax\relax\relax\relax
\@EWTECtmpcountB\EWTECquantizedlengthdiff
\@EWTECtmpdimenA\the\@EWTECtmpcountA sp\relax
\@EWTECtmpdimenB\the\@EWTECtmpcountB sp\relax
% \@EWTECtmpcountC will have the quantized int
% \EWTECquantizedlength will have the quantized length
% \@EWTECtmpdimenC will have the quantized diff
% initialize them to zero as this is what will be
% exported if an error occurs
\@EWTECtmpcountC 0\relax
\EWTECquantizedlength 0sp\relax
\@EWTECtmpdimenC 0sp\relax
% extract mode
\@EWTECextracttoken{#1}\relax
% check for mode errors
\ifx\@EWTECextractedtokenmacro\@empty
  \@EWTECclspkgerror{Empty mode type in \string\EWTECquantizelength\space (line \the\inputlineno).\MessageBreak
  Defaulting to `d'}{Valid modes for \string\EWTECquantizelength\space are: d, c and i.}\relax
  \let\@EWTECextractedtoken=d\relax
  \def\@EWTECextractedtokenmacro{d}\relax
\else
  \ifx\@EWTECextractedtokensdiscarded\@empty\else
    \typeout{** WARNING: \string\EWTECquantizelength\space mode specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
  \fi
\fi
% check for base unit is zero error
\ifnum\@EWTECtmpcountA=0\relax
\@EWTECclspkgerror{Base unit is zero in \string\EWTECquantizelength\space (line \the\inputlineno).\MessageBreak
  \string\EWTECquantizedlength\space and \string\EWTECquantizedlengthdiff\space are set to zero}{Division by zero is not allowed.}\relax
\else% base unit is nonzero
  % \@EWTECtmpcountC carries the number of integer units
  % in the quantized length (integer length \ base)
  \@EWTECtmpcountC\@EWTECtmpcountB\relax
  \divide\@EWTECtmpcountC by \@EWTECtmpcountA\relax
  % \EWTECquantizedlength has the (rounded down) quantized length
  % = base * int
  \EWTECquantizedlength\@EWTECtmpdimenA\relax
  \multiply\EWTECquantizedlength by \@EWTECtmpcountC\relax
  % \@EWTECtmpdimenC has the difference
  % = quantized length - length
  \@EWTECtmpdimenC\EWTECquantizedlength\relax
  \advance\@EWTECtmpdimenC by -\@EWTECtmpdimenB\relax
  % trap special case of length being already quantized
  % to avoid a roundup under i option
  \ifdim\@EWTECtmpdimenC=0sp\relax
  \else % length not is already quantized
    % set dimenA to carry the upper quantized (absolute value) difference:
    % quantizedlength + base - length
    \advance\@EWTECtmpdimenA by \EWTECquantizedlength\relax
    \advance\@EWTECtmpdimenA by -\@EWTECtmpdimenB\relax
    % set dimenB to carry the lower quantized (absolute value) difference:
    % length - quantizedlength
    \advance\@EWTECtmpdimenB by -\EWTECquantizedlength\relax
    % handle each mode
    \if\@EWTECextractedtoken c\relax
      % compare upper and lower amounts, select upper if lower > upper
      \ifdim\@EWTECtmpdimenB>\@EWTECtmpdimenA\relax
        % use upper
        \advance\EWTECquantizedlength by \the\@EWTECtmpcountA sp\relax
        \advance\@EWTECtmpcountC by 1\relax
        \@EWTECtmpdimenC\@EWTECtmpdimenA
      \else% <=. uselower
        % no need to do anything for lower, use output values already setup
      \fi
    \else% not mode c
    \if\@EWTECextractedtoken i\relax
      % always round up under i mode
      \advance\EWTECquantizedlength by \the\@EWTECtmpcountA sp\relax
      \advance\@EWTECtmpcountC by 1\relax
      \@EWTECtmpdimenC\@EWTECtmpdimenA
    \else
      \if\@EWTECextractedtoken d\relax
      \else
        \@EWTECclspkgerror{Unknown mode type `\@EWTECextractedtokenmacro' in \string\EWTECquantizelength\space (line \the\inputlineno).\MessageBreak
        Defaulting to `d'}%
        {Valid modes for \string\EWTECquantizelength\space are: d, c, and i.}\relax
      \fi % if d
      % no need to do anything for d, use output values already setup
    \fi\fi % if i, c
  \fi % if length is already quantized
\fi% if base unit is zero
% globally assign the results to macros we use here to escape the enclosing
% group without needing to call \global on any of the \@EWTECtmp variables.
% \@EWTECtmpcountC has the quantized int
% \EWTECquantizedlength has the quantized length
% \@EWTECtmpdimenC has the quantized diff
\xdef\@EWTECquantizedlengthintmacro{\the\@EWTECtmpcountC}\relax
\@EWTECtmpcountC\EWTECquantizedlength\relax
\xdef\@EWTECquantizedlengthmacro{\the\@EWTECtmpcountC}\relax
\@EWTECtmpcountC\@EWTECtmpdimenC\relax
\xdef\@EWTECquantizedlengthdiffmacro{\the\@EWTECtmpcountC}\relax
\endgroup
% locally assign the outputs here from the macros
\expandafter\EWTECquantizedlength\@EWTECquantizedlengthmacro sp\relax
\expandafter\EWTECquantizedlengthdiff\@EWTECquantizedlengthdiffmacro sp\relax
\edef\EWTECquantizedlengthint{\@EWTECquantizedlengthintmacro}\relax}



\newdimen\EWTECquantizedtextheightdiff
\EWTECquantizedtextheightdiff 0sp\relax

% usage: \EWTECquantizetextheight[base unit]{mode: d, c, i}
% Sets \textheight to be an integer multiple of the current \baselineskip
% (or the optionally specified base unit) plus the first (\topskip) line.
% \EWTECquantizedtextheightdiff is a length equal to the difference between
% the new quantized and original \textheight.
% \EWTECquantizedtextheightlpc is a macro containing the integer number of
% lines per column under the quantized \textheight. i.e.,
% \textheight = \EWTECquantizedtextheightlpc * \baselineskip + \topskip
% The mode determines how \textheight is quantized:
% d = always decrease (always round down the number of lines per column)
% c = use the closest match
% i = always increase (always round up the number of lines per column)
% In anycase, if \textheight is already quantized, it will remain unchanged,
% and \EWTECquantizedtextheightdiff will be set to zero.
% Depends on: \EWTECquantizelength
\def\EWTECquantizetextheight{\@ifnextchar [{\@EWTECquantizetextheight}{\@EWTECquantizetextheight[\baselineskip]}}
\def\@EWTECquantizetextheight[#1]#2{\begingroup
% use our \EWTECquantizedtextheightdiff as a scratch pad
% we need to subtract off \topskip before quantization
\EWTECquantizedtextheightdiff\textheight
\advance\EWTECquantizedtextheightdiff by -\topskip\relax
\EWTECquantizelength{#2}{#1}{\EWTECquantizedtextheightdiff}
% add back \topskip line
\advance\EWTECquantizedlength by \topskip
\@EWTECtmpcountC\EWTECquantizedlengthint\relax
\advance\@EWTECtmpcountC by 1\relax
% globally assign the results to macros we use here to escape the enclosing
% group without needing to call \global on any of the \@EWTECtmp variables.
\xdef\@EWTECquantizedtextheightlpcmacro{\the\@EWTECtmpcountC}\relax
\@EWTECtmpcountC\EWTECquantizedlength\relax
\xdef\@EWTECquantizedtextheightmacro{\the\@EWTECtmpcountC}\relax
\@EWTECtmpcountC\EWTECquantizedlengthdiff\relax
\xdef\@EWTECquantizedtextheightdiffmacro{\the\@EWTECtmpcountC}\relax
\endgroup
% locally assign the outputs here from the macros
\textheight\@EWTECquantizedtextheightmacro sp\relax
\EWTECquantizedtextheightdiff\@EWTECquantizedtextheightdiffmacro sp\relax
\edef\EWTECquantizedtextheightlpc{\@EWTECquantizedtextheightlpcmacro}}



% usage: \EWTECsettopmargin[sample text]{mode: t, b, c, a, q}{margin/offset}
% Sets \topmargin based on the specified vertical margin.
% Takes into consideration the base 1in offset, \headheight, \headsep,
% \topskip, and (by default) the the actual height (or, for the bottom, depth)
% of the \EWTECdefaultsampletext text.
% The available modes are:
% t = top margin
% b = bottom margin
% c = vertically centered, with the given offset
% a = adjust the vertical margins using the given offset
% q = adjust the margins using \EWTECquantizedtextheightdiff and the given offset
% For the offsets, positive values increase the top margin.
% \headheight, \headsep, \topskip and \textheight should be set properly for the
% given margins before calling this function.
\def\EWTECsettopmargin{\@ifnextchar [{\@EWTECsettopmargin}{\@EWTECsettopmargin[\EWTECdefaultsampletext]}}
\def\@EWTECsettopmargin[#1]#2#3{\@EWTECtmpdimenA #3\relax
\@EWTECextracttoken{#2}\relax
% check for mode errors
\ifx\@EWTECextractedtokenmacro\@empty
  \@EWTECclspkgerror{Empty mode type in \string\EWTECsettopmargin\space (line \the\inputlineno).\MessageBreak
  Defaulting to `t'}{Valid modes for \string\EWTECsettopmargin\space are: t, b, c, a and q.}\relax
  \let\@EWTECextractedtoken=t\relax
  \def\@EWTECextractedtokenmacro{t}\relax
\else
  \ifx\@EWTECextractedtokensdiscarded\@empty\else
    \typeout{** WARNING: \string\EWTECsettopmargin\space mode specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
  \fi
\fi
% handle each mode
\if\@EWTECextractedtoken a\relax
  \advance\topmargin by \@EWTECtmpdimenA\relax
\else
\if\@EWTECextractedtoken q\relax
  % we need to adjust by half the \EWTECquantizedtextheightdiff value
  \@EWTECtmpdimenB\EWTECquantizedtextheightdiff\relax
  \divide\@EWTECtmpdimenB by 2\relax
  % a positive \EWTECquantizedtextheightdiff means we need to reduce \topmargin
  % because \textheight has been lenghtened
  \advance\topmargin by -\@EWTECtmpdimenB\relax
  \advance\topmargin by \@EWTECtmpdimenA\relax
\else
\if\@EWTECextractedtoken c\relax
  \topmargin\paperheight
  \advance\topmargin by -\textheight
  % \textheight includes \topskip, but we should not count topskip whitespace here, backout
  \advance \topmargin by \topskip
  \settoheight{\@EWTECtmpdimenB}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\topmargin by -\@EWTECtmpdimenB\relax
  \settodepth{\@EWTECtmpdimenB}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\topmargin by -\@EWTECtmpdimenB\relax
  \divide\topmargin by 2\relax
  \advance\topmargin by \@EWTECtmpdimenA\relax
\else
\if\@EWTECextractedtoken b\relax
  \topmargin\paperheight
  \advance\topmargin by -\textheight
  % \textheight includes \topskip, but we should not count topskip whitespace here, backout
  \advance \topmargin by \topskip
  \settodepth{\@EWTECtmpdimenB}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\topmargin by -\@EWTECtmpdimenB\relax
  \advance\topmargin by -\@EWTECtmpdimenA\relax
\else
  \if\@EWTECextractedtoken t\relax
  \else
    \@EWTECclspkgerror{Unknown mode type `\@EWTECextractedtokenmacro' in \string\EWTECsettopmargin\space (line \the\inputlineno).\MessageBreak
    Defaulting to `t'}%
    {Valid modes for \string\EWTECsettopmargin\space are: t, b, c, a and q.}\relax
  \fi
  \topmargin\@EWTECtmpdimenA\relax
  \settoheight{\@EWTECtmpdimenB}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\topmargin by \@EWTECtmpdimenB\relax
\fi\fi % if t, b, c
% convert desired top margin into actual \topmargin
% this is not done for the q or a modes because they are only adjustments
\advance \topmargin by -\topskip
\advance \topmargin by -1in
\advance \topmargin by -\headheight
\advance \topmargin by -\headsep
\fi\fi % if q, a
}



% usage: \EWTECsetheadermargin[header sample][text sample]{mode: t, b, c, a}{margin/offset}
% Differentially adjusts \topmargin and \headsep (such that their sum is unchanged)
% based on the specified header margin.
% Takes into consideration the base 1in offset, \headheight, \topskip, and (by default)
% the actual height (or depth) of the \EWTECdefaultheadersampletext and
% \EWTECdefaultsampletext text.
% The available modes are:
% t = top margin (top of the header text to the top of the page)
% b = bottom margin (bottom of the header text to the top of the main text)
% c = vertically centered between the main text and the top of the page,
%     with the given offset
% a = adjust the vertical position using the given offset
% For the offsets, positive values move the header downward.
% \headheight, \headsep, \topskip and \topmargin should be set properly before
% calling this function.
\def\EWTECsetheadermargin{\@ifnextchar [{\@EWTECsetheadermargin}{\@EWTECsetheadermargin[\EWTECdefaultheadersampletext]}}
\def\@EWTECsetheadermargin[#1]{\@ifnextchar [{\@@EWTECsetheadermargin[#1]}{\@@EWTECsetheadermargin[#1][\EWTECdefaultsampletext]}}
\def\@@EWTECsetheadermargin[#1][#2]#3#4{\@EWTECtmpdimenA #4\relax
\@EWTECextracttoken{#3}\relax
% check for mode errors
\ifx\@EWTECextractedtokenmacro\@empty
  \@EWTECclspkgerror{Empty mode type in \string\EWTECsetheadermargin\space (line \the\inputlineno).\MessageBreak
  Defaulting to `t'}{Valid modes for \string\EWTECsetheadermargin\space are: t, b, c, and a.}\relax
  \let\@EWTECextractedtoken=t\relax
  \def\@EWTECextractedtokenmacro{t}\relax
\else
  \ifx\@EWTECextractedtokensdiscarded\@empty\else
    \typeout{** WARNING: \string\EWTECsetheadermargin\space mode specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
  \fi
\fi
% handle each mode
\if\@EWTECextractedtoken a\relax
  % No need to do anything here and can pass through the adjustment
  % value as is. The end adjustment of \topmargin and \headsep will
  % do all that is needed
\else
\if\@EWTECextractedtoken c\relax
  % get the bottom margin
  \@EWTECtmpdimenB\headsep\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  \advance\@EWTECtmpdimenB by \topskip
  \settoheight{\@EWTECtmpdimenC}{\begingroup #2\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual header bottom margin
  % subtract from it the top header margin
  \advance\@EWTECtmpdimenB -1in\relax % take into consideration the system 1in offset of the top margin
  \advance\@EWTECtmpdimenB by -\topmargin
  \advance\@EWTECtmpdimenB by -\headheight
  \settoheight{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by \@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the difference between the bottom and top margins
  % we need to adjust by half this amount to center the header
  \divide\@EWTECtmpdimenB by 2\relax
  % and add to offset
  \advance\@EWTECtmpdimenA by \@EWTECtmpdimenB
\else
\if\@EWTECextractedtoken b\relax
  \@EWTECtmpdimenB\headsep\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  \advance\@EWTECtmpdimenB by \topskip
  \settoheight{\@EWTECtmpdimenC}{\begingroup #2\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual header bottom margin
  % get the difference between the actual and the desired
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenA
  \@EWTECtmpdimenA\@EWTECtmpdimenB
\else
  \if\@EWTECextractedtoken t\relax
  \else
    \@EWTECclspkgerror{Unknown mode type `\@EWTECextractedtokenmacro' in \string\EWTECsetheadermargin\space (line \the\inputlineno).\MessageBreak
    Defaulting to `t'}%
    {Valid modes for \string\EWTECsetheadermargin\space are: t, b, c and a.}\relax
  \fi
  \@EWTECtmpdimenB 1in\relax % take into consideration the system 1in offset of the top margin
  \advance\@EWTECtmpdimenB by \topmargin
  \advance\@EWTECtmpdimenB by \headheight
  \settoheight{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual header top margin
  % get the difference between the desired and the actual
  \advance\@EWTECtmpdimenA by -\@EWTECtmpdimenB
\fi\fi % if t, b, c
\fi % if a
% advance \topmargin by the needed amount and reduce \headsep by the same
% so as not to disturb the location of the main text
\advance\topmargin by \@EWTECtmpdimenA\relax
\advance\headsep by -\@EWTECtmpdimenA\relax
}



% usage: \EWTECsetfootermargin[footer sample][text sample]{mode: t, b, c, a}{margin/offset}
% Adjusts \footskip based on the specified footer margin.
% Takes into consideration the base 1in offset, \paperheight, \headheight,
% \headsep, \textheight and (by default) the actual height (or depth) of the
% \EWTECdefaultfootersampletext and \EWTECdefaultsampletext text.
% The available modes are:
% t = top margin (top of the footer text to the bottom of the main text)
% b = bottom margin (bottom of the footer text to the bottom of page)
% c = vertically centered between the main text and the bottom of the page,
%     with the given offset
% a = adjust the vertical position using the given offset
% For the offsets, positive values move the footer downward.
% \headheight, \headsep, \topskip, \topmargin, and \textheight should be set
% properly before calling this function.
\def\EWTECsetfootermargin{\@ifnextchar [{\@EWTECsetfootermargin}{\@EWTECsetfootermargin[\EWTECdefaultfootersampletext]}}
\def\@EWTECsetfootermargin[#1]{\@ifnextchar [{\@@EWTECsetfootermargin[#1]}{\@@EWTECsetfootermargin[#1][\EWTECdefaultsampletext]}}
\def\@@EWTECsetfootermargin[#1][#2]#3#4{\@EWTECtmpdimenA #4\relax
\@EWTECextracttoken{#3}\relax
% check for mode errors
\ifx\@EWTECextractedtokenmacro\@empty
  \@EWTECclspkgerror{Empty mode type in \string\EWTECsetfootermargin\space (line \the\inputlineno).\MessageBreak
  Defaulting to `t'}{Valid modes for \string\EWTECsetfootermargin\space are: t, b, c, and a.}\relax
  \let\@EWTECextractedtoken=t\relax
  \def\@EWTECextractedtokenmacro{t}\relax
\else
  \ifx\@EWTECextractedtokensdiscarded\@empty\else
    \typeout{** WARNING: \string\EWTECsetfootermargin\space mode specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
  \fi
\fi
% handle each mode
\if\@EWTECextractedtoken a\relax
  % No need to do anything here and can pass through the adjustment
  % value as is. The end adjustment of \footskip will do all that
  % is needed
\else
\if\@EWTECextractedtoken c\relax
  % calculate the bottom margin
  \@EWTECtmpdimenB 1in\relax % system 1in offset
  \advance\@EWTECtmpdimenB\topmargin\relax
  \advance\@EWTECtmpdimenB\headheight\relax
  \advance\@EWTECtmpdimenB\headsep\relax
  \advance\@EWTECtmpdimenB\textheight\relax
  \advance\@EWTECtmpdimenB\footskip\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenC by \@EWTECtmpdimenB
  \@EWTECtmpdimenB\paperheight
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual footer bottom margin
  % now subtract off the footer top margin
  \advance\@EWTECtmpdimenB -\footskip\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #2\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by \@EWTECtmpdimenC
  \settoheight{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by \@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the difference between the bottom
  % and top footer margins
  % our adjustment must be half this value to center the footer
  \divide\@EWTECtmpdimenB by 2\relax
  % add to the offset
  \advance\@EWTECtmpdimenA by \@EWTECtmpdimenB
\else
\if\@EWTECextractedtoken b\relax
  % calculate the bottom margin
  \@EWTECtmpdimenB 1in\relax % system 1in offset
  \advance\@EWTECtmpdimenB\topmargin\relax
  \advance\@EWTECtmpdimenB\headheight\relax
  \advance\@EWTECtmpdimenB\headsep\relax
  \advance\@EWTECtmpdimenB\textheight\relax
  \advance\@EWTECtmpdimenB\footskip\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenC by \@EWTECtmpdimenB
  \@EWTECtmpdimenB\paperheight
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual footer bottom margin
  % get the difference between the actual and the desired
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenA
  \@EWTECtmpdimenA\@EWTECtmpdimenB
\else
  \if\@EWTECextractedtoken t\relax
  \else
    \@EWTECclspkgerror{Unknown mode type `\@EWTECextractedtokenmacro' in \string\EWTECsetfootermargin\space (line \the\inputlineno).\MessageBreak
    Defaulting to `t'}%
    {Valid modes for \string\EWTECsetfootermargin\space are: t, b, c and a.}\relax
  \fi
  \@EWTECtmpdimenB\footskip\relax
  \settodepth{\@EWTECtmpdimenC}{\begingroup #2\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  \settoheight{\@EWTECtmpdimenC}{\begingroup #1\relax\relax\relax\endgroup}\relax
  \advance\@EWTECtmpdimenB by -\@EWTECtmpdimenC
  % at this point \@EWTECtmpdimenB has the actual footer top margin
  % get the difference between the desired and the actual
  \advance\@EWTECtmpdimenA by -\@EWTECtmpdimenB
\fi\fi % if t, b, c
\fi % if a
% advance \footskip by the needed amount
\advance\footskip by \@EWTECtmpdimenA\relax
}

% -- End v1.0a page setup commands --





% v1.0
% LaTeX is a little to quick to use hyphenations
% So, we increase the penalty for their use and raise
% the badness level that triggers an underfull hbox
% warning. The author may still have to tweak things,
% but the appearance will be much better "right out
% of the box" than that under v1.0 and prior.
% TeX default is 50
\hyphenpenalty=750

% If we didn't adjust the interword spacing, 2200 might be better.
% The TeX default is 1000
\hbadness=1350
% The EWTEC does not use extra spacing after punctuation
\frenchspacing

% v1.0 increase this a tad to discourage equation breaks
\binoppenalty=1000 % default 700
\relpenalty=800     % default 500

% v1.8a increase these to discourage widows and orphans
\clubpenalty=1000          % default 150
\widowpenalty=1000         % default 150
\displaywidowpenalty=1000 % default  50


% margin note stuff
\marginparsep      10pt
\marginparwidth    20pt
\marginparpush     25pt


% if things get too close, go ahead and let them touch
\lineskip            0pt
\normallineskip      0pt
\lineskiplimit       0pt
\normallineskiplimit 0pt

% The distance from the lower edge of the text body to the
% footline
\footskip 0.4in

% normally zero, should be relative to font height.
% put in a little rubber to help stop some bad breaks (underfull vboxes)
\parskip 0ex plus 0.2ex minus 0.1ex

\parindent    1.0em

%%% LB 2018:
\headheight   12pt
\headsep      8mm
%%%

% use the normal font baselineskip
% so that \topskip is unaffected by changes in \baselinestretch
\topskip=\@EWTECnormalsizeunitybaselineskip


% v1.0 \maxdepth defaults to 4pt, but should be font size dependent
\maxdepth=0.5\@EWTECnormalsizeunitybaselineskip

%%% LB 2018:
\textheight       261mm  
%%%

% set the default top margin to 58pt
% which results in a \topmargin of -49.59pt for 10pt documents
\EWTECsettopmargin{t}{58pt}
% tweak textheight to a perfect integer number of lines/column.
% standard is: 9pt/63 lpc; 10pt/58 lpc; 11pt/52 lpc; 12pt/50 lpc
\EWTECquantizetextheight{c}
% tweak top margin so that the error is shared equally at the top and bottom
\EWTECsettopmargin{q}{0sp}

%%% LB 2018:
\columnsep         6mm
\textwidth        178mm   % 2 x 86mm + 6mm = 178mm
%%%


% set the default side margins to center the text
\EWTECsetsidemargin{c}{0pt}



% draft mode settings override that of all other modes
% provides a nice 1in margin all around the paper and extra
% space between the lines for editor's comments
\ifCLASSOPTIONdraftcls
  % we want 1in side margins regardless of paper type
  \EWTECsettextwidth{1in}{1in}
  \EWTECsetsidemargin{c}{0pt}
  % want 1in top and bottom margins
  \EWTECsettextheight{1in}{1in}
  \EWTECsettopmargin{t}{1in}
  % digitize textheight to be an integer number of lines.
  % this may cause the top and bottom margins to be off a tad
  \EWTECquantizetextheight{c}
  % tweak top margin so that the error is shared equally at the top and bottom
  \EWTECsettopmargin{q}{0sp}
\fi



% process CLASSINPUT inner/outer margin
% if inner margin defined, but outer margin not, set outer to inner.
\ifx\CLASSINPUTinnersidemargin\@EWTECundefined
\else
  \ifx\CLASSINPUToutersidemargin\@EWTECundefined
    \edef\CLASSINPUToutersidemargin{\CLASSINPUTinnersidemargin}
  \fi
\fi

\ifx\CLASSINPUToutersidemargin\@EWTECundefined
\else
  % if outer margin defined, but inner margin not, set inner to outer.
  \ifx\CLASSINPUTinnersidemargin\@EWTECundefined
    \edef\CLASSINPUTinnersidemargin{\CLASSINPUToutersidemargin}
  \fi
  \EWTECsettextwidth{\CLASSINPUTinnersidemargin}{\CLASSINPUToutersidemargin}
  \EWTECsetsidemargin{i}{\CLASSINPUTinnersidemargin}
  \typeout{** ATTENTION: Overriding inner side margin to \CLASSINPUTinnersidemargin\space and 
           outer side margin to \CLASSINPUToutersidemargin\space via \string\CLASSINPUT.}
\fi



% process CLASSINPUT top/bottom text margin
% if toptext margin defined, but bottomtext margin not, set bottomtext to toptext margin
\ifx\CLASSINPUTtoptextmargin\@EWTECundefined
\else
  \ifx\CLASSINPUTbottomtextmargin\@EWTECundefined
    \edef\CLASSINPUTbottomtextmargin{\CLASSINPUTtoptextmargin}
  \fi
\fi

\ifx\CLASSINPUTbottomtextmargin\@EWTECundefined
\else
  % if bottomtext margin defined, but toptext margin not, set toptext to bottomtext margin
  \ifx\CLASSINPUTtoptextmargin\@EWTECundefined
    \edef\CLASSINPUTtoptextmargin{\CLASSINPUTbottomtextmargin}
  \fi
  \EWTECsettextheight{\CLASSINPUTtoptextmargin}{\CLASSINPUTbottomtextmargin}
  \EWTECsettopmargin{t}{\CLASSINPUTtoptextmargin}
  \typeout{** ATTENTION: Overriding top text margin to \CLASSINPUTtoptextmargin\space and 
           bottom text margin to \CLASSINPUTbottomtextmargin\space via \string\CLASSINPUT.}
\fi



% default to center header and footer text in the margins
\EWTECsetheadermargin{c}{0pt}
\EWTECsetfootermargin{c}{0pt}



% v1.0a display lines per column info message on user's console
\def\EWTECdisplayinfolinespercolumn{\@EWTECtmpdimenA=\textheight
% topskip represents only one line even if > baselineskip
\advance\@EWTECtmpdimenA by -1\topskip
\@EWTECtmpcountA=\@EWTECtmpdimenA
\@EWTECtmpcountB=\@EWTECtmpdimenA
\divide\@EWTECtmpcountB by \baselineskip
% need to add one line to include topskip (first) line
\advance\@EWTECtmpcountB by 1
% save lines per column value as text
\edef\@EWTECnumlinespercolumninfotxt{\the\@EWTECtmpcountB}
% backout topskip advance to allow direct \@EWTECtmpcountA comparison
\advance\@EWTECtmpcountB by -1
% restore value as text height (without topskip) rather than just as number of lines
\multiply\@EWTECtmpcountB by \baselineskip
% is the column height an integer number of lines per column?
\ifnum\@EWTECtmpcountA=\@EWTECtmpcountB
\edef\@EWTECnumlinespercolumnexactinfotxt{exact}
\else
\@EWTECtmpdimenA\@EWTECtmpcountA sp\relax
\advance\@EWTECtmpdimenA by -\@EWTECtmpcountB sp\relax
\edef\@EWTECnumlinespercolumnexactinfotxt{approximate, difference = \the\@EWTECtmpdimenA}
\fi
\typeout{-- Lines per column: \@EWTECnumlinespercolumninfotxt\space (\@EWTECnumlinespercolumnexactinfotxt).}}
% delay execution till start of document to allow for user changes
\AtBeginDocument{\EWTECdisplayinfolinespercolumn}



% LIST SPACING CONTROLS

% Controls the amount of EXTRA spacing
% above and below \trivlist 
% Both \list and IED lists override this.
% However, \trivlist will use this as will most
% things built from \trivlist like the \center
% environment.
\topsep           0.5\baselineskip

% Controls the additional spacing around lists preceded
% or followed by blank lines. the EWTEC does not increase
% spacing before or after paragraphs so it is set to zero.
% \z@ is the same as zero, but faster.
\partopsep          \z@

% Controls the spacing between paragraphs in lists. 
% The EWTEC does not increase spacing before or after paragraphs
% so this is also zero. 
% With EWTEC.cls, global changes to
% this value DO affect lists (but not IED lists).
\parsep             \z@

% Controls the extra spacing between list items. 
% The EWTEC does not put extra spacing between items.
% With EWTEC.cls, global changes to this value DO affect
% lists (but not IED lists).
\itemsep            \z@

% \itemindent is the amount to indent the FIRST line of a list
% item. It is auto set to zero within the \list environment. To alter
% it, you have to do so when you call the \list.
% However, the EWTEC uses this for the theorem environment
% There is an alternative value for this near \leftmargini below
\itemindent         -1em

% \leftmargin, the spacing from the left margin of the main text to
% the left of the main body of a list item is set by \list.
% Hence this statement does nothing for lists.
% But, quote and verse do use it for indention.
\leftmargin         2em

% we retain this stuff from the older EWTEC.cls so that \list
% will work the same way as before. However, itemize, enumerate and
% description (IED) could care less about what these are as they
% all are overridden.
\leftmargini        2em
%\itemindent         2em  % Alternative values: sometimes used.
%\leftmargini        0em
\leftmarginii       1em
\leftmarginiii    1.5em
\leftmarginiv     1.5em
\leftmarginv      1.0em
\leftmarginvi     1.0em
\labelsep         0.5em 
\labelwidth         \z@


% The old EWTEC.cls behavior of \list is retained.
% However, the new V1.3 IED list environments override all the
% @list stuff (\@listX is called within \list for the
% appropriate level just before the user's list_decl is called). 
% \topsep is now 2pt as the EWTEC puts a little extra space around
% lists - used by those non-IED macros that depend on \list.
% Note that \parsep and \itemsep are not redefined as in 
% the sizexx.clo \@listX (which article.cls uses) so global changes
% of these values DO affect \list
% 
\def\@listi{\leftmargin\leftmargini \topsep 2pt plus 1pt minus 1pt}
\let\@listI\@listi
\def\@listii{\leftmargin\leftmarginii\labelwidth\leftmarginii%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listiii{\leftmargin\leftmarginiii\labelwidth\leftmarginiii%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listiv{\leftmargin\leftmarginiv\labelwidth\leftmarginiv%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listv{\leftmargin\leftmarginv\labelwidth\leftmarginv%
    \advance\labelwidth-\labelsep \topsep 2pt}
\def\@listvi{\leftmargin\leftmarginvi\labelwidth\leftmarginvi%
    \advance\labelwidth-\labelsep \topsep 2pt}


% The EWTEC uses 5) not 5.
\def\labelenumi{\theenumi)}     \def\theenumi{\arabic{enumi}}

% The EWTEC uses a) not (a)
\def\labelenumii{\theenumii)}  \def\theenumii{\alph{enumii}}

% The EWTEC uses iii) not iii.
\def\labelenumiii{\theenumiii)} \def\theenumiii{\roman{enumiii}}

% The EWTEC uses A) not A.
\def\labelenumiv{\theenumiv)}   \def\theenumiv{\Alph{enumiv}}

% exactly the same as in article.cls
\def\p@enumii{\theenumi}
\def\p@enumiii{\theenumi(\theenumii)}
\def\p@enumiv{\p@enumiii\theenumiii}

% itemized list label styles
\def\labelitemi{$\scriptstyle\bullet$}
\def\labelitemii{\textbf{--}}
\def\labelitemiii{$\ast$}
\def\labelitemiv{$\cdot$}



% **** V1.3 ENHANCEMENTS ****
% Itemize, Enumerate and Description (IED) List Controls
% ***************************
% 
% Itemized list indentation
\newdimen\EWTECilabelindent
\EWTECilabelindent \parindent

% This controls the default amount the enumerated list labels
% are indented to the right.
% Normally, this is the same as the paragraph indention
\newdimen\EWTECelabelindent
\EWTECelabelindent \parindent

% This controls the default amount the description list labels
% are indented to the right.
% Normally, this is the same as the paragraph indention
\newdimen\EWTECdlabelindent
\EWTECdlabelindent \parindent

% This is the value actually used within the IED lists.
% The IED environments automatically set its value to
% one of the three values above, so global changes do 
% not have any effect
\newdimen\EWTEClabelindent
\EWTEClabelindent \parindent

% The actual amount labels will be indented is
% \EWTEClabelindent multiplied by the factor below
% corresponding to the level of nesting depth
% This provides a means by which the user can
% alter the effective \EWTEClabelindent for deeper
% levels
% There may not be such a thing as correct "standard EWTEC"
% values. What the EWTEC actually does may depend on the specific
% circumstances.
% The first list level almost always has full indention.
% The second levels I've seen have only 75% of the normal indentation
% Three level or greater nestings are very rare. I am guessing
% that they don't use any indentation.
\def\EWTEClabelindentfactori{1.0}   % almost always one
\def\EWTEClabelindentfactorii{0.75} % 0.0 or 1.0 may be used in some cases
\def\EWTEClabelindentfactoriii{0.0} % 0.75? 0.5? 0.0?
\def\EWTEClabelindentfactoriv{0.0}
\def\EWTEClabelindentfactorv{0.0}
\def\EWTEClabelindentfactorvi{0.0}

% value actually used within IED lists, it is auto
% set to one of the 6 values above
% global changes here have no effect
\def\EWTEClabelindentfactor{1.0}

% This controls the default spacing between the end of the IED
% list labels and the list text, when normal text is used for
% the labels.
% compsoc uses a larger value here, but we'll set that later
% in the class so that this code block area can be extracted
% as-is for EWTECtools.sty
\newdimen\EWTECiednormlabelsep
\EWTECiednormlabelsep 0.6em

% This controls the default spacing between the end of the IED
% list labels and the list text, when math symbols are used for
% the labels (nomenclature lists). The EWTEC usually increases the 
% spacing in these cases
\newdimen\EWTECiedmathlabelsep
\EWTECiedmathlabelsep 1.2em

% This controls the extra vertical separation put above and
% below each IED list. the EWTEC usually puts a little extra spacing
% around each list. However, this spacing is barely noticeable.
% compsoc uses a larger value here, but we'll set that later
% in the class so that this code block area can be extracted
% as-is for EWTECtools.sty
\newskip\EWTECiedtopsep
\EWTECiedtopsep 2pt plus 1pt minus 1pt


% This command is executed within each IED list environment
% at the beginning of the list. You can use this to set the 
% parameters for some/all your IED list(s) without disturbing 
% global parameters that affect things other than lists.
% i.e., renewcommand{\EWTECiedlistdecl}{\setlength{\labelsep}{5em}}
% will alter the \labelsep for the next list(s) until 
% \EWTECiedlistdecl is redefined. 
\def\EWTECiedlistdecl{\relax}

% This command provides an easy way to set \leftmargin based
% on the \labelwidth, \labelsep and the argument \EWTEClabelindent
% Usage: \EWTECcalcleftmargin{width-to-indent-the-label}
% output is in the \leftmargin variable, i.e., effectively:
% \leftmargin = argument + \labelwidth + \labelsep
% Note controlled spacing here, shield end of lines with %
\def\EWTECcalcleftmargin#1{\setlength{\leftmargin}{#1}%
\addtolength{\leftmargin}{\labelwidth}%
\addtolength{\leftmargin}{\labelsep}}

% This command provides an easy way to set \labelwidth to the
% width of the given text. It is the same as
% \settowidth{\labelwidth}{label-text}
% and useful as a shorter alternative.
% Typically used to set \labelwidth to be the width
% of the longest label in the list
\def\EWTECsetlabelwidth#1{\settowidth{\labelwidth}{#1}}

% When this command is executed, IED lists will use the 
% EWTECiedmathlabelsep label separation rather than the normal
% spacing. To have an effect, this command must be executed via
% the \EWTECiedlistdecl or within the option of the IED list
% environments.
\def\EWTECusemathlabelsep{\setlength{\labelsep}{\EWTECiedmathlabelsep}}

% A flag which controls whether the IED lists automatically
% calculate \leftmargin from \EWTEClabelindent, \labelwidth and \labelsep
% Useful if you want to specify your own \leftmargin
% This flag must be set (\EWTECnocalcleftmargintrue or \EWTECnocalcleftmarginfalse) 
% via the \EWTECiedlistdecl or within the option of the IED list
% environments to have an effect.
\newif\ifEWTECnocalcleftmargin
\EWTECnocalcleftmarginfalse

% A flag which controls whether \EWTEClabelindent is multiplied by
% the \EWTEClabelindentfactor for each list level.
% This flag must be set via the \EWTECiedlistdecl or within the option 
% of the IED list environments to have an effect.
\newif\ifEWTECnolabelindentfactor
\EWTECnolabelindentfactorfalse


% internal variable to indicate type of IED label
% justification
% 0 - left; 1 - center; 2 - right
\def\@EWTECiedjustify{0}


% commands to allow the user to control IED
% label justifications. Use these commands within
% the IED environment option or in the \EWTECiedlistdecl
% Note that changing the normal list justifications
% is nonstandard and the EWTEC may not like it if you do so!
% I include these commands as they may be helpful to
% those who are using these enhanced list controls for
% other non-EWTEC related LaTeX work.
% itemize and enumerate automatically default to right
% justification, description defaults to left.
\def\EWTECiedlabeljustifyl{\def\@EWTECiedjustify{0}}%left
\def\EWTECiedlabeljustifyc{\def\@EWTECiedjustify{1}}%center
\def\EWTECiedlabeljustifyr{\def\@EWTECiedjustify{2}}%right




% commands to save to and restore from the list parameter copies
% this allows us to set all the list parameters within
% the list_decl and prevent \list (and its \@list) 
% from overriding any of our parameters
% v1.0 use \edefs instead of dimen's to conserve dimen registers
% Note controlled spacing here, shield end of lines with %
\def\@EWTECsavelistparams{\edef\@EWTECiedtopsep{\the\topsep}%
\edef\@EWTECiedlabelwidth{\the\labelwidth}%
\edef\@EWTECiedlabelsep{\the\labelsep}%
\edef\@EWTECiedleftmargin{\the\leftmargin}%
\edef\@EWTECiedpartopsep{\the\partopsep}%
\edef\@EWTECiedparsep{\the\parsep}%
\edef\@EWTECieditemsep{\the\itemsep}%
\edef\@EWTECiedrightmargin{\the\rightmargin}%
\edef\@EWTECiedlistparindent{\the\listparindent}%
\edef\@EWTECieditemindent{\the\itemindent}}

% Note controlled spacing here
\def\@EWTECrestorelistparams{\topsep\@EWTECiedtopsep\relax%
\labelwidth\@EWTECiedlabelwidth\relax%
\labelsep\@EWTECiedlabelsep\relax%
\leftmargin\@EWTECiedleftmargin\relax%
\partopsep\@EWTECiedpartopsep\relax%
\parsep\@EWTECiedparsep\relax%
\itemsep\@EWTECieditemsep\relax%
\rightmargin\@EWTECiedrightmargin\relax%
\listparindent\@EWTECiedlistparindent\relax%
\itemindent\@EWTECieditemindent\relax}


% v1.6b provide original LaTeX IED list environments
% note that latex.ltx defines \itemize and \enumerate, but not \description
% which must be created by the base classes
% save original LaTeX itemize and enumerate
\let\LaTeXitemize\itemize
\let\endLaTeXitemize\enditemize
\let\LaTeXenumerate\enumerate
\let\endLaTeXenumerate\endenumerate

% provide original LaTeX description environment from article.cls
\newenvironment{LaTeXdescription}
               {\list{}{\labelwidth\z@ \itemindent-\leftmargin
                        \let\makelabel\descriptionlabel}}
               {\endlist}
\newcommand*\descriptionlabel[1]{\hspace\labelsep
                                 \normalfont\bfseries #1}


% override LaTeX's default IED lists
\def\itemize{\@EWTECitemize}
\def\enditemize{\@endEWTECitemize}
\def\enumerate{\@EWTECenumerate}
\def\endenumerate{\@endEWTECenumerate}
\def\description{\@EWTECdescription}
\def\enddescription{\@endEWTECdescription}

% provide the user with aliases - may help those using packages that
% override itemize, enumerate, or description
\def\EWTECitemize{\@EWTECitemize}
\def\endEWTECitemize{\@endEWTECitemize}
\def\EWTECenumerate{\@EWTECenumerate}
\def\endEWTECenumerate{\@endEWTECenumerate}
\def\EWTECdescription{\@EWTECdescription}
\def\endEWTECdescription{\@endEWTECdescription}


% v1.0 we want to keep the EWTEC IED list definitions as our own internal
% commands so they are protected against redefinition
\def\@EWTECitemize{\@ifnextchar[{\@@EWTECitemize}{\@@EWTECitemize[\relax]}}
\def\@EWTECenumerate{\@ifnextchar[{\@@EWTECenumerate}{\@@EWTECenumerate[\relax]}}
\def\@EWTECdescription{\@ifnextchar[{\@@EWTECdescription}{\@@EWTECdescription[\relax]}}
\def\@endEWTECitemize{\endlist}
\def\@endEWTECenumerate{\endlist}
\def\@endEWTECdescription{\endlist}


% DO NOT ALLOW BLANK LINES TO BE IN THESE IED ENVIRONMENTS
% AS THIS WILL FORCE NEW PARAGRAPHS AFTER THE IED LISTS
% EWTEC itemized list MDS 1/2001
% Note controlled spacing here, shield end of lines with %
\def\@@EWTECitemize[#1]{%
                \ifnum\@itemdepth>3\relax\@toodeep\else%
                \ifnum\@listdepth>5\relax\@toodeep\else%
                \advance\@itemdepth\@ne%
                \edef\@itemitem{labelitem\romannumeral\the\@itemdepth}%
                % get the EWTEClabelindentfactor for this level
                \advance\@listdepth\@ne% we need to know what the level WILL be
                \edef\EWTEClabelindentfactor{\csname EWTEClabelindentfactor\romannumeral\the\@listdepth\endcsname}%
                \advance\@listdepth-\@ne% undo our increment
                \def\@EWTECiedjustify{2}% right justified labels are default
                % set other defaults
                \EWTECnocalcleftmarginfalse%
                \EWTECnolabelindentfactorfalse%
                \topsep\EWTECiedtopsep%
                \EWTEClabelindent\EWTECilabelindent%
                \labelsep\EWTECiednormlabelsep%
                \partopsep 0ex%
                \parsep 0ex%
                \itemsep 0ex%
                \rightmargin 0em%
                \listparindent 0em%
                \itemindent 0em%
                % calculate the label width
                % the user can override this later if
                % they specified a \labelwidth
                \settowidth{\labelwidth}{\csname labelitem\romannumeral\the\@itemdepth\endcsname}%
                \@EWTECsavelistparams% save our list parameters
                \list{\csname\@itemitem\endcsname}{%
                \@EWTECrestorelistparams% override any list{} changes
                                       % to our globals
                \let\makelabel\@EWTECiedmakelabel% v1.6b setup \makelabel
                \EWTECiedlistdecl% let user alter parameters
                #1\relax%
                % If the user has requested not to use the
                % EWTEClabelindent factor, don't revise \EWTEClabelindent
                \ifEWTECnolabelindentfactor\relax%
                \else\EWTEClabelindent=\EWTEClabelindentfactor\EWTEClabelindent%
                \fi%
                % Unless the user has requested otherwise,
                % calculate our left margin based
                % on \EWTEClabelindent, \labelwidth and
                % \labelsep
                \ifEWTECnocalcleftmargin\relax%
                \else\EWTECcalcleftmargin{\EWTEClabelindent}%
                \fi}\fi\fi}%


% DO NOT ALLOW BLANK LINES TO BE IN THESE IED ENVIRONMENTS
% AS THIS WILL FORCE NEW PARAGRAPHS AFTER THE IED LISTS
% EWTEC enumerate list MDS 1/2001
% Note controlled spacing here, shield end of lines with %
\def\@@EWTECenumerate[#1]{%
                \ifnum\@enumdepth>3\relax\@toodeep\else%
                \ifnum\@listdepth>5\relax\@toodeep\else%
                \advance\@enumdepth\@ne%
                \edef\@enumctr{enum\romannumeral\the\@enumdepth}%
                % get the EWTEClabelindentfactor for this level
                \advance\@listdepth\@ne% we need to know what the level WILL be
                \edef\EWTEClabelindentfactor{\csname EWTEClabelindentfactor\romannumeral\the\@listdepth\endcsname}%
                \advance\@listdepth-\@ne% undo our increment
                \def\@EWTECiedjustify{2}% right justified labels are default
                % set other defaults
                \EWTECnocalcleftmarginfalse%
                \EWTECnolabelindentfactorfalse%
                \topsep\EWTECiedtopsep%
                \EWTEClabelindent\EWTECelabelindent%
                \labelsep\EWTECiednormlabelsep%
                \partopsep 0ex%
                \parsep 0ex%
                \itemsep 0ex%
                \rightmargin 0em%
                \listparindent 0em%
                \itemindent 0em%
                % calculate the label width
                % We'll set it to the width suitable for all labels using
                % normalfont 1) to 9)
                % The user can override this later
                \settowidth{\labelwidth}{9)}%
                \@EWTECsavelistparams% save our list parameters
                \list{\csname label\@enumctr\endcsname}{\usecounter{\@enumctr}%
                \@EWTECrestorelistparams% override any list{} changes
                                       % to our globals
                \let\makelabel\@EWTECiedmakelabel% v1.6b setup \makelabel
                \EWTECiedlistdecl% let user alter parameters 
                #1\relax%
                % If the user has requested not to use the
                % EWTEClabelindent factor, don't revise \EWTEClabelindent
                \ifEWTECnolabelindentfactor\relax%
                \else\EWTEClabelindent=\EWTEClabelindentfactor\EWTEClabelindent%
                \fi%
                % Unless the user has requested otherwise,
                % calculate our left margin based
                % on \EWTEClabelindent, \labelwidth and
                % \labelsep
                \ifEWTECnocalcleftmargin\relax%
                \else\EWTECcalcleftmargin{\EWTEClabelindent}%
                \fi}\fi\fi}%


% DO NOT ALLOW BLANK LINES TO BE IN THESE IED ENVIRONMENTS
% AS THIS WILL FORCE NEW PARAGRAPHS AFTER THE IED LISTS
% EWTEC description list MDS 1/2001
% Note controlled spacing here, shield end of lines with %
\def\@@EWTECdescription[#1]{%
                \ifnum\@listdepth>5\relax\@toodeep\else%
                % get the EWTEClabelindentfactor for this level
                \advance\@listdepth\@ne% we need to know what the level WILL be
                \edef\EWTEClabelindentfactor{\csname EWTEClabelindentfactor\romannumeral\the\@listdepth\endcsname}%
                \advance\@listdepth-\@ne% undo our increment
                \def\@EWTECiedjustify{0}% left justified labels are default
                % set other defaults
                \EWTECnocalcleftmarginfalse%
                \EWTECnolabelindentfactorfalse%
                \topsep\EWTECiedtopsep% 
                \EWTEClabelindent\EWTECdlabelindent%
                % assume normal labelsep
                \labelsep\EWTECiednormlabelsep%
                \partopsep 0ex%
                \parsep 0ex%
                \itemsep 0ex%
                \rightmargin 0em%
                \listparindent 0em%
                \itemindent 0em%
                % Bogus label width in case the user forgets
                % to set it.
                % TIP: If you want to see what a variable's width is you
                % can use the TeX command \showthe\width-variable to 
                % display it on the screen during compilation 
                % (This might be helpful to know when you need to find out
                % which label is the widest)
                \settowidth{\labelwidth}{Hello}%
                \@EWTECsavelistparams% save our list parameters
                \list{}{\@EWTECrestorelistparams% override any list{} changes
                                               % to our globals
                \let\makelabel\@EWTECiedmakelabel% v1.6b setup \makelabel
                \EWTECiedlistdecl% let user alter parameters 
                #1\relax%
                % If the user has requested not to use the
                % labelindent factor, don't revise \EWTEClabelindent
                \ifEWTECnolabelindentfactor\relax%
                \else\EWTEClabelindent=\EWTEClabelindentfactor\EWTEClabelindent%
                \fi%
                % Unless the user has requested otherwise,
                % calculate our left margin based
                % on \EWTEClabelindent, \labelwidth and
                % \labelsep
                \ifEWTECnocalcleftmargin\relax%
                \else\EWTECcalcleftmargin{\EWTEClabelindent}\relax%
                \fi}\fi}

% v1.6b we use one makelabel that does justification as needed.
\def\@EWTECiedmakelabel#1{\relax\if\@EWTECiedjustify 0\relax
\makebox[\labelwidth][l]{\normalfont #1}\else
\if\@EWTECiedjustify 1\relax
\makebox[\labelwidth][c]{\normalfont #1}\else
\makebox[\labelwidth][r]{\normalfont #1}\fi\fi}


% VERSE and QUOTE
% v1.0 define environments with newenvironment
\newenvironment{verse}{\let\\=\@centercr
    \list{}{\itemsep\z@ \itemindent -1.5em \listparindent \itemindent
    \rightmargin\leftmargin\advance\leftmargin 1.5em}\item\relax}
    {\endlist}
\newenvironment{quotation}{\list{}{\listparindent 1.5em \itemindent\listparindent
    \rightmargin\leftmargin \parsep 0pt plus 1pt}\item\relax}
    {\endlist}
\newenvironment{quote}{\list{}{\rightmargin\leftmargin}\item\relax}
    {\endlist}


% \titlepage
% provided only for backward compatibility. \maketitle is the correct
% way to create the title page. 
\def\titlepage{\@restonecolfalse\if@twocolumn\@restonecoltrue\onecolumn
    \else \newpage \fi \thispagestyle{empty}\c@page\z@}
\def\endtitlepage{\if@restonecol\twocolumn \else \newpage \fi}

% standard values from article.cls
\arraycolsep     5pt
\arrayrulewidth .4pt
\doublerulesep   2pt

\tabcolsep       6pt
\tabbingsep      0.5em


%% FOOTNOTES
%
%\skip\footins 10pt plus 4pt minus 2pt
% v1.0 respond to changes in font size
% space added above the footnotes (if present)
\skip\footins 0.9\baselineskip  plus 0.4\baselineskip  minus 0.2\baselineskip

% v1.0, we need to make \footnotesep responsive to changes
% in \baselineskip or sge spacings will result when in
% draft mode. Here is a little LaTeX secret - \footnotesep
% determines the height of an invisible strut that is placed
% *above* the baseline of footnotes after the first. Since
% LaTeX considers the space for characters to be 0.7\baselineskip
% above the baseline and 0.3\baselineskip below it, we need to
% use 0.7\baselineskip as a \footnotesep to maintain equal spacing
% between all the lines of the footnotes. The EWTEC often uses a tad
% more, so use 0.8\baselineskip. This slightly larger value also helps
% the text to clear the footnote marks. Note that \thanks in EWTEC
% uses its own value of \footnotesep which is set in \maketitle.
{\footnotesize
\global\footnotesep 0.8\baselineskip}


\skip\@mpfootins = \skip\footins
\fboxsep = 3pt
\fboxrule = .4pt
% v1.0 use 1em, then use LaTeX2e's \@makefnmark
% Note that the EWTEC normally *left* aligns the footnote marks, so we don't need
% box resizing tricks here.
\long\def\@makefntext#1{\parindent 1em\indent\hbox{\@makefnmark}#1}% v1.0 use 1em
% v1.0 compsoc does not use superscipts for footnote marks

% The EWTEC does not use footnote rules
\def\footnoterule{}


% v1.0 do not allow LaTeX to break a footnote across multiple pages
\interfootnotelinepenalty=10000

% v1.0 discourage breaks within equations
% Note that amsmath normally sets this to 10000,
% but LaTeX2e normally uses 100.
\interdisplaylinepenalty=2500

% default allows section depth up to /paragraph
\setcounter{secnumdepth}{4}



\newcounter{section}
\newcounter{subsection}[section]
\newcounter{subsubsection}[subsection]
\newcounter{paragraph}[subsubsection]

% used only by EWTEC's EWTECeqnarray as other packages may
% have their own, different, implementations
\newcounter{EWTECsubequation}[equation]

% as shown when called by user from \ref, \label and in table of contents
\def\theequation{\arabic{equation}}                          % 1
\def\theEWTECsubequation{\theequation\alph{EWTECsubequation}}  % 1a (used only by EWTEC's EWTECeqnarray)


\def\thesection{\Roman{section}}                             % I
% v1.0, \mbox prevents breaks around - 
\def\thesubsection{\mbox{\thesection-\Alph{subsection}}}     % I-A
% v1.0 use I-A1 format used by the EWTEC rather than I-A.1
\def\thesubsubsection{\thesubsection\arabic{subsubsection}}  % I-A1
\def\theparagraph{\thesubsubsection\alph{paragraph}}         % I-A1a


% From Heiko Oberdiek. Because of the \mbox in \thesubsection, we need to
% tell hyperref to disable the \mbox command when making PDF bookmarks.
% This done already with hyperref.sty version 6.74o and later, but
% it will not hurt to do it here again for users of older versions.
\@ifundefined{pdfstringdefPreHook}{\let\pdfstringdefPreHook\@empty}{}%
\g@addto@macro\pdfstringdefPreHook{\let\mbox\relax}


% Main text forms (how shown in main text headings)
% v1.0, using \thesection in \thesectiondis allows changes
% in the former to automatically appear in the latter
\def\thesectiondis{\thesection.}                   % I.
\def\thesubsectiondis{\Alph{subsection}.}          % B.
\def\thesubsubsectiondis{\arabic{subsubsection})}  % 3)
\def\theparagraphdis{\alph{paragraph})}            % d)


% just like LaTeX2e's \@eqnnum
\def\theequationdis{{\normalfont \normalcolor (\theequation)}}% (1)
% EWTECsubequation used only by EWTEC's EWTECeqnarray
\def\theEWTECsubequationdis{{\normalfont \normalcolor (\theEWTECsubequation)}}% (1a)
% redirect LaTeX2e's equation number display and all that depend on
% it, through EWTEC's \theequationdis
\def\@eqnnum{\theequationdis}



% v1.0 provide string macros as article.cls does
\def\contentsname{Contents}
\def\listfigurename{List of Figures}
\def\listtablename{List of Tables}
\def\refname{References}
\def\indexname{Index}
\def\figurename{Fig.}
\def\tablename{TABLE}
\def\partname{Part}
\def\appendixname{Appendix}
\def\abstractname{Abstract}
% EWTEC specific names
\def\EWTECkeywordsname{Index Terms}
\def\EWTECproofname{Proof}


% LIST OF FIGURES AND TABLES AND TABLE OF CONTENTS
%
\def\@pnumwidth{1.55em}
\def\@tocrmarg{2.55em}
\def\@dotsep{4.5}
\setcounter{tocdepth}{3}

% adjusted some spacings here so that section numbers will not easily 
% collide with the section titles. 
% VIII; VIII-A; and VIII-A.1 are usually the worst offenders.
% MDS 1/2001
\def\tableofcontents{\section*{\contentsname}\@starttoc{toc}}
\def\l@section#1#2{\addpenalty{\@secpenalty}\addvspace{1.0em plus 1pt}%
    \@tempdima 2.75em \begingroup \parindent \z@ \rightskip \@pnumwidth%
    \parfillskip-\@pnumwidth {\bfseries\leavevmode #1}\hfil\hbox to\@pnumwidth{\hss #2}\par%
    \endgroup}
% argument format #1:level, #2:labelindent,#3:labelsep
\def\l@subsection{\@dottedtocline{2}{2.75em}{3.75em}}
\def\l@subsubsection{\@dottedtocline{3}{6.5em}{4.5em}}
% must provide \l@ defs for ALL sublevels EVEN if tocdepth
% is such as they will not appear in the table of contents
% these defs are how TOC knows what level these things are!
\def\l@paragraph{\@dottedtocline{4}{6.5em}{5.5em}}
\def\l@subparagraph{\@dottedtocline{5}{6.5em}{6.5em}}
\def\listoffigures{\section*{\listfigurename}\@starttoc{lof}}
\def\l@figure{\@dottedtocline{1}{0em}{2.75em}}
\def\listoftables{\section*{\listtablename}\@starttoc{lot}}
\let\l@table\l@figure


% Definitions for floats
%
% Normal Floats
% v1.0 floatsep et al. revised down by 0.15\baselineskip
% to account for the sideeffects of \topskip compensation
\floatsep 0.85\baselineskip plus  0.2\baselineskip minus  0.2\baselineskip
\textfloatsep 1.55\baselineskip plus  0.2\baselineskip minus  0.4\baselineskip
\@fptop 0pt plus 1fil
\@fpsep 0.75\baselineskip plus 2fil
\@fpbot 0pt plus 1fil
\def\topfraction{0.9}
\def\bottomfraction{0.4}
\def\floatpagefraction{0.8}
% v1.0, let top floats approach 90% of page
\def\textfraction{0.1}

% Double Column Floats
\dblfloatsep 0.85\baselineskip plus  0.2\baselineskip minus  0.2\baselineskip

\dbltextfloatsep 1.55\baselineskip plus  0.2\baselineskip minus  0.4\baselineskip
% Note that it would be nice if the rubber here actually worked in LaTeX2e.
% There is a long standing limitation in LaTeX, first discovered (to the best
% of my knowledge) by Alan Jeffrey in 1992. LaTeX ignores the stretchable
% portion of \dbltextfloatsep, and as a result, double column figures can and
% do result in an non-integer number of lines in the main text columns with
% underfull vbox errors as a consequence. A post to comp.text.tex
% by Donald Arseneau confirms that this had not yet been fixed in 1998.
% EWTEC v1.0 will fix this problem for you in the titles, but it doesn't
% protect you from other double floats. Happy vspace'ing.

\@dblfptop 0pt plus 1fil
\@dblfpsep 0.75\baselineskip plus 2fil
\@dblfpbot 0pt plus 1fil
\def\dbltopfraction{0.8}
\def\dblfloatpagefraction{0.8}
\setcounter{dbltopnumber}{4}

\intextsep 0.85\baselineskip plus 0.2\baselineskip minus  0.2\baselineskip
\setcounter{topnumber}{2}
\setcounter{bottomnumber}{2}
\setcounter{totalnumber}{4}



% article class provides these, we should too.
\newlength\abovecaptionskip
\newlength\belowcaptionskip
% but only \abovecaptionskip is used above figure captions and *below* table
% captions
\setlength\abovecaptionskip{0.5\baselineskip}

\setlength\belowcaptionskip{0pt}
% v1.0 create hooks in case the caption spacing ever needs to be
% overridden by a user
\def\@EWTECfigurecaptionsepspace{\vskip\abovecaptionskip\relax}%
\def\@EWTECtablecaptionsepspace{\vskip\abovecaptionskip\relax}%


% 1.6b revise caption system so that \@makecaption uses two arguments
% as with LaTeX2e. Otherwise, there will be problems when using hyperref.
\def\@EWTECtablestring{table}


% v1.0 compensate for \topskip so top of top figures align with tops of the first lines of main text
% here we calculate a space equal to the amount \topskip exceeds the main text height
% we hook in at \@floatboxreset
\def\@EWTECfiguretopskipspace{\ifdim\prevdepth=-1000pt\relax
\setlength{\@EWTECtmpdimenA}{1\topskip}\relax
\addtolength{\@EWTECtmpdimenA}{-0.7\@EWTECnormalsizeunitybaselineskip}\relax
\vspace*{\@EWTECtmpdimenA}\fi}
% v1.0 compensate for \topskip at the top of top tables so caption text is on main text baseline
% use a strut set on the caption baseline within \@makecaption
\def\@EWTECtabletopskipstrut{\ifdim\prevdepth=-1000pt\rule{0pt}{\topskip}\fi}
% the \ifdim\prevdepth checks are always expected to be true for EWTEC style float caption ordering
% because top of figure content and top of captions in tables is the first thing on the vertical
% list of these floats
% thanks to Donald Arseneau for his 2000/11/11 post "Re: caption hacking" with info on this topic.



%
% traditional noncompsoc \@makecaption
\long\def\@makecaption#1#2{%
% test if is a for a figure or table
\ifx\@captype\@EWTECtablestring%
% if a table, do table caption
\footnotesize\bgroup\par\centering\@EWTECtabletopskipstrut{\normalfont\footnotesize #1}\\{\normalfont\footnotesize\scshape #2}\par\addvspace{0.5\baselineskip}\egroup%
\@EWTECtablecaptionsepspace
% if not a table, format it as a figure
\else
\@EWTECfigurecaptionsepspace
% 3/2001 use footnotesize, not small; use two nonbreaking spaces, not one
\setbox\@tempboxa\hbox{\normalfont\footnotesize {#1.}\nobreakspace\nobreakspace #2}%
\ifdim \wd\@tempboxa >\hsize%
% if caption is longer than a line, let it wrap around
\setbox\@tempboxa\hbox{\normalfont\footnotesize {#1.}\nobreakspace\nobreakspace}%
\parbox[t]{\hsize}{\normalfont\footnotesize\noindent\unhbox\@tempboxa#2}%
% if caption is shorter than a line, center if conference, left justify otherwise
\else%
\hbox to\hsize{\normalfont\footnotesize\box\@tempboxa\hfil}%
\fi
\fi}




% v1.0 disable captions class option, do so in a way that retains operation of \label
% within \caption
\ifCLASSOPTIONcaptionsoff
\long\def\@makecaption#1#2{\vspace*{2em}\footnotesize\bgroup\par\addvspace{0.5\baselineskip}\centering{\footnotesize #1}\par\addvspace{0.5\baselineskip}\egroup%
\let\@EWTECtemporiglabeldefsave\label
\let\@EWTECtemplabelargsave\relax
\def\label##1{\gdef\@EWTECtemplabelargsave{##1}}%
\setbox\@tempboxa\hbox{#2}%
\let\label\@EWTECtemporiglabeldefsave
\ifx\@EWTECtemplabelargsave\relax\else\label{\@EWTECtemplabelargsave}\fi}
\fi


% v1.0 define end environments with \def not \let so as to work OK with
% preview-latex
\newcounter{figure}
\def\thefigure{\@arabic\c@figure}
\def\fps@figure{tbp}
\def\ftype@figure{1}
\def\ext@figure{lof}
\def\fnum@figure{\figurename\nobreakspace\thefigure}
% v1.0 within figures add \@EWTECfiguretopskipspace compensation to LaTeX2e's \@floatboxreset
\def\figure{\def\@floatboxreset{\reset@font\normalsize\@setminipage\@EWTECfiguretopskipspace}\@float{figure}}
\def\endfigure{\end@float}
% v1.0 also add \@EWTECfiguretopskipspace compensation to \figure*
\@namedef{figure*}{\def\@floatboxreset{\reset@font\normalsize\@setminipage\@EWTECfiguretopskipspace}\@dblfloat{figure}}
\@namedef{endfigure*}{\end@dblfloat}

\newcounter{table}
\def\thetable{\@Roman\c@table}
\def\fps@table{tbp}
\def\ftype@table{2}
\def\ext@table{lot}
\def\fnum@table{\tablename\nobreakspace\thetable}
% v1.0 The EWTEC uses 8pt text for tables
% within tables alter LaTeX2e's \@floatboxreset to use \footnotesize
\def\table{\def\@floatboxreset{\reset@font\footnotesize\@setminipage}\@float{table}}
\def\endtable{\end@float}
% v1.6b double column tables need to default to footnotesize as well.
\@namedef{table*}{\def\@floatboxreset{\reset@font\footnotesize\@setminipage}\@dblfloat{table}}
\@namedef{endtable*}{\end@dblfloat}




%% -- Command Argument Scanning Support Functions --
%% v1.0a 

% usage: \@EWTECstripouterbraces*{}
% \@EWTECstripouterbraces fully expands its argument (which it then stores
% in \@EWTECstripouterbracesarg) via \edef, then removes any outer enclosing
% braces, and finally stores the result in the macro
% \@EWTECstrippedouterbraces.
%
% For example:
% \@EWTECstripouterbraces{{{{ab}c}}}
% results in:
%
% \@EWTECstripouterbracesarg ==> a macro containing {{{ab}c}}
% \@EWTECstrippedouterbraces ==> a macro containing {ab}c
%
% the *-star form,\@EWTECstripouterbraces*, does not expand the argument
% contents during processing
\def\@EWTECstripouterbraces{\@ifstar{\let\@EWTECstripouterbracesdef=\def\@@EWTECstripouterbraces}{\let\@EWTECstripouterbracesdef=\edef\@@EWTECstripouterbraces}}

\def\@@EWTECstripouterbraces#1{\@EWTECstripouterbracesdef\@EWTECstripouterbracesarg{#1}\relax
% If the macro is unchanged after being acquired as a single delimited
% argument, we know we have one sequence of tokens without any enclosing
% braces. Loop until this is true.
\loop
  \expandafter\@@@EWTECstripouterbraces\@EWTECstripouterbracesarg\@EWTECgeneralsequenceDELIMITER
\ifx\@EWTECstrippedouterbraces\@EWTECstripouterbracesarg
\else
  \let\@EWTECstripouterbracesarg\@EWTECstrippedouterbraces
\repeat}

\def\@@@EWTECstripouterbraces#1\@EWTECgeneralsequenceDELIMITER{\def\@EWTECstrippedouterbraces{#1}}



% usage: \@EWTECextractgroup*{}
% \@EWTECextractgroup fully expands its argument (which it then stores in
% \@EWTECextractgrouparg) via \edef and then assigns the first "brace group"
% of tokens to the macro \@EWTECextractedgroup.
% The remaining groups, if any, are stored in the macro
% \@EWTECextractedgroupremain. If the argument does not contain the requisite
% groups, the respective macros will be defined to be empty.
% There is an asymmetry in that \@EWTECextractedgroup is stripped of its first
% outer grouping while \@EWTECextractedgroupremain retains even the outer
% grouping (if present) that originally identified it as a group.
%
% For example:
% \@EWTECextractgroup{{{ab}}{c{de}}}
% results in:
%
% \@EWTECextractgrouparg       ==> a macro containing {{ab}}{c{de}}
% \@EWTECextractedgroup        ==> a macro containing {ab}
% \@EWTECextractedgroupremain  ==> a macro containing {c{de}}
%
% The *-star form, \@EWTECextractgroup*, does not expand its argument
% contents during processing.
\def\@EWTECextractgroup{\@ifstar{\let\@EWTECextractgroupdef=\def\@@EWTECextractgroup}{\let\@EWTECextractgroupdef=\edef\@@EWTECextractgroup}}

\def\@@EWTECextractgroup#1{\@EWTECextractgroupdef\@EWTECextractgrouparg{#1}\relax
% trap the case of an empty extracted group as this would cause problems with
% \@EWTECextractgroupremain's argument acquisition
\ifx\@EWTECextractgrouparg\@empty
  \def\@EWTECextractedgroup{}\relax
  \def\@EWTECextractedgroupremain{}\relax
\else
  % We have to use some dirty tricks here. We want to insert {} around
  % whatever remains after the first group so that TeX's argument scanner
  % will preserve any originally enclosing braces as well as provide an
  % empty argument to acquire even if there isn't a second group.
  % In this first of two dirty tricks, we put a } at the end of the structure
  % we are going to extract from. The \ifnum0=`{\fi keeps TeX happy to allow
  % what would otherwise be an unbalanced macro definition for
  % \@@EWTECextractgroup to be acceptable to it.
  \ifnum0=`{\fi\expandafter\@EWTECextractgroupremain\@EWTECextractgrouparg}\relax
\fi}

% In the second part of the dirty tricks, we insert a leading { right after
% the first group is acquired, but before the remainder is. Again, the
% \ifnum0=`}\fi keeps TeX happy during definition time, but will disappear
% during run time.
\def\@EWTECextractgroupremain#1{\def\@EWTECextractedgroup{#1}\expandafter\@@EWTECextractgroupremain\expandafter{\ifnum0=`}\fi}

\def\@@EWTECextractgroupremain#1{\def\@EWTECextractedgroupremain{#1}}



% \@EWTECextracttoken relocated at top because margin setting commands rely on it



% usage: \@EWTECextracttokengroups*{}
% \@EWTECextracttokengroups fully expands its argument (which it then stores
% in \@EWTECextracttokengroupsarg) and then assigns the first "brace group" of
% tokens (with the outermost braces removed) to the macro
% \@EWTECextractedfirstgroup.
% The meaning of the first nonbrace (but including the empty group) token
% within this first group is assigned via \let to \@EWTECextractedfirsttoken
% as well as stored in the macro \@EWTECextractedfirsttokenmacro. If a first
% nonbrace token does not exist (or is an empty group), these will be \relax
% and empty, respectively.  Tokens that would otherwise be discarded during
% the acquisition of the first token in the first group are stored in
% \@EWTECextractedfirsttokensdiscarded, however their original relative brace
% nesting depths are not guaranteed to be preserved.
% The first group within this first group is stored in the macro
% \@EWTECextractedfirstfirstgroup.
% Likewise for the next group after the first: \@EWTECextractednextgroup,
% \@EWTECextractednextfirstgroup, \@EWTECextractednextgroupfirsttoken,
% \@EWTECextractednextgroupfirsttokenmacro, and 
% \@EWTECextractednextfirsttokensdiscarded.
% All tokens/groups after the first group, including any enclosing braces,
% are stored in the macro \@EWTECextractedafterfirstgroupremain which will
% be empty if none exist.
%
% For example:
% \@EWTECextracttokengroups{{{ab}{cd}}{{ef}g}}
% will result in:
%
% \@EWTECextracttokengroupsarg             ==> a macro containing {{ab}{cd}}{{ef}g}
% \@EWTECextractedfirstgroup               ==> a macro containing {ab}{cd}
% \@EWTECextractedafterfirstgroupremain    ==> a macro containing {{ef}g}
% \@EWTECextractedfirsttoken               ==> the letter a
% \@EWTECextractedfirsttokenmacro          ==> a macro containing a
% \@EWTECextractedfirsttokensdiscarded     ==> a macro containing bcd
% \@EWTECextractedfirstfirstgroup          ==> a macro containing ab
% \@EWTECextractednextgroup                ==> a macro containing {ef}g
% \@EWTECextractednextfirsttoken           ==> the letter e
% \@EWTECextractednextfirsttokenmacro      ==> a macro containing e
% \@EWTECextractednextfirsttokensdiscarded ==> a macro containing fg
% \@EWTECextractednextfirstgroup           ==> a macro containing ef
%
% If given an empty argument, \@EWTECextractedfirsttoken and
% \@EWTECextractednextfirsttoken will be set to \relax
% and all the macros will be empty.
% the *-star form, \@EWTECextracttokengroups*, does not expand its argument
% contents during processing.
%
% Depends on: \@EWTECextractgroup, \@EWTECextracttoken
\def\@EWTECextracttokengroups{\@ifstar{\let\@EWTECextracttokengroupsdef=\def\@@EWTECextracttokengroups}{\let\@EWTECextracttokengroupsdef=\edef\@@EWTECextracttokengroups}}
\def\@@EWTECextracttokengroups#1{\@EWTECextracttokengroupsdef\@EWTECextracttokengroupsarg{#1}\relax
% begin extraction, these functions are safe with empty arguments
% first group
\expandafter\@EWTECextractgroup\expandafter*\expandafter{\@EWTECextracttokengroupsarg}\relax
\let\@EWTECextractedfirstgroup\@EWTECextractedgroup
\let\@EWTECextractedafterfirstgroupremain\@EWTECextractedgroupremain
\expandafter\@EWTECextracttoken\expandafter*\expandafter{\@EWTECextractedfirstgroup}\relax
\let\@EWTECextractedfirsttoken\@EWTECextractedtoken
\let\@EWTECextractedfirsttokenmacro\@EWTECextractedtokenmacro
\let\@EWTECextractedfirsttokensdiscarded\@EWTECextractedtokensdiscarded
% first first group
\expandafter\@EWTECextractgroup\expandafter*\expandafter{\@EWTECextractedfirstgroup}\relax
\let\@EWTECextractedfirstfirstgroup\@EWTECextractedgroup
% next group
\expandafter\@EWTECextractgroup\expandafter*\expandafter{\@EWTECextractedafterfirstgroupremain}\relax
\let\@EWTECextractednextgroup\@EWTECextractedgroup
\expandafter\@EWTECextracttoken\expandafter*\expandafter{\@EWTECextractednextgroup}\relax
\let\@EWTECextractednextfirsttoken\@EWTECextractedtoken
\let\@EWTECextractednextfirsttokenmacro\@EWTECextractedtokenmacro
\let\@EWTECextractednextfirsttokensdiscarded\@EWTECextractedtokensdiscarded
% next first group
\expandafter\@EWTECextractgroup\expandafter*\expandafter{\@EWTECextractednextgroup}\relax
\let\@EWTECextractednextfirstgroup\@EWTECextractedgroup}


%% -- End of Command Argument Scanning Support Functions --




%%
%% START OF EWTECeqnarray DEFINITIONS
%%
%% Inspired by the concepts, examples, and previous works of LaTeX 
%% coders and developers such as Donald Arseneau, Fred Bartlett, 
%% David Carlisle, Tony Liu, Frank Mittelbach, Piet van Oostrum, 
%% Roland Winkler and Mark Wooding.
%% I don't make the claim that my work here is even near their calibre. ;)


\newif\if@EWTECeqnarrayboxnojot% flag to indicate if the environment was called as the star form
\@EWTECeqnarrayboxnojotfalse

\newif\if@advanceEWTECeqncolcnt% tracks if the environment should advance the col counter
% allows a way to make an \EWTECeqnarraybox that can be used within an \EWTECeqnarray
% used by EWTECeqnarraymulticol so that it can work properly in both
\@advanceEWTECeqncolcnttrue

\newcount\@EWTECeqnnumcols % tracks how many EWTECeqnarray cols are defined
\newcount\@EWTECeqncolcnt  % tracks how many EWTECeqnarray cols the user actually used


% The default math style used by the columns
\def\EWTECeqnarraymathstyle{\displaystyle}
% The default text style used by the columns
% default to using the current font
\def\EWTECeqnarraytextstyle{\relax}

% like the iedlistdecl but for \EWTECeqnarray
\def\EWTECeqnarraydecl{\relax}
\def\EWTECeqnarrayboxdecl{\relax}



% v1.0 flags to indicate that equation numbering is to persist
\newif\if@EWTECeqnumpersist%
\@EWTECeqnumpersistfalse
\newif\if@EWTECsubeqnumpersist%
\@EWTECsubeqnumpersistfalse
%
% v1.0 flags to indicate if (sub)equation number of last line was preadvanced
\newif\if@EWTECeqnumpreadv%
\@EWTECeqnumpreadvfalse
\newif\if@EWTECsubeqnumpreadv%
\@EWTECsubeqnumpreadvfalse

\newcount\@EWTECsubeqnnumrollback% saves previous value of EWTECsubequation number in case we need to restore it

% \yesnumber is the opposite of \nonumber
% a novel concept with the same def as the equationarray package
% However, we give EWTEC versions too since some LaTeX packages such as 
% the MDWtools mathenv.sty redefine \nonumber to something else.
% This command is intended for use in non-EWTECeqnarray math environments
\providecommand{\yesnumber}{\global\@eqnswtrue}


% EWTECyes/nonumber 
% v1.0 add persistant * forms
% These commands can alter the type of equation an EWTECeqnarray line is.
\def\EWTECyesnumber{\@ifstar{\global\@EWTECeqnumpersisttrue\global\@EWTECsubeqnumpersistfalse\@EWTECyesnumber}{\@EWTECyesnumber}}

\def\@EWTECyesnumber{\global\@eqnswtrue
\if@EWTECeqnarrayISinner% alter counters and label only inside an EWTECeqnarray
\ifnum\c@EWTECsubequation>0\relax
   \stepcounter{equation}\setcounter{EWTECsubequation}{0}\gdef\@currentlabel{\p@equation\theequation}\relax
   \gdef\@currentHref{\@EWTECtheHrefequation}% setup hyperref label
\fi
% even if we reached this eqn num via a preadv, it is legit now
\global\@EWTECeqnumpreadvfalse\global\@EWTECsubeqnumpreadvfalse
\fi}

\def\EWTECnonumber{\@ifstar{\global\@EWTECeqnumpersistfalse\global\@EWTECsubeqnumpersistfalse\global\@eqnswfalse}{\global\@eqnswfalse}}


\def\EWTECyessubnumber{\@ifstar{\global\@EWTECsubeqnumpersisttrue\@EWTECyessubnumber}{\@EWTECyessubnumber}}
%
\def\@EWTECyessubnumber{\if@EWTECeqnarrayISinner% alter counters and label only inside an EWTECeqnarray
  \ifnum\c@EWTECsubequation>0\relax% if it already is a subequation, we are good to go as-is
  \else% if we are a regular equation we have to watch out for two cases
    \if@EWTECeqnumpreadv% if this equation is the result of a preadvance, backout and bump the sub eqnnum
       \global\advance\c@equation\m@ne\global\c@EWTECsubequation=\@EWTECsubeqnnumrollback\addtocounter{EWTECsubequation}{1}\relax
    \else% non-preadvanced equations just need initialization of their sub eqnnum
       \setcounter{EWTECsubequation}{1}\relax
    \fi
  \fi% fi already is subequation
  \gdef\@currentlabel{\p@EWTECsubequation\theEWTECsubequation}\relax
  \gdef\@currentHref{\@EWTECtheHrefsubequation}% setup hyperref label
  \global\@EWTECeqnumpreadvfalse\global\@EWTECsubeqnumpreadvfalse% no longer a preadv anymore
  \global\@eqnswtrue
\fi}


\def\EWTECnosubnumber{\@ifstar{\global\@EWTECsubeqnumpersistfalse\@EWTECnosubnumber}{\@EWTECnosubnumber}}
%
\def\@EWTECnosubnumber{\if@EWTECeqnarrayISinner% alter counters and label only inside an EWTECeqnarray
  \if@eqnsw % we do nothing unless we know we will display because we play with the counters here
    % if it currently is a subequation, bump up to the next equation number and turn off the subequation
    \ifnum\c@EWTECsubequation>0\relax\addtocounter{equation}{1}\setcounter{EWTECsubequation}{0}\relax
    \fi
    \global\@EWTECeqnumpreadvfalse\global\@EWTECsubeqnumpreadvfalse% no longer a preadv anymore
    \gdef\@currentlabel{\p@equation\theequation}\relax
    \gdef\@currentHref{\@EWTECtheHrefequation}% setup hyperref label
  \fi
\fi}



% allows users to "push away" equations that get too close to the equation numbers
\def\EWTECeqnarraynumspace{\hphantom{\ifnum\c@EWTECsubequation>0\relax\theEWTECsubequationdis\else\theequationdis\fi}}

% provides a way to span multiple columns within EWTECeqnarray environments
% will consider \if@advanceEWTECeqncolcnt before globally advancing the
% column counter - so as to work within \EWTECeqnarraybox
% usage: \EWTECeqnarraymulticol{number cols. to span}{col type}{cell text}
\long\def\EWTECeqnarraymulticol#1#2#3{\multispan{#1}\relax
% check if column is defined for the precolumn definition
% We have to be careful here because TeX scans for & even within an \iffalse
% where it does not expand macros. So, if we used only one \ifx and a #3
% appeared in the false branch and the user inserted another alignment
% structure that uses & in the \EWTECeqnarraymulticol{}, TeX will not see that
% there is an inner alignment in the false branch yet still will see any &
% there and will think that they apply to the outer alignment resulting in an
% incomplete \ifx error.
% So, here we use separate checks for the pre and post parts in order to keep
% the #3 outside of all conditionals.
\relax\expandafter\ifx\csname @EWTECeqnarraycolDEF#2\endcsname\@EWTECeqnarraycolisdefined\relax
\csname @EWTECeqnarraycolPRE#2\endcsname
\else% if not, error and use default type
\@EWTECclspkgerror{Invalid column type "#2" in \string\EWTECeqnarraymulticol.\MessageBreak
Using a default centering column instead}%
{You must define EWTECeqnarray column types before use.}%
\csname @EWTECeqnarraycolPRE@EWTECdefault\endcsname
\fi
% The ten \relax are to help prevent misleading error messages in case a user
% accidently inserted a macro that tries to acquire additional arguments.
#3\relax\relax\relax\relax\relax\relax\relax\relax\relax\relax
% check if column is defined for the postcolumn definition
\expandafter\ifx\csname @EWTECeqnarraycolDEF#2\endcsname\@EWTECeqnarraycolisdefined\relax
\csname @EWTECeqnarraycolPOST#2\endcsname
\else% if not, use the default type
\csname @EWTECeqnarraycolPOST@EWTECdefault\endcsname
\fi
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by #1\relax\fi}

% like \omit, but maintains track of the column counter for \EWTECeqnarray
\def\EWTECeqnarrayomit{\omit\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by 1\relax\fi}


% provides a way to define a letter referenced column type
% usage: \EWTECeqnarraydefcol{col. type letter/name}{pre insertion text}{post insertion text}
\def\EWTECeqnarraydefcol#1#2#3{\expandafter\def\csname @EWTECeqnarraycolPRE#1\endcsname{#2}%
\expandafter\def\csname @EWTECeqnarraycolPOST#1\endcsname{#3}%
\expandafter\def\csname @EWTECeqnarraycolDEF#1\endcsname{1}}


% provides a way to define a numerically referenced inter-column glue types
% usage: \EWTECeqnarraydefcolsep{col. glue number}{glue definition}
\def\EWTECeqnarraydefcolsep#1#2{\expandafter\def\csname @EWTECeqnarraycolSEP\romannumeral #1\endcsname{#2}%
\expandafter\def\csname @EWTECeqnarraycolSEPDEF\romannumeral #1\endcsname{1}}


\def\@EWTECeqnarraycolisdefined{1}% just a macro for 1, used for checking undefined column types


% expands and appends the given argument to the \@EWTECtmptoksA token list
% used to build up the \halign preamble
\def\@EWTECappendtoksA#1{\edef\@@EWTECappendtoksA{\@EWTECtmptoksA={\the\@EWTECtmptoksA #1}}%
\@@EWTECappendtoksA}

% also appends to \@EWTECtmptoksA, but does not expand the argument
% uses \toks8 as a scratchpad register
\def\@EWTECappendNOEXPANDtoksA#1{\toks8={#1}%
\edef\@@EWTECappendNOEXPANDtoksA{\@EWTECtmptoksA={\the\@EWTECtmptoksA\the\toks8}}%
\@@EWTECappendNOEXPANDtoksA}

% define some common column types for the user
% math
\EWTECeqnarraydefcol{l}{$\EWTECeqnarraymathstyle}{$\hfil}
\EWTECeqnarraydefcol{c}{\hfil$\EWTECeqnarraymathstyle}{$\hfil}
\EWTECeqnarraydefcol{r}{\hfil$\EWTECeqnarraymathstyle}{$}
\EWTECeqnarraydefcol{L}{$\EWTECeqnarraymathstyle{}}{{}$\hfil}
\EWTECeqnarraydefcol{C}{\hfil$\EWTECeqnarraymathstyle{}}{{}$\hfil}
\EWTECeqnarraydefcol{R}{\hfil$\EWTECeqnarraymathstyle{}}{{}$}
% text
\EWTECeqnarraydefcol{s}{\EWTECeqnarraytextstyle}{\hfil}
\EWTECeqnarraydefcol{t}{\hfil\EWTECeqnarraytextstyle}{\hfil}
\EWTECeqnarraydefcol{u}{\hfil\EWTECeqnarraytextstyle}{}

% vertical rules
\EWTECeqnarraydefcol{v}{}{\vrule width\arrayrulewidth}
\EWTECeqnarraydefcol{vv}{\vrule width\arrayrulewidth\hfil}{\hfil\vrule width\arrayrulewidth}
\EWTECeqnarraydefcol{V}{}{\vrule width\arrayrulewidth\hskip\doublerulesep\vrule width\arrayrulewidth}
\EWTECeqnarraydefcol{VV}{\vrule width\arrayrulewidth\hskip\doublerulesep\vrule width\arrayrulewidth\hfil}%
{\hfil\vrule width\arrayrulewidth\hskip\doublerulesep\vrule width\arrayrulewidth}

% horizontal rules
\EWTECeqnarraydefcol{h}{}{\leaders\hrule height\arrayrulewidth\hfil}
\EWTECeqnarraydefcol{H}{}{\leaders\vbox{\hrule width\arrayrulewidth\vskip\doublerulesep\hrule width\arrayrulewidth}\hfil}

% plain
\EWTECeqnarraydefcol{x}{}{}
\EWTECeqnarraydefcol{X}{$}{$}

% the default column type to use in the event a column type is not defined
\EWTECeqnarraydefcol{@EWTECdefault}{\hfil$\EWTECeqnarraymathstyle}{$\hfil}


% a zero tabskip (used for "-" col types)
\def\@EWTECeqnarraycolSEPzero{0pt plus 0pt minus 0pt}
% a centering tabskip (used for "+" col types)
\def\@EWTECeqnarraycolSEPcenter{1000pt plus 0pt minus 1000pt}

% top level default tabskip glues for the start, end, and inter-column
% may be reset within environments not always at the top level, e.g., \EWTECeqnarraybox
\edef\@EWTECeqnarraycolSEPdefaultstart{\@EWTECeqnarraycolSEPcenter}% default start glue
\edef\@EWTECeqnarraycolSEPdefaultend{\@EWTECeqnarraycolSEPcenter}% default end glue
\edef\@EWTECeqnarraycolSEPdefaultmid{\@EWTECeqnarraycolSEPzero}% default inter-column glue



% creates a vertical rule that extends from the bottom to the top a a cell
% Provided in case other packages redefine \vline some other way.
% usage: \EWTECeqnarrayvrule[rule thickness]
% If no argument is provided, \arrayrulewidth will be used for the rule thickness. 
\newcommand\EWTECeqnarrayvrule[1][\arrayrulewidth]{\vrule\@width#1\relax}

% creates a blank separator row
% usage: \EWTECeqnarrayseprow[separation length][font size commands]
% default is \EWTECeqnarrayseprow[0.25\normalbaselineskip][\relax]
% blank arguments inherit the default values
% uses \skip5 as a scratch register - calls \@EWTECeqnarraystrutsize which uses more scratch registers
\def\EWTECeqnarrayseprow{\relax\@ifnextchar[{\@EWTECeqnarrayseprow}{\@EWTECeqnarrayseprow[0.25\normalbaselineskip]}}
\def\@EWTECeqnarrayseprow[#1]{\relax\@ifnextchar[{\@@EWTECeqnarrayseprow[#1]}{\@@EWTECeqnarrayseprow[#1][\relax]}}
\def\@@EWTECeqnarrayseprow[#1][#2]{\def\@EWTECeqnarrayseprowARGONE{#1}%
\ifx\@EWTECeqnarrayseprowARGONE\@empty%
% get the skip value, based on the font commands
% use skip5 because \EWTECeqnarraystrutsize uses \skip0, \skip2, \skip3
% assign within a bogus box to confine the font changes
{\setbox0=\hbox{#2\relax\global\skip5=0.25\normalbaselineskip}}%
\else%
{\setbox0=\hbox{#2\relax\global\skip5=#1}}%
\fi%
\@EWTECeqnarrayhoptolastcolumn\EWTECeqnarraystrutsize{\skip5}{0pt}[\relax]\relax}

% creates a blank separator row, but omits all the column templates
% usage: \EWTECeqnarrayseprowcut[separation length][font size commands]
% default is \EWTECeqnarrayseprowcut[0.25\normalbaselineskip][\relax]
% blank arguments inherit the default values
% uses \skip5 as a scratch register - calls \@EWTECeqnarraystrutsize which uses more scratch registers
\def\EWTECeqnarrayseprowcut{\multispan{\@EWTECeqnnumcols}\relax% span all the cols
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\@ifnextchar[{\@EWTECeqnarrayseprowcut}{\@EWTECeqnarrayseprowcut[0.25\normalbaselineskip]}}
\def\@EWTECeqnarrayseprowcut[#1]{\relax\@ifnextchar[{\@@EWTECeqnarrayseprowcut[#1]}{\@@EWTECeqnarrayseprowcut[#1][\relax]}}
\def\@@EWTECeqnarrayseprowcut[#1][#2]{\def\@EWTECeqnarrayseprowARGONE{#1}%
\ifx\@EWTECeqnarrayseprowARGONE\@empty%
% get the skip value, based on the font commands
% use skip5 because \EWTECeqnarraystrutsize uses \skip0, \skip2, \skip3
% assign within a bogus box to confine the font changes
{\setbox0=\hbox{#2\relax\global\skip5=0.25\normalbaselineskip}}%
\else%
{\setbox0=\hbox{#2\relax\global\skip5=#1}}%
\fi%
\EWTECeqnarraystrutsize{\skip5}{0pt}[\relax]\relax}



% draws a single rule across all the columns optional
% argument determines the rule width, \arrayrulewidth is the default
% updates column counter as needed and turns off struts
% usage: \EWTECeqnarrayrulerow[rule line thickness]
\def\EWTECeqnarrayrulerow{\multispan{\@EWTECeqnnumcols}\relax% span all the cols
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\@ifnextchar[{\@EWTECeqnarrayrulerow}{\@EWTECeqnarrayrulerow[\arrayrulewidth]}}
\def\@EWTECeqnarrayrulerow[#1]{\leaders\hrule height#1\hfil\relax% put in our rule 
% turn off any struts
\EWTECeqnarraystrutsize{0pt}{0pt}[\relax]\relax}


% draws a double rule by using a single rule row, a separator row, and then
% another single rule row 
% first optional argument determines the rule thicknesses, \arrayrulewidth is the default
% second optional argument determines the rule spacing, \doublerulesep is the default
% usage: \EWTECeqnarraydblrulerow[rule line thickness][rule spacing]
\def\EWTECeqnarraydblrulerow{\multispan{\@EWTECeqnnumcols}\relax% span all the cols
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\@ifnextchar[{\@EWTECeqnarraydblrulerow}{\@EWTECeqnarraydblrulerow[\arrayrulewidth]}}
\def\@EWTECeqnarraydblrulerow[#1]{\relax\@ifnextchar[{\@@EWTECeqnarraydblrulerow[#1]}%
{\@@EWTECeqnarraydblrulerow[#1][\doublerulesep]}}
\def\@@EWTECeqnarraydblrulerow[#1][#2]{\def\@EWTECeqnarraydblrulerowARG{#1}%
% we allow the user to say \EWTECeqnarraydblrulerow[][]
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\@EWTECeqnarrayrulerow[\arrayrulewidth]%
\else%
\@EWTECeqnarrayrulerow[#1]\relax%
\fi%
\def\@EWTECeqnarraydblrulerowARG{#2}%
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\\\EWTECeqnarrayseprow[\doublerulesep][\relax]%
\else%
\\\EWTECeqnarrayseprow[#2][\relax]%
\fi%
\\\multispan{\@EWTECeqnnumcols}%
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\def\@EWTECeqnarraydblrulerowARG{#1}%
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\@EWTECeqnarrayrulerow[\arrayrulewidth]%
\else%
\@EWTECeqnarrayrulerow[#1]%
\fi%
}

% draws a double rule by using a single rule row, a separator (cutting) row, and then
% another single rule row 
% first optional argument determines the rule thicknesses, \arrayrulewidth is the default
% second optional argument determines the rule spacing, \doublerulesep is the default
% usage: \EWTECeqnarraydblrulerow[rule line thickness][rule spacing]
\def\EWTECeqnarraydblrulerowcut{\multispan{\@EWTECeqnnumcols}\relax% span all the cols
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\@ifnextchar[{\@EWTECeqnarraydblrulerowcut}{\@EWTECeqnarraydblrulerowcut[\arrayrulewidth]}}
\def\@EWTECeqnarraydblrulerowcut[#1]{\relax\@ifnextchar[{\@@EWTECeqnarraydblrulerowcut[#1]}%
{\@@EWTECeqnarraydblrulerowcut[#1][\doublerulesep]}}
\def\@@EWTECeqnarraydblrulerowcut[#1][#2]{\def\@EWTECeqnarraydblrulerowARG{#1}%
% we allow the user to say \EWTECeqnarraydblrulerow[][]
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\@EWTECeqnarrayrulerow[\arrayrulewidth]%
\else%
\@EWTECeqnarrayrulerow[#1]%
\fi%
\def\@EWTECeqnarraydblrulerowARG{#2}%
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\\\EWTECeqnarrayseprowcut[\doublerulesep][\relax]%
\else%
\\\EWTECeqnarrayseprowcut[#2][\relax]%
\fi%
\\\multispan{\@EWTECeqnnumcols}%
% advance column counter only if the EWTECeqnarray environment wants it
\if@advanceEWTECeqncolcnt\global\advance\@EWTECeqncolcnt by \@EWTECeqnnumcols\relax\fi%
\def\@EWTECeqnarraydblrulerowARG{#1}%
\ifx\@EWTECeqnarraydblrulerowARG\@empty%
\@EWTECeqnarrayrulerow[\arrayrulewidth]%
\else%
\@EWTECeqnarrayrulerow[#1]%
\fi%
}



% inserts a full row's worth of &'s
% relies on \@EWTECeqnnumcols to provide the correct number of columns
% uses \@EWTECtmptoksA, \count0 as scratch registers
\def\@EWTECeqnarrayhoptolastcolumn{\@EWTECtmptoksA={}\count0=1\relax%
\loop% add cols if the user did not use them all
\ifnum\count0<\@EWTECeqnnumcols\relax%
\@EWTECappendtoksA{&}%
\advance\count0 by 1\relax% update the col count
\repeat%
\the\@EWTECtmptoksA%execute the &'s
}



\newif\if@EWTECeqnarrayISinner % flag to indicate if we are within the lines
\@EWTECeqnarrayISinnerfalse    % of an EWTECeqnarray - after the EWTECeqnarraydecl

\edef\@EWTECeqnarrayTHEstrutheight{0pt} % height and depth of EWTECeqnarray struts
\edef\@EWTECeqnarrayTHEstrutdepth{0pt}

\edef\@EWTECeqnarrayTHEmasterstrutheight{0pt} % default height and depth of
\edef\@EWTECeqnarrayTHEmasterstrutdepth{0pt}  % struts within an EWTECeqnarray

\edef\@EWTECeqnarrayTHEmasterstrutHSAVE{0pt} % saved master strut height
\edef\@EWTECeqnarrayTHEmasterstrutDSAVE{0pt} % and depth

\newif\if@EWTECeqnarrayusemasterstrut % flag to indicate that the master strut value
\@EWTECeqnarrayusemasterstruttrue     % is to be used



% saves the strut height and depth of the master strut
\def\@EWTECeqnarraymasterstrutsave{\relax%
\expandafter\skip0=\@EWTECeqnarrayTHEmasterstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEmasterstrutdepth\relax%
% remove stretchability
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% save values
\edef\@EWTECeqnarrayTHEmasterstrutHSAVE{\the\dimen0}%
\edef\@EWTECeqnarrayTHEmasterstrutDSAVE{\the\dimen2}}

% restores the strut height and depth of the master strut
\def\@EWTECeqnarraymasterstrutrestore{\relax%
\expandafter\skip0=\@EWTECeqnarrayTHEmasterstrutHSAVE\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEmasterstrutDSAVE\relax%
% remove stretchability
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% restore values
\edef\@EWTECeqnarrayTHEmasterstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEmasterstrutdepth{\the\dimen2}}


% globally restores the strut height and depth to the 
% master values and sets the master strut flag to true
\def\@EWTECeqnarraystrutreset{\relax%
\expandafter\skip0=\@EWTECeqnarrayTHEmasterstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEmasterstrutdepth\relax%
% remove stretchability
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% restore values
\xdef\@EWTECeqnarrayTHEstrutheight{\the\dimen0}%
\xdef\@EWTECeqnarrayTHEstrutdepth{\the\dimen2}%
\global\@EWTECeqnarrayusemasterstruttrue}


% if the master strut is not to be used, make the current
% values of \@EWTECeqnarrayTHEstrutheight, \@EWTECeqnarrayTHEstrutdepth
% and the use master strut flag, global
% this allows user strut commands issued in the last column to be carried
% into the isolation/strut column
\def\@EWTECeqnarrayglobalizestrutstatus{\relax%
\if@EWTECeqnarrayusemasterstrut\else%
\xdef\@EWTECeqnarrayTHEstrutheight{\@EWTECeqnarrayTHEstrutheight}%
\xdef\@EWTECeqnarrayTHEstrutdepth{\@EWTECeqnarrayTHEstrutdepth}%
\global\@EWTECeqnarrayusemasterstrutfalse%
\fi}



% usage: \EWTECeqnarraystrutsize{height}{depth}[font size commands]
% If called outside the lines of an EWTECeqnarray, sets the height
% and depth of both the master and local struts. If called inside
% an EWTECeqnarray line, sets the height and depth of the local strut
% only and sets the flag to indicate the use of the local strut
% values. If the height or depth is left blank, 0.7\normalbaselineskip
% and 0.3\normalbaselineskip will be used, respectively.
% The optional argument can be used to evaluate the lengths under
% a different font size and styles. If none is specified, the current
% font is used.
% uses scratch registers \skip0, \skip2, \skip3, \dimen0, \dimen2
\def\EWTECeqnarraystrutsize#1#2{\relax\@ifnextchar[{\@EWTECeqnarraystrutsize{#1}{#2}}{\@EWTECeqnarraystrutsize{#1}{#2}[\relax]}}
\def\@EWTECeqnarraystrutsize#1#2[#3]{\def\@EWTECeqnarraystrutsizeARG{#1}%
\ifx\@EWTECeqnarraystrutsizeARG\@empty%
{\setbox0=\hbox{#3\relax\global\skip3=0.7\normalbaselineskip}}%
\skip0=\skip3\relax%
\else% arg one present
{\setbox0=\hbox{#3\relax\global\skip3=#1\relax}}%
\skip0=\skip3\relax%
\fi% if null arg
\def\@EWTECeqnarraystrutsizeARG{#2}%
\ifx\@EWTECeqnarraystrutsizeARG\@empty%
{\setbox0=\hbox{#3\relax\global\skip3=0.3\normalbaselineskip}}%
\skip2=\skip3\relax%
\else% arg two present
{\setbox0=\hbox{#3\relax\global\skip3=#2\relax}}%
\skip2=\skip3\relax%
\fi% if null arg
% remove stretchability, just to be safe
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% dimen0 = height, dimen2 = depth
\if@EWTECeqnarrayISinner% inner does not touch master strut size
\edef\@EWTECeqnarrayTHEstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEstrutdepth{\the\dimen2}%
\@EWTECeqnarrayusemasterstrutfalse% do not use master
\else% outer, have to set master strut too
\edef\@EWTECeqnarrayTHEmasterstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEmasterstrutdepth{\the\dimen2}%
\edef\@EWTECeqnarrayTHEstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEstrutdepth{\the\dimen2}%
\@EWTECeqnarrayusemasterstruttrue% use master strut
\fi}


% usage: \EWTECeqnarraystrutsizeadd{added height}{added depth}[font size commands]
% If called outside the lines of an EWTECeqnarray, adds the given height
% and depth to both the master and local struts.
% If called inside an EWTECeqnarray line, adds the given height and depth
% to the local strut only and sets the flag to indicate the use 
% of the local strut values.
% In both cases, if a height or depth is left blank, 0pt is used instead.
% The optional argument can be used to evaluate the lengths under
% a different font size and styles. If none is specified, the current
% font is used.
% uses scratch registers \skip0, \skip2, \skip3, \dimen0, \dimen2
\def\EWTECeqnarraystrutsizeadd#1#2{\relax\@ifnextchar[{\@EWTECeqnarraystrutsizeadd{#1}{#2}}{\@EWTECeqnarraystrutsizeadd{#1}{#2}[\relax]}}
\def\@EWTECeqnarraystrutsizeadd#1#2[#3]{\def\@EWTECeqnarraystrutsizearg{#1}%
\ifx\@EWTECeqnarraystrutsizearg\@empty%
\skip0=0pt\relax%
\else% arg one present
{\setbox0=\hbox{#3\relax\global\skip3=#1}}%
\skip0=\skip3\relax%
\fi% if null arg
\def\@EWTECeqnarraystrutsizearg{#2}%
\ifx\@EWTECeqnarraystrutsizearg\@empty%
\skip2=0pt\relax%
\else% arg two present
{\setbox0=\hbox{#3\relax\global\skip3=#2}}%
\skip2=\skip3\relax%
\fi% if null arg
% remove stretchability, just to be safe
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% dimen0 = height, dimen2 = depth
\if@EWTECeqnarrayISinner% inner does not touch master strut size
% get local strut size
\expandafter\skip0=\@EWTECeqnarrayTHEstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEstrutdepth\relax%
% add it to the user supplied values
\advance\dimen0 by \skip0\relax%
\advance\dimen2 by \skip2\relax%
% update the local strut size
\edef\@EWTECeqnarrayTHEstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEstrutdepth{\the\dimen2}%
\@EWTECeqnarrayusemasterstrutfalse% do not use master
\else% outer, have to set master strut too
% get master strut size
\expandafter\skip0=\@EWTECeqnarrayTHEmasterstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEmasterstrutdepth\relax%
% add it to the user supplied values
\advance\dimen0 by \skip0\relax%
\advance\dimen2 by \skip2\relax%
% update the local and master strut sizes
\edef\@EWTECeqnarrayTHEmasterstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEmasterstrutdepth{\the\dimen2}%
\edef\@EWTECeqnarrayTHEstrutheight{\the\dimen0}%
\edef\@EWTECeqnarrayTHEstrutdepth{\the\dimen2}%
\@EWTECeqnarrayusemasterstruttrue% use master strut
\fi}


% allow user a way to see the struts
\newif\ifEWTECvisiblestruts
\EWTECvisiblestrutsfalse

% inserts an invisible strut using the master or local strut values
% uses scratch registers \skip0, \skip2, \dimen0, \dimen2
\def\@EWTECeqnarrayinsertstrut{\relax%
\if@EWTECeqnarrayusemasterstrut
% get master strut size
\expandafter\skip0=\@EWTECeqnarrayTHEmasterstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEmasterstrutdepth\relax%
\else%
% get local strut size
\expandafter\skip0=\@EWTECeqnarrayTHEstrutheight\relax%
\expandafter\skip2=\@EWTECeqnarrayTHEstrutdepth\relax%
\fi%
% remove stretchability, probably not needed
\dimen0\skip0\relax%
\dimen2\skip2\relax%
% dimen0 = height, dimen2 = depth
% allow user to see struts if desired
\ifEWTECvisiblestruts%
\vrule width0.2pt height\dimen0 depth\dimen2\relax%
\else%
\vrule width0pt height\dimen0 depth\dimen2\relax\fi}


% creates an invisible strut, useable even outside \EWTECeqnarray
% if \EWTECvisiblestrutstrue, the strut will be visible and 0.2pt wide. 
% usage: \EWTECstrut[height][depth][font size commands]
% default is \EWTECstrut[0.7\normalbaselineskip][0.3\normalbaselineskip][\relax]
% blank arguments inherit the default values
% uses \dimen0, \dimen2, \skip0, \skip2
\def\EWTECstrut{\relax\@ifnextchar[{\@EWTECstrut}{\@EWTECstrut[0.7\normalbaselineskip]}}
\def\@EWTECstrut[#1]{\relax\@ifnextchar[{\@@EWTECstrut[#1]}{\@@EWTECstrut[#1][0.3\normalbaselineskip]}}
\def\@@EWTECstrut[#1][#2]{\relax\@ifnextchar[{\@@@EWTECstrut[#1][#2]}{\@@@EWTECstrut[#1][#2][\relax]}}
\def\@@@EWTECstrut[#1][#2][#3]{\mbox{#3\relax%
\def\@EWTECstrutARG{#1}%
\ifx\@EWTECstrutARG\@empty%
\skip0=0.7\normalbaselineskip\relax%
\else%
\skip0=#1\relax%
\fi%
\def\@EWTECstrutARG{#2}%
\ifx\@EWTECstrutARG\@empty%
\skip2=0.3\normalbaselineskip\relax%
\else%
\skip2=#2\relax%
\fi%
% remove stretchability, probably not needed
\dimen0\skip0\relax%
\dimen2\skip2\relax%
\ifEWTECvisiblestruts%
\vrule width0.2pt height\dimen0 depth\dimen2\relax%
\else%
\vrule width0.0pt height\dimen0 depth\dimen2\relax\fi}}


% enables strut mode by setting a default strut size and then zeroing the
% \baselineskip, \lineskip, \lineskiplimit and \jot
\def\EWTECeqnarraystrutmode{\EWTECeqnarraystrutsize{0.7\normalbaselineskip}{0.3\normalbaselineskip}[\relax]%
\baselineskip=0pt\lineskip=0pt\lineskiplimit=0pt\jot=0pt}


% equation and subequation forms to use to setup hyperref's \@currentHref
\def\@EWTECtheHrefequation{equation.\theHequation}
\def\@EWTECtheHrefsubequation{equation.\theHequation\alph{EWTECsubequation}}


\def\EWTECeqnarray{\@EWTECeqnumpersisttrue\@EWTECsubeqnumpersistfalse\@EWTECeqnarray}
\def\endEWTECeqnarray{\end@EWTECeqnarray}

\@namedef{EWTECeqnarray*}{\@EWTECeqnumpersistfalse\@EWTECsubeqnumpersistfalse\@EWTECeqnarray}
\@namedef{endEWTECeqnarray*}{\end@EWTECeqnarray}


% \EWTECeqnarray is an enhanced \eqnarray. 
% The star form defaults to not putting equation numbers at the end of each row.
% usage: \EWTECeqnarray[decl]{cols}
\def\@EWTECeqnarray{\relax\@ifnextchar[{\@@EWTECeqnarray}{\@@EWTECeqnarray[\relax]}}
% We have to be careful here to normalize catcodes just before acquiring the
% cols as that specification may contain punctuation which could be subject
% to document catcode changes.
\def\@@EWTECeqnarray[#1]{\begingroup\EWTECnormalcatcodes\@@@EWTECeqnarray[#1]}
\def\@@@EWTECeqnarray[#1]#2{\endgroup
   % default to showing the equation number or not based on whether or not
   % the star form was involked
   \if@EWTECeqnumpersist\global\@eqnswtrue
   \else% not the star form
   \global\@eqnswfalse
   \fi% if star form
   % provide a basic hyperref \theHequation if this has not already been setup (hyperref not loaded, or no section counter)
   \@ifundefined{theHequation}{\def\theHequation{\arabic{equation}}}{}\relax
   % provide dummy hyperref commands in case hyperref is not loaded
   \providecommand{\Hy@raisedlink}[1]{}\relax
   \providecommand{\hyper@anchorstart}[1]{}\relax
   \providecommand{\hyper@anchorend}{}\relax
   \providecommand{\@currentHref}{}\relax
   \@EWTECeqnumpreadvfalse% reset eqnpreadv flag
   \@EWTECsubeqnumpreadvfalse% reset subeqnpreadv flag
   \@EWTECeqnarrayISinnerfalse% not yet within the lines of the halign
   \@EWTECeqnarraystrutsize{0pt}{0pt}[\relax]% turn off struts by default
   \@EWTECeqnarrayusemasterstruttrue% use master strut till user asks otherwise
   \EWTECvisiblestrutsfalse% diagnostic mode defaults to off
   % no extra space unless the user specifically requests it
   \lineskip=0pt\relax
   \lineskiplimit=0pt\relax
   \baselineskip=\normalbaselineskip\relax%
   \jot=\EWTECnormaljot\relax%
   \mathsurround\z@\relax% no extra spacing around math
   \@advanceEWTECeqncolcnttrue% advance the col counter for each col the user uses, 
                             % used in \EWTECeqnarraymulticol and in the preamble build
   %v1.0 Here we preadvance to the next equation number.
   % If the user later wants a continued subequation, we can roll back.
   \global\@EWTECsubeqnnumrollback=\c@EWTECsubequation%
   \stepcounter{equation}\@EWTECeqnumpreadvtrue% advance equation counter before first line
   \setcounter{EWTECsubequation}{0}% no subequation yet
   \let\@EWTECcurrentlabelsave\@currentlabel% save current label as we later change it globally
   \let\@EWTECcurrentHrefsave\@currentHref% save current href label as we later change it globally
   \def\@currentlabel{\p@equation\theequation}% redefine the ref label
   \def\@currentHref{\@EWTECtheHrefequation}% setup hyperref label
   \EWTECeqnarraydecl\relax% allow a way for the user to make global overrides
   #1\relax% allow user to override defaults
   \let\\\@EWTECeqnarraycr% replace newline with one that can put in eqn. numbers
   \global\@EWTECeqncolcnt\z@% col. count = 0 for first line
   \@EWTECbuildpreamble{#2}\relax% build the preamble and put it into \@EWTECtmptoksA 
   % put in the column for the equation number
   \ifnum\@EWTECeqnnumcols>0\relax\@EWTECappendtoksA{&}\fi% col separator for those after the first
   \toks0={##}%
   % advance the \@EWTECeqncolcnt for the isolation col, this helps with error checking
   \@EWTECappendtoksA{\global\advance\@EWTECeqncolcnt by 1\relax}%
   % add the isolation column
   \@EWTECappendtoksA{\tabskip\z@skip\bgroup\the\toks0\egroup}%
   % advance the \@EWTECeqncolcnt for the equation number col, this helps with error checking
   \@EWTECappendtoksA{&\global\advance\@EWTECeqncolcnt by 1\relax}%
   % add the equation number col to the preamble
   \@EWTECappendtoksA{\tabskip\z@skip\hb@xt@\z@\bgroup\hss\the\toks0\egroup}%
   % note \@EWTECeqnnumcols does not count the equation col or isolation col
   % set the starting tabskip glue as determined by the preamble build
   \tabskip=\@EWTECBPstartglue\relax
   % begin the display alignment
   \@EWTECeqnarrayISinnertrue% commands are now within the lines
   $$\everycr{}\halign to\displaywidth\bgroup
   % "exspand" the preamble
   \span\the\@EWTECtmptoksA\cr}

% enter isolation/strut column (or the next column if the user did not use
% every column), record the strut status, complete the columns, do the strut if needed,
% restore counters (to backout any equation setup for a next line that was never used)
% to their correct values and exit
\def\end@EWTECeqnarray{\@EWTECeqnarrayglobalizestrutstatus&\@@EWTECeqnarraycr\egroup
\if@EWTECsubeqnumpreadv\global\advance\c@EWTECsubequation\m@ne\fi
\if@EWTECeqnumpreadv\global\advance\c@equation\m@ne\global\c@EWTECsubequation=\@EWTECsubeqnnumrollback\fi
\global\let\@currentlabel\@EWTECcurrentlabelsave% restore current label
\global\let\@currentHref\@EWTECcurrentHrefsave% restore current href label
$$\@ignoretrue}


% EWTECeqnarray uses a modifed \\ instead of the plain \cr to
% end rows. This allows for things like \\*[vskip amount]
% These "cr" macros are modified versions of those for LaTeX2e's eqnarray
% the {\ifnum0=`} braces must be kept away from the last column to avoid
% altering spacing of its math, so we use & to advance to the next column
% as there is an isolation/strut column after the user's columns
\def\@EWTECeqnarraycr{\@EWTECeqnarrayglobalizestrutstatus&% save strut status and advance to next column
   {\ifnum0=`}\fi
   \@ifstar{%
      \global\@eqpen\@M\@EWTECeqnarrayYCR
   }{%
      \global\@eqpen\interdisplaylinepenalty \@EWTECeqnarrayYCR
   }%
}

\def\@EWTECeqnarrayYCR{\@testopt\@EWTECeqnarrayXCR\z@skip}

\def\@EWTECeqnarrayXCR[#1]{%
   \ifnum0=`{\fi}%
   \@@EWTECeqnarraycr
   \noalign{\penalty\@eqpen\vskip\jot\vskip #1\relax}}%

\def\@@EWTECeqnarraycr{\@EWTECtmptoksA={}% clear token register
    \advance\@EWTECeqncolcnt by -1\relax% adjust col count because of the isolation column
    \ifnum\@EWTECeqncolcnt>\@EWTECeqnnumcols\relax
    \@EWTECclspkgerror{Too many columns within the EWTECeqnarray\MessageBreak
                          environment}%
    {Use fewer \string &'s or put more columns in the EWTECeqnarray column\MessageBreak 
     specifications.}\relax%
    \else
    \loop% add cols if the user did not use them all
    \ifnum\@EWTECeqncolcnt<\@EWTECeqnnumcols\relax
    \@EWTECappendtoksA{&}%
    \advance\@EWTECeqncolcnt by 1\relax% update the col count
    \repeat
    % this number of &'s will take us the the isolation column
    \fi
    % execute the &'s
    \the\@EWTECtmptoksA%
    % handle the strut/isolation column
    \@EWTECeqnarrayinsertstrut% do the strut if needed
    \@EWTECeqnarraystrutreset% reset the strut system for next line or EWTECeqnarray
    &% and enter the equation number column
    \if@eqnsw% only if we display something
      \Hy@raisedlink{\hyper@anchorstart{\@currentHref}}% start a hyperref anchor
      \global\@EWTECeqnumpreadvfalse\relax% displaying an equation number means
      \global\@EWTECsubeqnumpreadvfalse\relax% the equation counters point to valid equations
      % v1.0 Here we setup the counters, currentlabel and status for what would be the *next*
      % equation line as would be the case under the current settings. However, there are two problems.
      % One problem is that there might not ever be a next line. The second problem is that the user
      % may later alter the meaning of a line with commands such as \EWTECyessubnumber. So, to handle
      % these cases we have to record the current values of the (sub)equation counters and revert back
      % to them if the next line is changed or never comes. The \if@EWTECeqnumpreadv, \if@EWTECsubeqnumpreadv
      % and \@EWTECsubeqnnumrollback stuff tracks this.
      % The logic to handle all this is surprisingly complex, but a nice feature of the approach here is
      % that the equation counters and labels remain valid for what the line would be unless a
      % \EWTECyessubnumber et al. later changes it. So, any hyperref links are always correct.
      \ifnum\c@EWTECsubequation>0\relax% handle subequation
         \theEWTECsubequationdis\relax
         \if@EWTECsubeqnumpersist% setup for default type of next line
            \stepcounter{EWTECsubequation}\global\@EWTECsubeqnumpreadvtrue\relax
            \gdef\@currentlabel{\p@EWTECsubequation\theEWTECsubequation}\relax
            \gdef\@currentHref{\@EWTECtheHrefsubequation}% setup hyperref label
         \else
             % if no subeqnum persist, go ahead and setup for a new equation number
             \global\@EWTECsubeqnnumrollback=\c@EWTECsubequation
             \stepcounter{equation}\global\@EWTECeqnumpreadvtrue\relax
             \setcounter{EWTECsubequation}{0}\gdef\@currentlabel{\p@equation\theequation}\relax
             \gdef\@currentHref{\@EWTECtheHrefequation}% setup hyperref label
         \fi
      \else% display a standard equation number
        \theequationdis\relax
        \setcounter{EWTECsubequation}{0}\relax% not really needed
        \if@EWTECsubeqnumpersist% setup for default type of next line
           % subequations that follow plain equations carry the same equation number e.g, 5, 5a rather than 5, 6a
           \stepcounter{EWTECsubequation}\global\@EWTECsubeqnumpreadvtrue\relax
           \gdef\@currentlabel{\p@EWTECsubequation\theEWTECsubequation}\relax
           \gdef\@currentHref{\@EWTECtheHrefsubequation}% setup hyperref label
         \else
             % if no subeqnum persist, go ahead and setup for a new equation number
             \global\@EWTECsubeqnnumrollback=\c@EWTECsubequation
             \stepcounter{equation}\global\@EWTECeqnumpreadvtrue\relax
             \setcounter{EWTECsubequation}{0}\gdef\@currentlabel{\p@equation\theequation}\relax
             \gdef\@currentHref{\@EWTECtheHrefequation}% setup hyperref label
         \fi
      \fi%
      \Hy@raisedlink{\hyper@anchorend}% end hyperref anchor
    \fi% fi only if we display something
    % reset the flags to indicate the default preferences of the display of equation numbers
    \if@EWTECeqnumpersist\global\@eqnswtrue\else\global\@eqnswfalse\fi
    \if@EWTECsubeqnumpersist\global\@eqnswtrue\fi% ditto for the subequation flag
    % reset the number of columns the user actually used
    \global\@EWTECeqncolcnt\z@\relax
    % the real end of the line
    \cr}





% \EWTECeqnarraybox is like \EWTECeqnarray except the box form puts everything
% inside a vtop, vbox, or vcenter box depending on the letter in the second
% optional argument (t,b,c). Vbox is the default. Unlike \EWTECeqnarray,
% equation numbers are not displayed and \EWTECeqnarraybox can be nested.
% \EWTECeqnarrayboxm is for math mode (like \array) and does not put the vbox
% within an hbox.
% \EWTECeqnarrayboxt is for text mode (like \tabular) and puts the vbox within
% a \hbox{$ $} construct.
% \EWTECeqnarraybox will auto detect whether to use \EWTECeqnarrayboxm or 
% \EWTECeqnarrayboxt depending on the math mode.
% The third optional argument specifies the width this box is to be set to -
% natural width is the default.
% The * forms do not add \jot line spacing
% usage: \EWTECeqnarraybox[decl][pos][width]{cols}
\def\EWTECeqnarrayboxm{\@EWTECeqnarrayboxnojotfalse\@EWTECeqnarrayboxHBOXSWfalse\@EWTECeqnarraybox}
\def\endEWTECeqnarrayboxm{\end@EWTECeqnarraybox}
\@namedef{EWTECeqnarrayboxm*}{\@EWTECeqnarrayboxnojottrue\@EWTECeqnarrayboxHBOXSWfalse\@EWTECeqnarraybox}
\@namedef{endEWTECeqnarrayboxm*}{\end@EWTECeqnarraybox}

\def\EWTECeqnarrayboxt{\@EWTECeqnarrayboxnojotfalse\@EWTECeqnarrayboxHBOXSWtrue\@EWTECeqnarraybox}
\def\endEWTECeqnarrayboxt{\end@EWTECeqnarraybox}
\@namedef{EWTECeqnarrayboxt*}{\@EWTECeqnarrayboxnojottrue\@EWTECeqnarrayboxHBOXSWtrue\@EWTECeqnarraybox}
\@namedef{endEWTECeqnarrayboxt*}{\end@EWTECeqnarraybox}

\def\EWTECeqnarraybox{\@EWTECeqnarrayboxnojotfalse\ifmmode\@EWTECeqnarrayboxHBOXSWfalse\else\@EWTECeqnarrayboxHBOXSWtrue\fi%
\@EWTECeqnarraybox}
\def\endEWTECeqnarraybox{\end@EWTECeqnarraybox}

\@namedef{EWTECeqnarraybox*}{\@EWTECeqnarrayboxnojottrue\ifmmode\@EWTECeqnarrayboxHBOXSWfalse\else\@EWTECeqnarrayboxHBOXSWtrue\fi%
\@EWTECeqnarraybox}
\@namedef{endEWTECeqnarraybox*}{\end@EWTECeqnarraybox}

% flag to indicate if the \EWTECeqnarraybox needs to put things into an hbox{$ $} 
% for \vcenter in non-math mode
\newif\if@EWTECeqnarrayboxHBOXSW%
\@EWTECeqnarrayboxHBOXSWfalse

\def\@EWTECeqnarraybox{\relax\@ifnextchar[{\@@EWTECeqnarraybox}{\@@EWTECeqnarraybox[\relax]}}
% We have to be careful here to normalize catcodes just before acquiring the
% cols as that specification may contain punctuation which could be subject
% to document catcode changes.
\def\@@EWTECeqnarraybox[#1]{\relax\begingroup\EWTECnormalcatcodes\@ifnextchar[{\@@@EWTECeqnarraybox[#1]}{\@@@EWTECeqnarraybox[#1][b]}}
\def\@@@EWTECeqnarraybox[#1][#2]{\relax\@ifnextchar[{\@@@@EWTECeqnarraybox[#1][#2]}{\@@@@EWTECeqnarraybox[#1][#2][\relax]}}

% #1 = decl; #2 = t,b,c; #3 = width, #4 = col specs
\def\@@@@EWTECeqnarraybox[#1][#2][#3]#4{\endgroup\@EWTECeqnarrayISinnerfalse % not yet within the lines of the halign
   \@EWTECeqnarraymasterstrutsave% save current master strut values
   \@EWTECeqnarraystrutsize{0pt}{0pt}[\relax]% turn off struts by default
   \@EWTECeqnarrayusemasterstruttrue% use master strut till user asks otherwise
   \EWTECvisiblestrutsfalse% diagnostic mode defaults to off
   % no extra space unless the user specifically requests it
   \lineskip=0pt\relax%
   \lineskiplimit=0pt\relax%
   \baselineskip=\normalbaselineskip\relax%
   \jot=\EWTECnormaljot\relax%
   \mathsurround\z@\relax% no extra spacing around math
   % the default end glues are zero for an \EWTECeqnarraybox
   \edef\@EWTECeqnarraycolSEPdefaultstart{\@EWTECeqnarraycolSEPzero}% default start glue
   \edef\@EWTECeqnarraycolSEPdefaultend{\@EWTECeqnarraycolSEPzero}% default end glue
   \edef\@EWTECeqnarraycolSEPdefaultmid{\@EWTECeqnarraycolSEPzero}% default inter-column glue
   \@advanceEWTECeqncolcntfalse% do not advance the col counter for each col the user uses, 
                              % used in \EWTECeqnarraymulticol and in the preamble build
   \EWTECeqnarrayboxdecl\relax% allow a way for the user to make global overrides
   #1\relax% allow user to override defaults
   \let\\\@EWTECeqnarrayboxcr% replace newline with one that allows optional spacing
   \@EWTECbuildpreamble{#4}\relax% build the preamble and put it into \@EWTECtmptoksA
   % add an isolation column to the preamble to stop \\'s {} from getting into the last col
   \ifnum\@EWTECeqnnumcols>0\relax\@EWTECappendtoksA{&}\fi% col separator for those after the first
   \toks0={##}%
   % add the isolation column to the preamble
   \@EWTECappendtoksA{\tabskip\z@skip\bgroup\the\toks0\egroup}% 
   % set the starting tabskip glue as determined by the preamble build
   \tabskip=\@EWTECBPstartglue\relax
   % begin the alignment
   \everycr{}%
   % use only the very first token to determine the positioning
   \@EWTECextracttoken{#2}\relax
   \ifx\@EWTECextractedtokensdiscarded\@empty\else
     \typeout{** WARNING: EWTECeqnarraybox position specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
   \fi
   % \@EWTECextractedtoken has the first token, the rest are ignored
   % if we need to put things into and hbox and go into math mode, do so now
   \if@EWTECeqnarrayboxHBOXSW \leavevmode \hbox \bgroup $\fi%
   % use the appropriate vbox type
   \if\@EWTECextractedtoken t\relax\vtop\else\if\@EWTECextractedtoken c\relax%
   \vcenter\else\vbox\fi\fi\bgroup%
   \@EWTECeqnarrayISinnertrue% commands are now within the lines
   \ifx#3\relax\halign\else\halign to #3\relax\fi%
   \bgroup
   % "exspand" the preamble
   \span\the\@EWTECtmptoksA\cr}

% carry strut status and enter the isolation/strut column, 
% exit from math mode if needed, and exit
\def\end@EWTECeqnarraybox{\@EWTECeqnarrayglobalizestrutstatus% carry strut status
&% enter isolation/strut column
\@EWTECeqnarrayinsertstrut% do strut if needed
\@EWTECeqnarraymasterstrutrestore% restore the previous master strut values
% reset the strut system for next EWTECeqnarray
% (sets local strut values back to previous master strut values)
\@EWTECeqnarraystrutreset%
% ensure last line, exit from halign, close vbox
\crcr\egroup\egroup%
% exit from math mode and close hbox if needed
\if@EWTECeqnarrayboxHBOXSW $\egroup\fi}



% EWTECeqnarraybox uses a modifed \\ instead of the plain \cr to
% end rows. This allows for things like \\[vskip amount]
% This "cr" macros are modified versions those for LaTeX2e's eqnarray
% For EWTECeqnarraybox, \\* is the same as \\
% the {\ifnum0=`} braces must be kept away from the last column to avoid
% altering spacing of its math, so we use & to advance to the isolation/strut column
% carry strut status into isolation/strut column
\def\@EWTECeqnarrayboxcr{\@EWTECeqnarrayglobalizestrutstatus% carry strut status
&% enter isolation/strut column
\@EWTECeqnarrayinsertstrut% do strut if needed
% reset the strut system for next line or EWTECeqnarray
\@EWTECeqnarraystrutreset%
{\ifnum0=`}\fi%
\@ifstar{\@EWTECeqnarrayboxYCR}{\@EWTECeqnarrayboxYCR}}

% test and setup the optional argument to \\[]
\def\@EWTECeqnarrayboxYCR{\@testopt\@EWTECeqnarrayboxXCR\z@skip}

% EWTECeqnarraybox does not automatically increase line spacing by \jot
\def\@EWTECeqnarrayboxXCR[#1]{\ifnum0=`{\fi}%
\cr\noalign{\if@EWTECeqnarrayboxnojot\else\vskip\jot\fi\vskip#1\relax}}



% usage: \@EWTECbuildpreamble{column specifiers}
% starts the halign preamble build 
% the assembled preamble is put in \@EWTECtmptoksA
\def\@EWTECbuildpreamble#1{\@EWTECtmptoksA={}% clear token register
\let\@EWTECBPcurtype=u%current column type is not yet known
\let\@EWTECBPprevtype=s%the previous column type was the start
\let\@EWTECBPnexttype=u%next column type is not yet known
% ensure these are valid
\def\@EWTECBPcurglue={0pt plus 0pt minus 0pt}%
\def\@EWTECBPcurcolname{@EWTECdefault}% name of current column definition
% currently acquired numerically referenced glue
% use a name that is easier to remember
\let\@EWTECBPcurnum=\@EWTECtmpcountA%
\@EWTECBPcurnum=0%
% tracks number of columns in the preamble
\@EWTECeqnnumcols=0%
% record the default end glues
\edef\@EWTECBPstartglue{\@EWTECeqnarraycolSEPdefaultstart}%
\edef\@EWTECBPendglue{\@EWTECeqnarraycolSEPdefaultend}%
\edef\@EWTECedefMACRO{#1}\relax% fully expand the preamble to support macro containers
% now parse the user's column specifications
% \ignorespaces is used as a delimiter, need at least one trailing \relax because
% \@@EWTECbuildpreamble looks into the future 
\expandafter\@@EWTECbuildpreamble\@EWTECedefMACRO\ignorespaces\relax\relax}


% usage: \@@EWTECbuildpreamble{current column}{next column}
% parses and builds the halign preamble
\def\@@EWTECbuildpreamble#1#2{\let\@@nextEWTECbuildpreamble=\@@EWTECbuildpreamble%
% use only the very first token to check the end
\@EWTECextracttokengroups{#1}\relax
\ifx\@EWTECextractedfirsttoken\ignorespaces\let\@@nextEWTECbuildpreamble=\@@EWTECfinishpreamble\else%
% identify current and next token type
\@EWTECgetcoltype{#1}{\@EWTECBPcurtype}{1}% current, error on invalid
\@EWTECgetcoltype{#2}{\@EWTECBPnexttype}{0}% next, no error on invalid next
% if curtype is a glue, get the glue def
\if\@EWTECBPcurtype g\@EWTECgetcurglue{#1}{\@EWTECBPcurglue}\fi%
% if curtype is a column, get the column def and set the current column name
\if\@EWTECBPcurtype c\@EWTECgetcurcol{#1}\fi%
% if curtype is a numeral, acquire the user defined glue
\if\@EWTECBPcurtype n\@EWTECprocessNcol{#1}\fi%
% process the acquired glue 
\if\@EWTECBPcurtype g\@EWTECprocessGcol\fi%
% process the acquired col 
\if\@EWTECBPcurtype c\@EWTECprocessCcol\fi%
% ready prevtype for next col spec.
\let\@EWTECBPprevtype=\@EWTECBPcurtype%
% be sure and put back the future token(s) as a group
\fi\@@nextEWTECbuildpreamble{#2}}


% usage: \@@EWTECfinishpreamble{discarded}
% executed just after preamble build is completed
% warn about zero cols, and if prevtype type = u, put in end tabskip glue
% argument is not used
\def\@@EWTECfinishpreamble#1{\ifnum\@EWTECeqnnumcols<1\relax
\@EWTECclspkgerror{No column specifiers declared for EWTECeqnarray}%
{At least one column type must be declared for each EWTECeqnarray.}%
\fi%num cols less than 1
%if last type undefined, set default end tabskip glue
\if\@EWTECBPprevtype u\@EWTECappendtoksA{\tabskip=\@EWTECBPendglue}\fi}


% usage: \@EWTECgetcoltype{col specifier}{\output}{error more}
% Identify and return the column specifier's type code in the given
% \output macro:
% n = number
% g = glue (any other char in catagory 12)
% c = letter
% e = \ignorespaces (end of sequence)
% u = undefined
% error mode: 0 = no error message, 1 = error on invalid char
\def\@EWTECgetcoltype#1#2#3{%
% use only the very first token to determine the type
\@EWTECextracttoken{#1}\relax
% \@EWTECextractedtoken has the first token, the rest are discarded
\let#2=u\relax% assume invalid until know otherwise
\ifx\@EWTECextractedtoken\ignorespaces\let#2=e\else
\ifcat\@EWTECextractedtoken\relax\else% screen out control sequences
\if0\@EWTECextractedtoken\let#2=n\else
\if1\@EWTECextractedtoken\let#2=n\else
\if2\@EWTECextractedtoken\let#2=n\else
\if3\@EWTECextractedtoken\let#2=n\else
\if4\@EWTECextractedtoken\let#2=n\else
\if5\@EWTECextractedtoken\let#2=n\else
\if6\@EWTECextractedtoken\let#2=n\else
\if7\@EWTECextractedtoken\let#2=n\else
\if8\@EWTECextractedtoken\let#2=n\else
\if9\@EWTECextractedtoken\let#2=n\else
\ifcat,\@EWTECextractedtoken\let#2=g\relax
\else\ifcat a\@EWTECextractedtoken\let#2=c\relax\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi
\if#2u\relax
\if0\noexpand#3\relax\else\@EWTECclspkgerror{Invalid character in column specifications}%
{Only letters, numerals and certain other symbols are allowed \MessageBreak
as EWTECeqnarray column specifiers.}\fi\fi}


% usage: \@EWTECgetcurcol{col specifier}
% verify the letter referenced column exists
% and return its name in \@EWTECBPcurcolname
% if column specifier is invalid, use the default column @EWTECdefault
\def\@EWTECgetcurcol#1{\expandafter\ifx\csname @EWTECeqnarraycolDEF#1\endcsname\@EWTECeqnarraycolisdefined%
\def\@EWTECBPcurcolname{#1}\else% invalid column name
\@EWTECclspkgerror{Invalid column type "#1" in column specifications.\MessageBreak
Using a default centering column instead}%
{You must define EWTECeqnarray column types before use.}%
\def\@EWTECBPcurcolname{@EWTECdefault}\fi}


% usage: \@EWTECgetcurglue{glue specifier}{\output}
% identify the predefined (punctuation) glue value
% and return it in the given output macro
\def\@EWTECgetcurglue#1#2{%
% ! = \! (neg small)  -0.16667em (-3/18 em)
% , = \, (small)       0.16667em ( 3/18 em)
% : = \: (med)         0.22222em ( 4/18 em)
% ; = \; (large)       0.27778em ( 5/18 em)
% ' = \quad            1em
% " = \qquad           2em
% . = 0.5\arraycolsep
% / = \arraycolsep
% ? = 2\arraycolsep
% * = 1fil
% + = \@EWTECeqnarraycolSEPcenter
% - = \@EWTECeqnarraycolSEPzero
% Note that all em values are referenced to the math font (textfont2) fontdimen6
% value for 1em.
% 
% use only the very first token to determine the type
\@EWTECextracttoken{#1}\relax
\ifx\@EWTECextractedtokensdiscarded\@empty\else
  \typeout{** WARNING: EWTECeqnarray predefined inter-column glue type specifiers after the first in `\@EWTECextracttokenarg' ignored (line \the\inputlineno).}\relax
\fi
% get the math font 1em value
% LaTeX2e's NFSS2 does not preload the fonts, but \EWTECeqnarray needs
% to gain access to the math (\textfont2) font's spacing parameters.
% So we create a bogus box here that uses the math font to ensure
% that \textfont2 is loaded and ready. If this is not done,
% the \textfont2 stuff here may not work.
% Thanks to Bernd Raichle for his 1997 post on this topic.
{\setbox0=\hbox{$\displaystyle\relax$}}%
% fontdimen6 has the width of 1em (a quad).
\@EWTECtmpdimenA=\fontdimen6\textfont2\relax%
% identify the glue value based on the first token
% we discard anything after the first
\if!\@EWTECextractedtoken\@EWTECtmpdimenA=-0.16667\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if,\@EWTECextractedtoken\@EWTECtmpdimenA=0.16667\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if:\@EWTECextractedtoken\@EWTECtmpdimenA=0.22222\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if;\@EWTECextractedtoken\@EWTECtmpdimenA=0.27778\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if'\@EWTECextractedtoken\@EWTECtmpdimenA=1\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if"\@EWTECextractedtoken\@EWTECtmpdimenA=2\@EWTECtmpdimenA\edef#2{\the\@EWTECtmpdimenA}\else
\if.\@EWTECextractedtoken\@EWTECtmpdimenA=0.5\arraycolsep\edef#2{\the\@EWTECtmpdimenA}\else
\if/\@EWTECextractedtoken\edef#2{\the\arraycolsep}\else
\if?\@EWTECextractedtoken\@EWTECtmpdimenA=2\arraycolsep\edef#2{\the\@EWTECtmpdimenA}\else
\if *\@EWTECextractedtoken\edef#2{0pt plus 1fil minus 0pt}\else
\if+\@EWTECextractedtoken\edef#2{\@EWTECeqnarraycolSEPcenter}\else
\if-\@EWTECextractedtoken\edef#2{\@EWTECeqnarraycolSEPzero}\else
\edef#2{\@EWTECeqnarraycolSEPzero}%
\@EWTECclspkgerror{Invalid predefined inter-column glue type "#1" in\MessageBreak
column specifications. Using a default value of\MessageBreak
0pt instead}%
{Only !,:;'"./?*+ and - are valid predefined glue types in the\MessageBreak 
EWTECeqnarray column specifications.}\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi\fi}


% usage: \@EWTECprocessNcol{digit}
% process a numerical digit from the column specification
% and look up the corresponding user defined glue value
% can sform current type from n to g or a as the user defined glue is acquired
\def\@EWTECprocessNcol#1{\if\@EWTECBPprevtype g%
\@EWTECclspkgerror{Back-to-back inter-column glue specifiers in column\MessageBreak
specifications. Ignoring consecutive glue specifiers\MessageBreak
after the first}%
{You cannot have two or more glue types next to each other\MessageBreak 
in the EWTECeqnarray column specifications.}%
\let\@EWTECBPcurtype=a% abort this glue, future digits will be discarded
\@EWTECBPcurnum=0\relax%
\else% if we previously aborted a glue
\if\@EWTECBPprevtype a\@EWTECBPcurnum=0\let\@EWTECBPcurtype=a%maintain digit abortion
\else%acquire this number
% save the previous type before the numerical digits started
\if\@EWTECBPprevtype n\else\let\@EWTECBPprevsavedtype=\@EWTECBPprevtype\fi%
\multiply\@EWTECBPcurnum by 10\relax%
\advance\@EWTECBPcurnum by #1\relax% add in number, \relax is needed to stop TeX's number scan
\if\@EWTECBPnexttype n\else%close acquisition
\expandafter\ifx\csname @EWTECeqnarraycolSEPDEF\expandafter\romannumeral\number\@EWTECBPcurnum\endcsname\@EWTECeqnarraycolisdefined%
\edef\@EWTECBPcurglue{\csname @EWTECeqnarraycolSEP\expandafter\romannumeral\number\@EWTECBPcurnum\endcsname}%
\else%user glue not defined
\@EWTECclspkgerror{Invalid user defined inter-column glue type "\number\@EWTECBPcurnum" in\MessageBreak
column specifications. Using a default value of\MessageBreak
0pt instead}%
{You must define all EWTECeqnarray numerical inter-column glue types via\MessageBreak
\string\EWTECeqnarraydefcolsep \space before they are used in column specifications.}%
\edef\@EWTECBPcurglue{\@EWTECeqnarraycolSEPzero}%
\fi% glue defined or not
\let\@EWTECBPcurtype=g% change the type to reflect the acquired glue
\let\@EWTECBPprevtype=\@EWTECBPprevsavedtype% restore the prev type before this number glue
\@EWTECBPcurnum=0\relax%ready for next acquisition
\fi%close acquisition, get glue
\fi%discard or acquire number
\fi%prevtype glue or not
}


% process an acquired glue
% add any acquired column/glue pair to the preamble
\def\@EWTECprocessGcol{\if\@EWTECBPprevtype a\let\@EWTECBPcurtype=a%maintain previous glue abortions
\else
% if this is the start glue, save it, but do nothing else 
% as this is not used in the preamble, but before
\if\@EWTECBPprevtype s\edef\@EWTECBPstartglue{\@EWTECBPcurglue}%
\else%not the start glue
\if\@EWTECBPprevtype g%ignore if back to back glues
\@EWTECclspkgerror{Back-to-back inter-column glue specifiers in column\MessageBreak
specifications. Ignoring consecutive glue specifiers\MessageBreak
after the first}%
{You cannot have two or more glue types next to each other\MessageBreak 
in the EWTECeqnarray column specifications.}%
\let\@EWTECBPcurtype=a% abort this glue
\else% not a back to back glue
\if\@EWTECBPprevtype c\relax% if the previoustype was a col, add column/glue pair to preamble
\ifnum\@EWTECeqnnumcols>0\relax\@EWTECappendtoksA{&}\fi
\toks0={##}%
% make preamble advance col counter if this environment needs this
\if@advanceEWTECeqncolcnt\@EWTECappendtoksA{\global\advance\@EWTECeqncolcnt by 1\relax}\fi
% insert the column defintion into the preamble, being careful not to expand
% the column definition
\@EWTECappendtoksA{\tabskip=\@EWTECBPcurglue}%
\@EWTECappendNOEXPANDtoksA{\begingroup\csname @EWTECeqnarraycolPRE}%
\@EWTECappendtoksA{\@EWTECBPcurcolname}%
\@EWTECappendNOEXPANDtoksA{\endcsname}%
\@EWTECappendtoksA{\the\toks0}%
\@EWTECappendNOEXPANDtoksA{\relax\relax\relax\relax\relax%
\relax\relax\relax\relax\relax\csname @EWTECeqnarraycolPOST}%
\@EWTECappendtoksA{\@EWTECBPcurcolname}%
\@EWTECappendNOEXPANDtoksA{\endcsname\relax\relax\relax\relax\relax%
\relax\relax\relax\relax\relax\endgroup}%
\advance\@EWTECeqnnumcols by 1\relax%one more column in the preamble
\else% error: non-start glue with no pending column
\@EWTECclspkgerror{Inter-column glue specifier without a prior column\MessageBreak
type in the column specifications. Ignoring this glue\MessageBreak 
specifier}%
{Except for the first and last positions, glue can be placed only\MessageBreak
between column types.}%
\let\@EWTECBPcurtype=a% abort this glue
\fi% previous was a column
\fi% back-to-back glues
\fi% is start column glue
\fi% prev type not a
}


% process an acquired letter referenced column and, if necessary, add it to the preamble
\def\@EWTECprocessCcol{\if\@EWTECBPnexttype g\else
\if\@EWTECBPnexttype n\else
% we have a column followed by something other than a glue (or numeral glue)
% so we must add this column to the preamble now
\ifnum\@EWTECeqnnumcols>0\relax\@EWTECappendtoksA{&}\fi%col separator for those after the first
\if\@EWTECBPnexttype e\@EWTECappendtoksA{\tabskip=\@EWTECBPendglue\relax}\else%put in end glue
\@EWTECappendtoksA{\tabskip=\@EWTECeqnarraycolSEPdefaultmid\relax}\fi% or default mid glue
\toks0={##}%
% make preamble advance col counter if this environment needs this
\if@advanceEWTECeqncolcnt\@EWTECappendtoksA{\global\advance\@EWTECeqncolcnt by 1\relax}\fi
% insert the column definition into the preamble, being careful not to expand
% the column definition
\@EWTECappendNOEXPANDtoksA{\begingroup\csname @EWTECeqnarraycolPRE}%
\@EWTECappendtoksA{\@EWTECBPcurcolname}%
\@EWTECappendNOEXPANDtoksA{\endcsname}%
\@EWTECappendtoksA{\the\toks0}%
\@EWTECappendNOEXPANDtoksA{\relax\relax\relax\relax\relax%
\relax\relax\relax\relax\relax\csname @EWTECeqnarraycolPOST}%
\@EWTECappendtoksA{\@EWTECBPcurcolname}%
\@EWTECappendNOEXPANDtoksA{\endcsname\relax\relax\relax\relax\relax%
\relax\relax\relax\relax\relax\endgroup}%
\advance\@EWTECeqnnumcols by 1\relax%one more column in the preamble
\fi%next type not numeral
\fi%next type not glue
}


%%
%% END OF EWTECeqnarray DEFINITIONS
%%





% set up the running headers and footers
%
% header and footer font and size specifications
\def\@EWTECheaderstyle{\normalfont\scriptsize}
\def\@EWTECfooterstyle{\normalfont\scriptsize}
%



% standard page style, ps@headings
\def\ps@headings{% default to standard twoside headers, no footers
% will change later if the mode requires otherwise
\def\@oddhead{\hbox{}\@EWTECheaderstyle\rightmark\hfil\thepage}\relax
\def\@evenhead{\@EWTECheaderstyle\thepage\hfil\leftmark\hbox{}}\relax
\let\@oddfoot\@empty
\let\@evenfoot\@empty

\ifCLASSOPTIONdraftcls
  % draft footers
  \def\@oddfoot{\@EWTECfooterstyle\@date\hfil DRAFT}\relax
  \def\@evenfoot{\@EWTECfooterstyle DRAFT\hfil\@date}\relax
\fi
% oneside
\if@twoside\else
  % standard one side headers
  \def\@oddhead{\hbox{}\@EWTECheaderstyle\leftmark\hfil\thepage}\relax
  \let\@evenhead\@empty
  \ifCLASSOPTIONdraftcls
    % oneside draft footers
    \def\@oddfoot{\@EWTECfooterstyle\@date\hfil DRAFT}\relax
    \let\@evenfoot\@empty
  \fi
\fi

% turn off footers for draftclsnofoot
\ifCLASSOPTIONdraftclsnofoot
  \let\@oddfoot\@empty
  \let\@evenfoot\@empty
\fi}


% title page style, ps@EWTECtitlepagestyle
\def\ps@EWTECtitlepagestyle{% default title page headers, no footers
\def\@oddhead{\hbox{}\@EWTECheaderstyle\leftmark\hfil\thepage}\relax
\def\@evenhead{\@EWTECheaderstyle\thepage\hfil\leftmark\hbox{}}\relax
\let\@oddfoot\@empty
\let\@evenfoot\@empty
% will change later if the mode requires otherwise
\ifCLASSOPTIONdraftcls
  % draft footers
  \ifCLASSOPTIONdraftclsnofoot\else
    % but only if not draftclsnofoot
    \def\@oddfoot{\@EWTECfooterstyle\@date\hfil DRAFT}\relax
    \def\@evenfoot{\@EWTECfooterstyle DRAFT\hfil\@date}\relax
  \fi
\else
  % all nondraft mode footers
  \if@EWTECusingpubid
    % for title pages that are using a pubid
    % do not repeat pubid on the title page if using a peer review cover page
    \ifCLASSOPTIONpeerreview\else
      % for noncompsoc papers, the pubid uses footnotesize and
      % is at the same vertical position as where the last baseline would normally be
      \def\@oddfoot{\hbox{}\hss\@EWTECfooterstyle\footnotesize\raisebox{\footskip}[0pt][0pt]{\@EWTECpubid}\hss\hbox{}}\relax
      \def\@evenfoot{\hbox{}\hss\@EWTECfooterstyle\footnotesize\raisebox{\footskip}[0pt][0pt]{\@EWTECpubid}\hss\hbox{}}\relax
      
    \fi
  \fi
\fi

}


% peer review cover page style, ps@EWTECpeerreviewcoverpagestyle
\def\ps@EWTECpeerreviewcoverpagestyle{% default peer review cover no headers, no footers
\let\@oddhead\@empty
\let\@evenhead\@empty
\let\@oddfoot\@empty
\let\@evenfoot\@empty
% will change later if the mode requires otherwise
\ifCLASSOPTIONdraftcls
  % draft footers
  \ifCLASSOPTIONdraftclsnofoot\else
    % but only if not draftclsnofoot
    \def\@oddfoot{\@EWTECfooterstyle\@date\hfil DRAFT}\relax
    \def\@evenfoot{\@EWTECfooterstyle DRAFT\hfil\@date}\relax
  \fi
\else
  % all nondraft mode footers
  \if@EWTECusingpubid
    % for peer review cover pages that are using a pubid
    % for noncompsoc papers, the pubid uses footnotesize and
    % is at the same vertical position as where the last baseline would normally be
    \def\@oddfoot{\hbox{}\hss\@EWTECfooterstyle\footnotesize\raisebox{\footskip}[0pt][0pt]{\@EWTECpubid}\hss\hbox{}}\relax
    \def\@evenfoot{\hbox{}\hss\@EWTECfooterstyle\footnotesize\raisebox{\footskip}[0pt][0pt]{\@EWTECpubid}\hss\hbox{}}\relax
    %
  \fi
\fi}



%% Defines the command for putting the header.
%% Note that all the text is forced into uppercase, if you have some text
%% that needs to be in lower case, for instance et. al., then either manually
%% set \leftmark and \rightmark or use \MakeLowercase{et. al.} within the
%% arguments to \markboth.
%% v1.0b add \protect to work with Babel
\def\markboth#1#2{\def\leftmark{\MakeUppercase{\protect#1}}%
\def\rightmark{\MakeUppercase{\protect#2}}}

\def\today{\ifcase\month\or
    January\or February\or March\or April\or May\or June\or
    July\or August\or September\or October\or November\or December\fi
    \space\number\day, \number\year}




%% CITATION AND BIBLIOGRAPHY COMMANDS
% 
% Modify Latex2e \@citex to separate citations with "], ["
\def\@citex[#1]#2{%
  \let\@citea\@empty
  \@cite{\@for\@citeb:=#2\do
    {\@citea\def\@citea{], [}%
     \edef\@citeb{\expandafter\@firstofone\@citeb\@empty}%
     \if@filesw\immediate\write\@auxout{\string\citation{\@citeb}}\fi
     \@ifundefined{b@\@citeb}{\mbox{\reset@font\bfseries ?}%
       \G@refundefinedtrue
       \@latex@warning
         {Citation `\@citeb' on page \thepage \space undefined}}%
       {\hbox{\csname b@\@citeb\endcsname}}}}{#1}}

% v1.0 we create hooks for the optional use of Donald Arseneau's
% cite.sty package. cite.sty is "smart" and will notice that the
% following format controls are already defined and will not
% redefine them. The result will be the proper sorting of the
% citation numbers and auto detection of 3 or more entry "ranges" -
% all in EWTEC style:  [1], [2], [5]--[7], [12]
% This also allows for an optional note, i.e., \cite[mynote]{..}.
% If the \cite with note has more than one reference, the note will
% be applied to the last of the listed references. It is generally
% desired that if a note is given, only one reference is listed in
% that \cite.
% Thanks to Mr. Arseneau for providing the required format arguments
% to produce the EWTEC style.
\def\citepunct{], [}
\def\citedash{]--[}

% v1.0 default to using same font for urls made by url.sty
\AtBeginDocument{\csname url@samestyle\endcsname}

% v1.0 class files should always provide these
\def\newblock{\hskip .11em\@plus.33em\@minus.07em}
\let\@openbib@code\@empty
% v1.0b article.cls is now providing these too
% we do not use \@mkboth, nor alter the page style
\newenvironment{theindex}
               {\if@twocolumn
                  \@restonecolfalse
                \else
                  \@restonecoltrue
                \fi
                \twocolumn[\section*{\indexname}]%
                \parindent\z@
                \parskip\z@ \@plus .3\p@\relax
                \columnseprule \z@
                \columnsep 35\p@
                \let\item\@idxitem}
               {\if@restonecol\onecolumn\else\clearpage\fi}
\newcommand\@idxitem{\par\hangindent 40\p@}
\newcommand\subitem{\@idxitem \hspace*{20\p@}}
\newcommand\subsubitem{\@idxitem \hspace*{30\p@}}
\newcommand\indexspace{\par \vskip 10\p@ \@plus5\p@ \@minus3\p@\relax}



% Provide support for the control entries of EWTEC.bst V1.00 and later.
% v1.0 optional argument allows for a different aux file to be specified in
% order to handle multiple bibliographies. For example, with multibib.sty:
% \newcites{sec}{Secondary Literature}
% \bstctlcite[@auxoutsec]{BSTcontrolhak}
\def\bstctlcite{\@ifnextchar[{\@bstctlcite}{\@bstctlcite[@auxout]}}
\def\@bstctlcite[#1]#2{\@bsphack
  \@for\@citeb:=#2\do{%
    \edef\@citeb{\expandafter\@firstofone\@citeb}%
    \if@filesw\immediate\write\csname #1\endcsname{\string\citation{\@citeb}}\fi}%
  \@esphack}

% \EWTECnoauxwrite{} allows for citations that do not add to or affect
% the order of the existing citation list. Can be useful for \cite
% within \thanks{}.
\DeclareRobustCommand{\EWTECnoauxwrite}[1]{\relax
\if@filesw
\@fileswfalse
#1\relax\relax\relax\relax\relax
\@fileswtrue
\else
#1\relax\relax\relax\relax\relax
\fi}

% v1.0 provide a way for a user to execute a command just before 
% a given reference number - used to insert a \newpage to balance
% the columns on the last page
\edef\@EWTECtriggerrefnum{0}   % the default of zero means that
                              % the command is not executed
\def\@EWTECtriggercmd{\newpage}

% allow the user to alter the triggered command
\long\def\EWTECtriggercmd#1{\long\def\@EWTECtriggercmd{#1}}

% allow user a way to specify the reference number just before the
% command is executed
\def\EWTECtriggeratref#1{\@EWTECtmpcountA=#1%
\edef\@EWTECtriggerrefnum{\the\@EWTECtmpcountA}}%

% trigger command at the given reference
\def\@EWTECbibitemprefix{\@EWTECtmpcountA=\@EWTECtriggerrefnum\relax%
\advance\@EWTECtmpcountA by -1\relax%
\ifnum\c@enumiv=\@EWTECtmpcountA\relax\@EWTECtriggercmd\relax\fi}


\def\@biblabel#1{[#1]}


% controls bib item spacing
\def\EWTECbibitemsep{0pt plus .5pt}



\def\thebibliography#1{\section*{\refname}%
    \addcontentsline{toc}{section}{\refname}%
    % v1.0 add some rubber space here and provide a command trigger
    \footnotesize\vskip 0.3\baselineskip plus 0.1\baselineskip minus 0.1\baselineskip%
    \list{\@biblabel{\@arabic\c@enumiv}}%
    {\settowidth\labelwidth{\@biblabel{#1}}%
    \leftmargin\labelwidth
    \advance\leftmargin\labelsep\relax
    \itemsep \EWTECbibitemsep\relax
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \renewcommand\theenumiv{\@arabic\c@enumiv}}%
    \let\@EWTEClatexbibitem\bibitem%
    \def\bibitem{\@EWTECbibitemprefix\@EWTEClatexbibitem}%
\def\newblock{\hskip .11em plus .33em minus .07em}%
% originally:
%   \sloppy\clubpenalty4000\widowpenalty4000%
% by adding the \interlinepenalty here, we make it more
% difficult, but not impossible, for LaTeX to break within a reference.
% The EWTEC almost never breaks a reference (but they do it more often with
% technotes). You may get an underfull vbox warning around the bibliography, 
% but the final result will be much more like what the EWTEC will publish. 
% MDS 11/2000
\sloppy\clubpenalty4000\widowpenalty4000\interlinepenalty500%
    \sfcode`\.=1000\relax}
\let\endthebibliography=\endlist




% TITLE PAGE COMMANDS
% 


% \EWTECauthorrefmark{} produces a footnote type symbol to indicate author affiliation.
% When given an argument of 1 to 9, \EWTECauthorrefmark{} follows the standard LaTeX footnote
% symbol sequence convention. However, for arguments 10 and above, \EWTECauthorrefmark{} 
% reverts to using lower case roman numerals, so it cannot overflow. Do note that you 
% cannot use \footnotemark[] in place of \EWTECauthorrefmark{} within \author as the footnote
% symbols will have been turned off to prevent \thanks from creating footnote marks.
% \EWTECauthorrefmark{} produces a symbol that appears to LaTeX as having zero vertical
% height - this allows for a more compact line packing, but the user must ensure that
% the interline spacing is large enough to prevent \EWTECauthorrefmark{} from colliding
% with the text above.
% v1.0 make this a robust command
% v1.0 smag uses an arabic author affiliation symbol

\DeclareRobustCommand*{\EWTECauthorrefmark}[1]{\raisebox{0pt}[0pt][0pt]{\textsuperscript{\footnotesize\ensuremath{\ifcase#1\or *\or \dagger\or \ddagger\or%
    \mathsection\or \mathparagraph\or \|\or **\or \dagger\dagger%
    \or \ddagger\ddagger \else\textsuperscript{\expandafter\romannumeral#1}\fi}}}}



% FONT CONTROLS AND SPACINGS FOR CONFERENCE MODE AUTHOR NAME AND AFFILIATION BLOCKS
% 
% The default font styles for the author name and affiliation blocks (confmode)
\def\@EWTECauthorblockNstyle{\normalfont\sublargesize}
\def\@EWTECauthorblockAstyle{\normalfont\normalsize}
% The default if the user does not use an author block
\def\@EWTECauthordefaulttextstyle{\normalfont\sublargesize}

% adjustment spacing from title (or special paper notice) to author name blocks (confmode)
% can be negative
\def\@EWTECauthorblockconfadjspace{-0.25em}


% spacing between name and affiliation blocks (confmode)
% This can be negative.
% The EWTEC doesn't want any added spacing here, but I will leave these
% controls in place in case they ever change their mind.
% Personally, I like 0.75ex.
%\def\@EWTECauthorblockNtopspace{0.75ex}
%\def\@EWTECauthorblockAtopspace{0.75ex}
\def\@EWTECauthorblockNtopspace{0.0ex}
\def\@EWTECauthorblockAtopspace{0.0ex}


% baseline spacing within name and affiliation blocks (confmode)
% must be positive, spacings below certain values will make 
% the position of line of text sensitive to the contents of the
% line above it i.e., whether or not the prior line has descenders, 
% subscripts, etc. For this reason it is a good idea to keep
% these above 2.6ex
\def\@EWTECauthorblockNinterlinespace{2.6ex}
\def\@EWTECauthorblockAinterlinespace{2.75ex}

% This tracks the required strut size.
% See the \@EWTECauthorhalign command for the actual default value used.
\def\@EWTECauthorblockXinterlinespace{2.7ex}

% variables to retain font size and style across groups
% values given here have no effect as they will be overwritten later
\gdef\@EWTECSAVESTATEfontsize{10}
\gdef\@EWTECSAVESTATEfontbaselineskip{12}
\gdef\@EWTECSAVESTATEfontencoding{OT1}
\gdef\@EWTECSAVESTATEfontfamily{ptm}
\gdef\@EWTECSAVESTATEfontseries{m}
\gdef\@EWTECSAVESTATEfontshape{n}

% saves the current font attributes
\def\@EWTECcurfontSAVE{\global\let\@EWTECSAVESTATEfontsize\f@size%
\global\let\@EWTECSAVESTATEfontbaselineskip\f@baselineskip%
\global\let\@EWTECSAVESTATEfontencoding\f@encoding%
\global\let\@EWTECSAVESTATEfontfamily\f@family%
\global\let\@EWTECSAVESTATEfontseries\f@series%
\global\let\@EWTECSAVESTATEfontshape\f@shape}

% restores the saved font attributes
\def\@EWTECcurfontRESTORE{\fontsize{\@EWTECSAVESTATEfontsize}{\@EWTECSAVESTATEfontbaselineskip}%
\fontencoding{\@EWTECSAVESTATEfontencoding}%
\fontfamily{\@EWTECSAVESTATEfontfamily}%
\fontseries{\@EWTECSAVESTATEfontseries}%
\fontshape{\@EWTECSAVESTATEfontshape}%
\selectfont}


% variable to indicate if the current block is the first block in the column
\newif\if@EWTECprevauthorblockincol   \@EWTECprevauthorblockincolfalse


% the command places a strut with height and depth = \@EWTECauthorblockXinterlinespace
% we use this technique to have complete manual control over the spacing of the lines
% within the halign environment.
% We set the below baseline portion at 30%, the above
% baseline portion at 70% of the total length.
% Responds to changes in the document's \baselinestretch
\def\@EWTECauthorstrutrule{\@EWTECtmpdimenA\@EWTECauthorblockXinterlinespace%
\@EWTECtmpdimenA=\baselinestretch\@EWTECtmpdimenA%
\rule[-0.3\@EWTECtmpdimenA]{0pt}{\@EWTECtmpdimenA}}


% blocks to hold the authors' names and affilations. 
% Makes formatting easy for conferences
%
% use real definitions in conference mode
% name block
\def\EWTECauthorblockN#1{\relax\@EWTECauthorblockNstyle% set the default text style
\gdef\@EWTECauthorblockXinterlinespace{0pt}% disable strut for spacer row
% the \expandafter hides the \cr in conditional tex, see the array.sty docs
% for details, probably not needed here as the \cr is in a macro
% do a spacer row if needed
\if@EWTECprevauthorblockincol\expandafter\@EWTECauthorblockNtopspaceline\fi
\global\@EWTECprevauthorblockincoltrue% we now have a block in this column
%restore the correct strut value
\gdef\@EWTECauthorblockXinterlinespace{\@EWTECauthorblockNinterlinespace}%
% input the author names
#1%
% end the row if the user did not already
\crcr}
% spacer row for names
\def\@EWTECauthorblockNtopspaceline{\cr\noalign{\vskip\@EWTECauthorblockNtopspace}}
%
% affiliation block
\def\EWTECauthorblockA#1{\relax\@EWTECauthorblockAstyle% set the default text style
\gdef\@EWTECauthorblockXinterlinespace{0pt}%disable strut for spacer row
% the \expandafter hides the \cr in conditional tex, see the array.sty docs
% for details, probably not needed here as the \cr is in a macro
% do a spacer row if needed
\if@EWTECprevauthorblockincol\expandafter\@EWTECauthorblockAtopspaceline\fi
\global\@EWTECprevauthorblockincoltrue% we now have a block in this column
%restore the correct strut value
\gdef\@EWTECauthorblockXinterlinespace{\@EWTECauthorblockAinterlinespace}%
% input the author affiliations
#1%
% end the row if the user did not already
\crcr
}

% spacer row for affiliations
\def\@EWTECauthorblockAtopspaceline{\cr\noalign{\vskip\@EWTECauthorblockAtopspace}}


% allow papers to compile even if author blocks are used in modes other
% than conference or peerreviewca. For such cases, we provide dummy blocks.

   \ifCLASSOPTIONpeerreviewca\else
      % not peerreviewca mode
         \def\EWTECauthorblockN#1{#1}%
         \def\EWTECauthorblockA#1{#1}%
   \fi




% we provide our own halign so as not to have to depend on tabular
\def\@EWTECauthorhalign{\@EWTECauthordefaulttextstyle% default text style
   \lineskip=0pt\relax% disable line spacing
   \lineskiplimit=0pt\relax%
   \baselineskip=0pt\relax%
   \@EWTECcurfontSAVE% save the current font
   \mathsurround\z@\relax% no extra spacing around math
   \let\\\@EWTECauthorhaligncr% replace newline with halign friendly one
   \tabskip=0pt\relax% no column spacing
   \everycr{}% ensure no problems here
   \@EWTECprevauthorblockincolfalse% no author blocks yet
   \def\@EWTECauthorblockXinterlinespace{2.7ex}% default interline space
   \vtop\bgroup%vtop box
   \halign\bgroup&\relax\hfil\@EWTECcurfontRESTORE\relax ##\relax
   \hfil\@EWTECcurfontSAVE\@EWTECauthorstrutrule\cr}

% ensure last line, exit from halign, close vbox
\def\end@EWTECauthorhalign{\crcr\egroup\egroup}

% handle bogus star form
\def\@EWTECauthorhaligncr{{\ifnum0=`}\fi\@ifstar{\@@EWTECauthorhaligncr}{\@@EWTECauthorhaligncr}}

% test and setup the optional argument to \\[]
\def\@@EWTECauthorhaligncr{\@testopt\@@@EWTECauthorhaligncr\z@skip}

% end the line and do the optional spacer
\def\@@@EWTECauthorhaligncr[#1]{\ifnum0=`{\fi}\cr\noalign{\vskip#1\relax}}



% flag to prevent multiple \and warning messages
\newif\if@EWTECWARNand
\@EWTECWARNandtrue

% if in conference or peerreviewca modes, we support the use of \and as \author is a
% tabular environment, otherwise we warn the user that \and is invalid
% outside of conference or peerreviewca modes.
\def\and{\relax} % provide a bogus \and that we will then override

\renewcommand{\and}[1][\relax]{\if@EWTECWARNand\typeout{** WARNING: \noexpand\and is valid only
                               when in conference or peerreviewca}\typeout{modes (line \the\inputlineno).}\fi\global\@EWTECWARNandfalse}


\ifCLASSOPTIONpeerreviewca
\renewcommand{\and}[1][\hfill]{\end{@EWTECauthorhalign}#1\begin{@EWTECauthorhalign}}%
\fi


% page clearing command
% based on LaTeX2e's \cleardoublepage, but allows different page styles
% for the inserted blank pages
\def\@EWTECcleardoublepage#1{\clearpage\if@twoside\ifodd\c@page\else
\hbox{}\thispagestyle{#1}\newpage\if@twocolumn\hbox{}\thispagestyle{#1}\newpage\fi\fi\fi}

% v1.0b hooks to allow adjustment of space above title
\def\EWTECtitletopspace{0.5\baselineskip}
% an added extra amount to allow for adjustment/offset
\def\EWTECtitletopspaceextra{0pt}

% user command to invoke the title page
\def\maketitle{\par%
  \begingroup%
  \normalfont%
  \def\thefootnote{}%  the \thanks{} mark type is empty
  \def\footnotemark{}% and kill space from \thanks within author
  \let\@makefnmark\relax% v1.0, must *really* kill footnotemark to remove all \textsuperscript spacing as well.
  \footnotesize%       equal spacing between thanks lines
  \footnotesep 0.7\baselineskip%see global setting of \footnotesep for more info
  
  \normalsize%
  \ifCLASSOPTIONpeerreview
     \newpage\global\@topnum\z@ \@maketitle\@EWTECstatictitlevskip\@EWTECaftertitletext%
     \thispagestyle{EWTECpeerreviewcoverpagestyle}\@thanks%
  \else
     \if@twocolumn%
        
           \twocolumn[{\EWTECquantizevspace{\@maketitle}[\EWTECquantizedisabletitlecmds]{0pt}[-\topskip]{\baselineskip}{\@EWTECNORMtitlevspace}{\@EWTECMINtitlevspace}\@EWTECaftertitletext}]%
      
     \else
        \newpage\global\@topnum\z@ \@maketitle\@EWTECstatictitlevskip\@EWTECaftertitletext%
     \fi
     \thispagestyle{EWTECtitlepagestyle}\@thanks%
  \fi
  % pullup page for pubid if used.
  \if@EWTECusingpubid
     \enlargethispage{-\@EWTECpubidpullup}%
  \fi 
  \endgroup
  \setcounter{footnote}{0}\let\maketitle\relax\let\@maketitle\relax
  \gdef\@thanks{}%
  % v1.6b do not clear these as we will need the title again for peer review papers
  % \gdef\@author{}\gdef\@title{}%
  \let\thanks\relax}


% v1.0 parbox to format \@EWTECtitleabstractindextext
\long\def\@EWTECtitleabstractindextextbox#1{\parbox{1\textwidth}{#1}}


% formats the Title, authors names, affiliations and special paper notice
% THIS IS A CONTROLLED SPACING COMMAND! Do not allow blank lines or unintentional
% spaces to enter the definition - use % at the end of each line
\def\@maketitle{\newpage
\bgroup\par\vskip\EWTECtitletopspace\vskip\EWTECtitletopspaceextra\centering%
\vskip0.2em{\Huge\@title\par}\relax\vskip1.0em\par%
  % journal or peerreview
           {\lineskip.5em\sublargesize\@author\@EWTECspecialpapernotice\par
           }\relax
\par\addvspace{0.5\baselineskip}\egroup}




% v1.0 standard LateX2e \thanks, but with \itshape under compsoc. Also make it a \long\def
% We also need to trigger the one-shot footnote rule
\def\@EWTECtriggeroneshotfootnoterule{\global\@EWTECenableoneshotfootnoteruletrue}


\long\def\thanks#1{\footnotemark
    \protected@xdef\@thanks{\@thanks
        \protect\footnotetext[\the\c@footnote]{\ignorespaces#1}}}
\let\@thanks\@empty


% v1.0 allow \author to contain \par's. This is needed to allow \thanks to contain \par.
\long\def\author#1{\gdef\@author{#1}}


% in addition to setting up EWTECitemize, we need to remove a baselineskip space above and
% below it because \list's \pars introduce blank lines because of the footnote struts.
\def\@EWTECsetupcompsocitemizelist{\def\labelitemi{$\bullet$}%
\setlength{\EWTEClabelindent}{0pt}\setlength{\labelsep}{1.2em}\setlength{\parskip}{0pt}%
\setlength{\partopsep}{0pt}\setlength{\topsep}{0.5\baselineskip}\vspace{-1\baselineskip}\relax}


% flag for fake non-compsoc \EWTECcompsocthanksitem - prevents line break on very first item
\newif\if@EWTECbreakcompsocthanksitem \@EWTECbreakcompsocthanksitemfalse



% non-compsoc, allow for dual compilation via rerouting to normal \thanks
\long\def\EWTECcompsocitemizethanks#1{\thanks{#1}}
% redirect to "pseudo-par" \hfil\break\indent after swallowing [] from \EWTECcompsocthanksitem[]
\DeclareRobustCommand{\EWTECcompsocthanksitem}{\@ifnextchar [{\@EWTECthanksswallowoptionalarg}%
{\@EWTECthanksswallowoptionalarg[\relax]}}
% be sure and break only after first item, be sure and ignore spaces after optional argument
\def\@EWTECthanksswallowoptionalarg[#1]{\relax\if@EWTECbreakcompsocthanksitem\hfil\break
\indent\fi\@EWTECbreakcompsocthanksitemtrue\ignorespaces}



% v1.0b define the \EWTECpeerreviewmaketitle as needed
\ifCLASSOPTIONpeerreview
\def\EWTECpeerreviewmaketitle{\@EWTECcleardoublepage{empty}%
\ifCLASSOPTIONtwocolumn
\twocolumn[{\EWTECquantizevspace{\@EWTECpeerreviewmaketitle}[\EWTECquantizedisabletitlecmds]{0pt}[-\topskip]{\baselineskip}{\@EWTECNORMtitlevspace}{\@EWTECMINtitlevspace}}]
\else
\newpage\@EWTECpeerreviewmaketitle\@EWTECstatictitlevskip
\fi
\thispagestyle{EWTECtitlepagestyle}}
\else
% \EWTECpeerreviewmaketitle does nothing if peer review option has not been selected
\def\EWTECpeerreviewmaketitle{\relax}
\fi

% peerreview formats the repeated title like the title in journal papers.
\def\@EWTECpeerreviewmaketitle{\bgroup\par\addvspace{0.5\baselineskip}\centering%
\normalfont\normalsize\vskip0.2em{\Huge\@title\par}\vskip1.0em\par
\par\addvspace{0.5\baselineskip}\egroup}



% v1.0 
% this is a static rubber spacer between the title/authors and the main text
% used for single column text, or when the title appears in the first column
% of two column text (technotes). 
\def\@EWTECstatictitlevskip{{\normalfont\normalsize
% adjust spacing to next text
% v1.6b handle peer review papers
\ifCLASSOPTIONpeerreview
% for peer review papers, the same value is used for both title pages
% regardless of the other paper modes
   \vskip 1\baselineskip plus 0.375\baselineskip minus 0.1875\baselineskip
\else
         \vskip 2.5\baselineskip plus 0.75\baselineskip minus 0.375\baselineskip%
      \fi%
}}


% set the nominal and minimum values for the quantized title spacer
% the quantization algorithm will not allow the spacer size to
% become less than \@EWTECMINtitlevspace - instead it will be lengthened
% default to proceedings values
\def\@EWTECNORMtitlevspace{2.5\baselineskip}
\def\@EWTECMINtitlevspace{2\baselineskip}



% v1.0a
\def\EWTECquantizevspace{\begingroup\@ifstar{\@EWTECquantizevspacestarformtrue\@EWTECquantizevspace}{\@EWTECquantizevspacestarformfalse\@EWTECquantizevspace}}
% \EWTECquantizevspace[output dimen register]{object}[object decl]
%                    {top baselineskip}
%                    [offset][prevdepth][lineskip limit][lineskip]
%                    {unit height}{nominal vspace}{minimum vspace}
%
% Calculates and creates the vspace needed to make the combined height with
% the given object an integer multiple of the given unit height. This command
% is more general than the older \@EWTECdynamictitlevspace it replaces.
%
% The star form has no effect at present, but is reserved for future use.
%
% If the optional argument [output dimen register] is given, the calculated
% vspace height is stored in the given output dimen (or skip) register
% and no other action is taken, otherwise the object followed by a vspace*
% of the appropriate height is evaluated/output.
%
% The optional object decl (declarations) is code that is evaluated just
% before the object's height is evaluated. Its intented purpose is to allow
% for the alteration or disabling of code within the object during internal
% height evaluation (e.g., \long\def\thanks#1{\relax} ).
% This special code is not invoked if/when the object is rendered at the end.
%
% The nominal vspace is the target value of the added vspace and the minimum
% vspace is the lower allowed limit. The vspacer will be the value that achieves
% integral overall height, in terms of the given unit height, that is closest
% to the nominal vspace and that is not less than the specified minimum vspace.
%
% The line spacing algorithm of TeX is somewhat involved and requires special
% care with regard to the first line of a vertical list (which is indicated
% when \prevdepth is -1000pt or less). top baselineskip specifies the
% baselineskip or topskip used prior to the object. If the height of the
% first line of the object is greater than the given top baselineskip, then
% the top baselineskip is subtracted from the height of the first line and
% that difference is considered along with the rest of the object height
% (because the object will be shifted down by an amount = 
% top line height - top baselineskip). Otherwise, the height of the first line
% of the object is ignored as far as the calculations are concerned.
% This algorithm is adequate for objects that appear at the top of a page
% (e.g., titles) where \topskip spacing is used.
%
% However, as explained on page 78 of the TeXbook, interline spacing is more
% complex when \baselineskip is being used (indicated by \prevdepth > 
% -1000pt). The four optional parameters offset, prevdepth, lineskip limit and
% lineskip are assumed to be equal to be 0pt, \prevdepth, \lineskiplimit and
% \lineskip, respectively, if they are omitted.
%
% The prevdepth is the depth of the line before the object, the lineskip limit
% specifies how close the top of the object can come to the bottom of the
% previous line before \baselineskip is ignored and \lineskip is inserted
% between the object and the line above it. Lineskip does not come into
% play unless the first line of the object is high enough to "get too close"
% (as specified by lineskiplimit) to the line before it. The the prevdepth,
% lineskip limit, and lineskip optional parameters are not needed for the
% first object/line on a page (i.e., prevdepth <= -1000pt) where the simplier
% \topskip spacing rules are in effect.
%
% Offset is a manual adjustment that is added to the height calculations of
% object irrespective of the value of \prevdepth. It is useful when the top
% baselineskip will result in a noninteger unit height object placement even
% if the object itself has integral height. e.g., a footnotesize baselineskip
% is used before the object, thus an offset of, say -3pt, can be given as a
% correction.

% Common combinations of these parameters include:
%
% top baselineskip:   (and default values for offset, prevdepth, etc.)
% \topskip            % for objects that appear at the top of a page
% \maxdimen           % always ignore the height of the top line
% 0pt                 % always consider any positive height of the top line
%
% for objects to appear inline in normal text:
% top baselineskip = \baselineskip
%
% set prevdepth = -1000pt and top baselineskip = 0pt to consider the
% overall height of the object without any other external skip
% consideration

\newif\if@EWTECquantizevspacestarform       % flag to indicate star form
\newif\if@EWTECquantizevspaceuseoutdimenreg % flag to indicate output dimen register is to be used
% Use our own private registers because the object could contain a
% structure that uses the existing tmp scratch pad registers
\newdimen\@EWTECquantizeheightA
\newdimen\@EWTECquantizeheightB
\newdimen\@EWTECquantizeheightC
\newdimen\@EWTECquantizeprevdepth % need to save this early as can change
\newcount\@EWTECquantizemultiple
\newbox\@EWTECquantizeboxA


\def\@EWTECquantizevspace{\@ifnextchar [{\@EWTECquantizevspaceuseoutdimenregtrue\@@EWTECquantizevspace}{\@EWTECquantizevspaceuseoutdimenregfalse\@@EWTECquantizevspace[]}}


\long\def\@@EWTECquantizevspace[#1]#2{\relax
% acquire and store
% #1 optional output dimen register
% #2 object
\edef\@EWTECquantizeoutdimenreg{#1}\relax
% allow for object specifications that contain parameters
\@EWTECtmptoksA={#2}\relax
\long\edef\@EWTECquantizeobject{\the\@EWTECtmptoksA}\relax
\@ifnextchar [{\@@@EWTECquantizevspace}{\@@@EWTECquantizevspace[\relax]}}

\long\def\@@@EWTECquantizevspace[#1]#2{\relax
% acquire and store
% [#1] optional object decl, is \relax if not given by user
% #2 top baselineskip
% allow for object decl specifications that have parameters
\@EWTECtmptoksA={#1}\relax
\long\edef\@EWTECquantizeobjectdecl{\the\@EWTECtmptoksA}\relax
\edef\@EWTECquantizetopbaselineskip{#2}\ivEWTECquantizevspace}

% acquire optional argument set and store
% [offset][prevdepth][lineskip limit][lineskip]
\def\ivEWTECquantizevspace{\@ifnextchar [{\@vEWTECquantizevspace}{\@vEWTECquantizevspace[0pt]}}
\def\@vEWTECquantizevspace[#1]{\edef\@EWTECquantizeoffset{#1}\@ifnextchar [{\@viEWTECquantizevspace}{\@viEWTECquantizevspace[\prevdepth]}}
\def\@viEWTECquantizevspace[#1]{\@EWTECquantizeprevdepth=#1\relax\@ifnextchar [{\@viiEWTECquantizevspace}{\@viiEWTECquantizevspace[\lineskiplimit]}}
\def\@viiEWTECquantizevspace[#1]{\edef\@EWTECquantizelineskiplimit{#1}\@ifnextchar [{\@viiiEWTECquantizevspace}{\@viiiEWTECquantizevspace[\lineskip]}}
\def\@viiiEWTECquantizevspace[#1]{\edef\@EWTECquantizelineskip{#1}\@ixEWTECquantizevspace}

% main routine
\def\@ixEWTECquantizevspace#1#2#3{\relax
\edef\@EWTECquantizeunitheight{#1}\relax
\edef\@EWTECquantizenomvspace{#2}\relax
\edef\@EWTECquantizeminvspace{#3}\relax
% \@EWTECquantizeoutdimenreg
% \@EWTECquantizeobject
% \@EWTECquantizeobjectdecl
% \@EWTECquantizetopbaselineskip
% \@EWTECquantizeoffset
% \@EWTECquantizeprevdepth
% \@EWTECquantizelineskiplimit
% \@EWTECquantizelineskip
% \@EWTECquantizeunitheight
% \@EWTECquantizenomvspace
% \@EWTECquantizeminvspace
% get overall height of object
\setbox\@EWTECquantizeboxA\vbox{\begingroup\@EWTECquantizeobjectdecl\@EWTECquantizeobject\relax\endgroup}\relax
\@EWTECquantizeheightA\ht\@EWTECquantizeboxA\relax
% get height of first line of object
\setbox\@EWTECquantizeboxA\vtop{\begingroup\@EWTECquantizeobjectdecl\@EWTECquantizeobject\relax\endgroup}\relax
\@EWTECquantizeheightB\ht\@EWTECquantizeboxA\relax
\ifdim\@EWTECquantizeprevdepth>-1000pt\relax % prevdepth > -1000pf means full baselineskip\lineskip rules in effect
% lineskip spacing rule takes effect if height of top line > baselineskip - prevdepth - lineskiplimit, 
% otherwise the baselineskip rule is in effect and the height of the first line does not matter at all.
\@EWTECquantizeheightC=\@EWTECquantizetopbaselineskip\relax
\advance\@EWTECquantizeheightC-\@EWTECquantizeprevdepth\relax
\advance\@EWTECquantizeheightC-\@EWTECquantizelineskiplimit\relax % this works even though \@EWTECquantizelineskiplimit is a macro because TeX allows --10pt notation
\ifdim\@EWTECquantizeheightB>\@EWTECquantizeheightC\relax
% lineskip spacing rule is in effect i.e., the object is going to be shifted down relative to the
% baselineskip set position by its top line height (already a part of the total height) + prevdepth + lineskip - baselineskip
\advance\@EWTECquantizeheightA\@EWTECquantizeprevdepth\relax
\advance\@EWTECquantizeheightA\@EWTECquantizelineskip\relax
\advance\@EWTECquantizeheightA-\@EWTECquantizetopbaselineskip\relax
\else
% height of first line <= \@EWTECquantizetopbaselineskip - \@EWTECquantizeprevdepth - \@EWTECquantizelineskiplimit
% standard baselineskip rules are in effect, so don't consider height of first line
\advance\@EWTECquantizeheightA-\@EWTECquantizeheightB\relax
\fi
%
\else % prevdepth <= -1000pt, simplier \topskip type rules in effect
\ifdim\@EWTECquantizeheightB>\@EWTECquantizetopbaselineskip
% height of top line (already included in the total height) in excess of
% baselineskip is the amount it will be downshifted
\advance\@EWTECquantizeheightA-\@EWTECquantizetopbaselineskip\relax
\else
% height of first line is irrelevant, remove it
\advance\@EWTECquantizeheightA-\@EWTECquantizeheightB\relax
\fi
\fi % prevdepth <= -1000pt
%
% adjust height for any manual offset
\advance\@EWTECquantizeheightA\@EWTECquantizeoffset\relax
% add in nominal spacer
\advance\@EWTECquantizeheightA\@EWTECquantizenomvspace\relax
% check for nonzero unitheight
\@EWTECquantizeheightB=\@EWTECquantizeunitheight\relax
\ifnum\@EWTECquantizeheightB=0\relax
\@EWTECclspkgerror{EWTECquantizevspace unit height cannot be zero. Assuming 10pt.}%
{Division by zero is not allowed.}
\@EWTECquantizeheightB=10pt\relax
\fi
% get integer number of lines
\@EWTECquantizemultiple=\@EWTECquantizeheightA\relax
\divide\@EWTECquantizemultiple\@EWTECquantizeheightB\relax
% set A to contain the excess height over the \@EWTECquantizemultiple of lines
% A = height - multiple*unitheight
\@EWTECquantizeheightC\@EWTECquantizeheightB\relax
\multiply\@EWTECquantizeheightC\@EWTECquantizemultiple\relax
\advance\@EWTECquantizeheightA-\@EWTECquantizeheightC\relax
% set B to contain the height short of \@EWTECquantizemultiple+1 of lines
% B = unitheight - A
\advance\@EWTECquantizeheightB-\@EWTECquantizeheightA\relax
% choose A or B based on which is closer
\@EWTECquantizeheightC\@EWTECquantizenomvspace\relax
\ifdim\@EWTECquantizeheightA<\@EWTECquantizeheightB\relax
% C = nomvspace - A, go with lower
\advance\@EWTECquantizeheightC-\@EWTECquantizeheightA\relax
\else
% C = nomvspace + B, go with upper
\advance\@EWTECquantizeheightC\@EWTECquantizeheightB\relax
\fi
% if violate lower bound, use next integer bound
\ifdim\@EWTECquantizeheightC<\@EWTECquantizeminvspace\relax
% A + B = unitheight
\advance\@EWTECquantizeheightC\@EWTECquantizeheightA\relax
\advance\@EWTECquantizeheightC\@EWTECquantizeheightB\relax
\fi
% export object and spacer outside of group
\global\let\@EWTECquantizeobjectout\@EWTECquantizeobject\relax
\global\@EWTECquantizeheightC\@EWTECquantizeheightC\relax
\endgroup
\if@EWTECquantizevspaceuseoutdimenreg
\@EWTECquantizeoutdimenreg=\@EWTECquantizeheightC\relax
\else
\@EWTECquantizeobjectout\relax
\vskip\@EWTECquantizeheightC\relax
\fi}


% user command to disable all global assignments, possible use within object decl
\def\EWTECquantizedisableglobal{\let\global\relax
\let\gdef\def
\let\xdef\edef}
% user command to allow for the disabling of \thanks and other commands, possible use within object decl
\def\EWTECquantizedisabletitlecmds{\long\def\thanks##1{\relax}\relax
\long\def\EWTECcompsocitemizethanks##1{\relax}\def\newpage{\relax}}





% v1.0
% we allow the user access to the last part of the title area
% useful in emergencies such as when a different spacing is needed
% This text is NOT compensated for in the dynamic sizer.
\let\@EWTECaftertitletext=\relax
\long\def\EWTECaftertitletext#1{\def\@EWTECaftertitletext{#1}}


% v1.0 provide a way for users to enter abstract and keywords
% into the onecolumn title are. This text is compensated for
% in the dynamic sizer.
\let\@EWTECtitleabstractindextext=\relax
\long\def\EWTECtitleabstractindextext#1{\def\@EWTECtitleabstractindextext{#1}}

% v1.0 provide a way for users to get the \@EWTECtitleabstractindextext if
% not in compsoc or smag journal mode - this way abstract and keywords
% can still be placed in their conventional position if not in those modes.
\def\EWTECdisplaynontitleabstractindextext{%
               \@EWTECtitleabstractindextext\relax
      }


% command to allow alteration of baselinestretch, but only if the current
% baselineskip is unity. Used to tweak the compsoc abstract and keywords line spacing.
\def\@EWTECtweakunitybaselinestretch#1{{\def\baselinestretch{1}\selectfont
\global\@tempskipa\baselineskip}\ifnum\@tempskipa=\baselineskip%
\def\baselinestretch{#1}\selectfont\fi\relax}


% abstract and keywords are in \small, except 
% for 9pt docs in which they are in \footnotesize
% Because 9pt docs use an 8pt footnotesize, \small
% becomes a rather awkward 8.5pt
\def\@EWTECabskeysecsize{\small}
\ifx\CLASSOPTIONpt\@EWTECptsizenine
 \def\@EWTECabskeysecsize{\footnotesize}
\fi


% v1.0 have abstract and keywords strip leading spaces, pars and newlines
% so that spacing is more tightly controlled.
\def\abstract{\normalfont
    \if@twocolumn
      \@EWTECabskeysecsize\bfseries\textit{\abstractname}---\relax
    \else
      \bgroup\par\addvspace{0.5\baselineskip}\centering\vspace{-1.78ex}\@EWTECabskeysecsize\textbf{\abstractname}\par\addvspace{0.5\baselineskip}\egroup\quotation\@EWTECabskeysecsize
    \fi\@EWTECgobbleleadPARNLSP}
% v1.0 The EWTEC wants only 1 pica from end of abstract to introduction heading when in 
% conference mode (the heading already has this much above it)
\def\endabstract{\relax\vspace{1.34ex}\par\if@twocolumn\else\endquotation\fi
    \normalfont\normalsize}

\def\EWTECkeywords{\normalfont
    \if@twocolumn
      \@EWTECabskeysecsize\bfseries\textit{\EWTECkeywordsname}---\relax
    \else
      \bgroup\par\addvspace{0.5\baselineskip}\centering\@EWTECabskeysecsize\textbf{\EWTECkeywordsname}\par\addvspace{0.5\baselineskip}\egroup\quotation\@EWTECabskeysecsize
    \fi\@EWTECgobbleleadPARNLSP}
\def\endEWTECkeywords{\relax\vspace{0.67ex}
    \par\if@twocolumn\else\endquotation\fi%
    \normalfont\normalsize}





% gobbles all leading \, \\ and \par, upon finding first token that
% is not a \ , \\ or a \par, it ceases and returns that token
% 
% used to strip leading \, \\ and \par from the input
% so that such things in the beginning of an environment will not
% affect the formatting of the text
\long\def\@EWTECgobbleleadPARNLSP#1{\let\@EWTECswallowthistoken=0%
\let\@EWTECgobbleleadPARNLSPtoken#1%
\let\@EWTECgobbleleadPARtoken=\par%
\let\@EWTECgobbleleadNLtoken=\\%
\let\@EWTECgobbleleadSPtoken=\ %
\def\@EWTECgobbleleadSPMACRO{\ }%
\ifx\@EWTECgobbleleadPARNLSPtoken\@EWTECgobbleleadPARtoken%
\let\@EWTECswallowthistoken=1%
\fi%
\ifx\@EWTECgobbleleadPARNLSPtoken\@EWTECgobbleleadNLtoken%
\let\@EWTECswallowthistoken=1%
\fi%
\ifx\@EWTECgobbleleadPARNLSPtoken\@EWTECgobbleleadSPtoken%
\let\@EWTECswallowthistoken=1%
\fi%
% a control space will come in as a macro
% when it is the last one on a line
\ifx\@EWTECgobbleleadPARNLSPtoken\@EWTECgobbleleadSPMACRO%
\let\@EWTECswallowthistoken=1%
\fi%
% if we have to swallow this token, do so and taste the next one
% else spit it out and stop gobbling
\ifx\@EWTECswallowthistoken 1\let\@EWTECnextgobbleleadPARNLSP=\@EWTECgobbleleadPARNLSP\else%
\let\@EWTECnextgobbleleadPARNLSP=#1\fi%
\@EWTECnextgobbleleadPARNLSP}%




% TITLING OF SECTIONS
\def\@EWTECsectpunct{:\ \,}  % Punctuation after run-in section heading  (headings which are
                            % part of the paragraphs), need little bit more than a single space
                            % spacing from section number to title



\def\@seccntformat#1{\csname the#1dis\endcsname\hskip 0.5em\relax}



%v1.7 put {} after #6 to allow for some types of user font control
%and use \@@par rather than \par
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \ifnum #2>\c@secnumdepth
     \let\@svsec\@empty
  \else
     \refstepcounter{#1}%
     % load section label and spacer into \@svsec
     \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi%
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@% tempskipa determines whether is treated as a high
     \begingroup #6{\relax% or low level heading
      \noindent % subsections are NOT indented
       % print top level headings. \@svsec is label, #8 is heading title
       % The EWTEC does not block indent the section title text, it flows like normal
       {\hskip #3\relax\@svsec}{\interlinepenalty \@M #8\@@par}}%
     \endgroup
     \addcontentsline{toc}{#1}{\ifnum #2>\c@secnumdepth\relax\else
               \protect\numberline{\csname the#1\endcsname}\fi#7}%
  \else % printout low level headings
     % svsechd seems to swallow the trailing space, protect it with \mbox{}
     % got rid of sectionmark stuff
     \def\@svsechd{#6{\hskip #3\relax\@svsec #8\@EWTECsectpunct\mbox{}}%
     \addcontentsline{toc}{#1}{\ifnum #2>\c@secnumdepth\relax\else
               \protect\numberline{\csname the#1\endcsname}\fi#7}}%
  \fi%skip down
  \@xsect{#5}}


% section* handler
%v1.7 put {} after #4 to allow for some types of user font control
%and use \@@par rather than \par
\def\@ssect#1#2#3#4#5{\@tempskipa #3\relax
  \ifdim \@tempskipa>\z@
     %\begingroup #4\@hangfrom{\hskip #1}{\interlinepenalty \@M #5\par}\endgroup
     % The EWTEC does not block indent the section title text, it flows like normal
     \begingroup \noindent #4{\relax{\hskip #1}{\interlinepenalty \@M #5\@@par}}\endgroup
  % svsechd swallows the trailing space, protect it with \mbox{}
  \else \def\@svsechd{#4{\hskip #1\relax #5\@EWTECsectpunct\mbox{}}}\fi
  \@xsect{#3}}


%% SECTION heading spacing and font
%%
% arguments are: #1 - sectiontype name
% (for \@sect)   #2 - section level
%                #3 - section heading indent
%                #4 - top separation (absolute value used, neg indicates not to indent main text)
%                     If negative, make stretch parts negative too!
%                #5 - (absolute value used) positive: bottom separation after heading,
%                      negative: amount to indent main text after heading
%                Both #4 and #5 negative means to indent main text and use negative top separation
%                #6 - font control
% You've got to have \normalfont\normalsize in the font specs below to prevent
% trouble when you do something like:
% \section{Note}{\ttfamily TT-TEXT} is known to ... 
% The EWTEC sometimes REALLY stretches the area before a section
% heading by up to about 0.5in. However, it may not be a good
% idea to let LaTeX have quite this much rubber.

 % for journals
\def\section{\@startsection{section}{1}{\z@}{3.0ex plus 1.5ex minus 1.5ex}% v1.0 3.0ex from 3.5ex
{0.7ex plus 1ex minus 0ex}{\normalfont\normalsize\centering\scshape}}%
\def\subsection{\@startsection{subsection}{2}{\z@}{3.5ex plus 1.5ex minus 1.5ex}%
{0.7ex plus .5ex minus 0ex}{\normalfont\normalsize\itshape}}%


% for both journals and conferences
% decided to put in a little rubber above the section, might help somebody
\def\subsubsection{\@startsection{subsubsection}{3}{\parindent}{0ex plus 0.1ex minus 0.1ex}%
{0ex}{\normalfont\normalsize\itshape}}%
\def\paragraph{\@startsection{paragraph}{4}{2\parindent}{0ex plus 0.1ex minus 0.1ex}%
{0ex}{\normalfont\normalsize\itshape}}%





% v1.0a provide for a raised line Introduction section for use with Computer
% Society papers. We have to remove any spacing glue after the section
% heading and then remove the blank line for the new paragraph after it.
% LaTeX's section handler alters \everypar and we need to propogate those
% changes outside of the \parbox lest there be spacing problems at the top
% of the next section.
\def\EWTECraisesectionheading#1{\noindent\raisebox{1.5\baselineskip}[0pt][0pt]{\parbox[b]{\columnwidth}{#1\unskip\global\everypar=\everypar}}\vspace{-1\baselineskip}\vspace{-\parskip}\par}



%% ENVIRONMENTS
% "box" symbols at end of proofs
\def\EWTECQEDclosed{\mbox{\rule[0pt]{1.3ex}{1.3ex}}} % for a filled box
% v1.0 some journals use an open box instead that will just fit around a closed one
\def\EWTECQEDopen{{\setlength{\fboxsep}{0pt}\setlength{\fboxrule}{0.2pt}\fbox{\rule[0pt]{0pt}{1.3ex}\rule[0pt]{1.3ex}{0pt}}}}

\def\EWTECQED{\EWTECQEDclosed} % default to closed


%v1.0 flag to indicate if QED symbol is to be shown
\newif\if@EWTECQEDshow  \@EWTECQEDshowtrue
\def\EWTECproofindentspace{2\parindent}% v1.0 allow user to change indentation amount if desired
% v1.7 name change to avoid namespace collision with amsthm. Also add support
% for an optional argument.
\def\EWTECproof{\@ifnextchar[{\@EWTECproof}{\@EWTECproof[\EWTECproofname]}}
\def\@EWTECproof[#1]{\@EWTECQEDshowtrue\par\noindent\hspace{\EWTECproofindentspace}{\itshape #1: }}
\def\endEWTECproof{\if@EWTECQEDshow\hspace*{\fill}\nobreakspace\EWTECQED\fi\par}
% qedhere for equation environments, similar to AMS \qedhere
\def\EWTECQEDhereeqn{\global\@EWTECQEDshowfalse\eqno\let\eqno\relax\let\leqno\relax
                    \let\veqno\relax\hbox{\EWTECQED}}
% EWTEC style qedhere for EWTECeqnarray and other environments
\def\EWTECQEDhere{\global\@EWTECQEDshowfalse\EWTECQED}
% command to disable QED at end of EWTECproof
\def\EWTECQEDoff{\global\@EWTECQEDshowfalse}


%\itemindent is set to \z@ by list, so define new temporary variable
\newdimen\@EWTECtmpitemindent



% 
% v1.0 allow long theorem names to break across lines.
% Thanks to Miquel Payaro for reporting this.
\def\@begintheorem#1#2{\@EWTECtmpitemindent\itemindent\relax\topsep 0pt\rmfamily\trivlist%
    \item[]\textit{\indent #1\ #2:} \itemindent\@EWTECtmpitemindent\relax}
\def\@opargbegintheorem#1#2#3{\@EWTECtmpitemindent\itemindent\relax\topsep 0pt\rmfamily \trivlist%
% v1.0 The EWTEC is back to using () around theorem names which are also in italics
% Thanks to Christian Peel for reporting this.
    \item[]\textit{\indent #1\ #2\ (#3):} \itemindent\@EWTECtmpitemindent\relax}
% v1.0 remove bogus \unskip that caused equations in theorems to collide with
% lines below.
\def\@endtheorem{\endtrivlist}




% v1.0
% display command for the section the theorem is in - so that \thesection
% is not used as this will be in Roman numerals when we want arabic.
% LaTeX2e uses \def\@thmcounter#1{\noexpand\arabic{#1}} for the theorem number
% (second part) display and \def\@thmcountersep{.} as a separator.
% v1.0 intercept calls to the section counter and reroute to \@EWTECthmcounterinsection
% to allow \appendix(ices} to override as needed.
%
% special handler for sections, allows appendix(ices) to override
\gdef\@EWTECthmcounterinsection#1{\arabic{#1}}
% string macro
\edef\@EWTECstringsection{section}

% redefine the #1#2[#3] form of newtheorem to use a hook to \@EWTECthmcounterinsection
% if section in_counter is used
\def\@xnthm#1#2[#3]{%
  \expandafter\@ifdefinable\csname #1\endcsname
    {\@definecounter{#1}\@newctr{#1}[#3]%
     \edef\@EWTECstringtmp{#3}
     \ifx\@EWTECstringtmp\@EWTECstringsection
     \expandafter\xdef\csname the#1\endcsname{%
     \noexpand\@EWTECthmcounterinsection{#3}\@thmcountersep
          \@thmcounter{#1}}%
     \else
     \expandafter\xdef\csname the#1\endcsname{%
       \expandafter\noexpand\csname the#3\endcsname \@thmcountersep
          \@thmcounter{#1}}%
     \fi
     \global\@namedef{#1}{\@thm{#1}{#2}}%
     \global\@namedef{end#1}{\@endtheorem}}}



%% SET UP THE DEFAULT PAGESTYLE
\pagestyle{headings}
\pagenumbering{arabic}

% normally the page counter starts at 1
\setcounter{page}{1}
% however, for peerreview the cover sheet is page 0 or page -1
% (for duplex printing)
\ifCLASSOPTIONpeerreview
   \if@twoside
      \setcounter{page}{-1}
   \else
      \setcounter{page}{0}
   \fi
\fi

% standard book class behavior - let bottom line float up and down as
% needed when single sided
\ifCLASSOPTIONtwoside\else\raggedbottom\fi
% if two column - turn on twocolumn, allow word spacings to stretch more and
% enforce a rigid position for the last lines
\ifCLASSOPTIONtwocolumn
% the peer review option delays invoking twocolumn
   \ifCLASSOPTIONpeerreview\else
      \twocolumn
   \fi
\sloppy 
\flushbottom
\fi




% \APPENDIX and \APPENDICES definitions

% This is the \@ifmtarg command from the LaTeX ifmtarg package
% by Peter Wilson (CUA) and Donald Arseneau
% \@ifmtarg is used to determine if an argument to a command
% is present or not.
% For instance:
% \@ifmtarg{#1}{\typeout{empty}}{\typeout{has something}}
% \@ifmtarg is used with our redefined \section command if
% \appendices is invoked.
% The command \section will behave slightly differently depending
% on whether the user specifies a title: 
% \section{My appendix title}
% or not:
% \section{}
% This way, we can eliminate the blank lines where the title
% would be, and the unneeded : after Appendix in the table of
% contents 
\begingroup
\catcode`\Q=3
\long\gdef\@ifmtarg#1{\@xifmtarg#1QQ\@secondoftwo\@firstoftwo\@nil}
\long\gdef\@xifmtarg#1#2Q#3#4#5\@nil{#4}
\endgroup
% end of \@ifmtarg defs


% v1.0
% command that allows the one time saving of the original definition
% of section to \@EWTECappendixsavesection for \appendix or \appendices 
% we don't save \section here as it may be redefined later by other
% packages (hyperref.sty, etc.)
\def\@EWTECsaveoriginalsectiononce{\let\@EWTECappendixsavesection\section
\let\@EWTECsaveoriginalsectiononce\relax}

% neat trick to grab and process the argument from \section{argument}
% we process differently if the user invoked \section{} with no
% argument (title)
% note we reroute the call to the old \section*
\def\@EWTECprocessthesectionargument#1{%
\@ifmtarg{#1}{%
\@EWTECappendixsavesection*{\appendixname\nobreakspace\thesectiondis}%
\addcontentsline{toc}{section}{\appendixname\nobreakspace\thesection}}{%
\@EWTECappendixsavesection*{\appendixname\nobreakspace\thesectiondis\\* #1}%
\addcontentsline{toc}{section}{\appendixname\nobreakspace\thesection: #1}}}

% we use this if the user calls \section{} after
% \appendix-- which has no meaning. So, we ignore the
% command and its argument. Then, warn the user.
\def\@EWTECdestroythesectionargument#1{\typeout{** WARNING: Ignoring useless
\protect\section\space in Appendix (line \the\inputlineno).}}


% remember \thesection forms will be displayed in \ref calls
% and in the Table of Contents.
% The \sectiondis form is used in the actual heading itself

% appendix command for one single appendix
% normally has no heading. However, if you want a 
% heading, you can do so via the optional argument:
% \appendix[Optional Heading]
\def\appendix{\relax}
\renewcommand{\appendix}[1][]{\@EWTECsaveoriginalsectiononce\par
    % v1.6 keep hyperref's identifiers unique
    \gdef\theHsection{Appendix.A}%
    % v1.6 adjust hyperref's string name for the section
    \xdef\Hy@chapapp{appendix}%
    \setcounter{section}{0}%
    \setcounter{subsection}{0}%
    \setcounter{subsubsection}{0}%
    \setcounter{paragraph}{0}%
    \gdef\thesection{A}%
    \gdef\thesectiondis{}% 
    \gdef\thesubsection{\Alph{subsection}}%
    \gdef\@EWTECthmcounterinsection##1{A}
    \refstepcounter{section}% update the \ref counter
    \@ifmtarg{#1}{\@EWTECappendixsavesection*{\appendixname}%
                  \addcontentsline{toc}{section}{\appendixname}}{%
             \@EWTECappendixsavesection*{\appendixname\nobreakspace\\* #1}%
             \addcontentsline{toc}{section}{\appendixname: #1}}%
    % redefine \section command for appendix
    % leave \section* as is
    \def\section{\@ifstar{\@EWTECappendixsavesection*}{%
                    \@EWTECdestroythesectionargument}}% throw out the argument
                                                     % of the normal form
}



% appendices command for multiple appendices
% user then calls \section with an argument (possibly empty) to
% declare the individual appendices
\def\appendices{\@EWTECsaveoriginalsectiononce\par
    % v1.6 keep hyperref's identifiers unique
    \gdef\theHsection{Appendix.\Alph{section}}%
    % v1.6 adjust hyperref's string name for the section
    \xdef\Hy@chapapp{appendix}%
    \setcounter{section}{-1}% we want \refstepcounter to use section 0
    \setcounter{subsection}{0}%
    \setcounter{subsubsection}{0}%
    \setcounter{paragraph}{0}%
    \ifCLASSOPTIONromanappendices%
    \gdef\thesection{\Roman{section}}%
    \gdef\thesectiondis{\Roman{section}}%
    \gdef\@EWTECthmcounterinsection##1{A\arabic{##1}}
    \else%
    \gdef\thesection{\Alph{section}}%
    \gdef\thesectiondis{\Alph{section}}%
    \gdef\@EWTECthmcounterinsection##1{\Alph{##1}}
    \fi%
    \refstepcounter{section}% update the \ref counter
    \setcounter{section}{0}% NEXT \section will be the FIRST appendix
    % redefine \section command for appendices
    % leave \section* as is
    \def\section{\@ifstar{\@EWTECappendixsavesection*}{% process the *-form
                    \refstepcounter{section}% or is a new section so,
                    \@EWTECprocessthesectionargument}}% process the argument 
                                                 % of the normal form
}




%
%
% \EWTECPARstart
% Definition for the big two line drop cap letter at the beginning of the
% first paragraph of conference papers. The first argument is the first letter
% of the first word, the second argument is the remaining letters of the
% first word which will be rendered in upper case.
% In v1.0 this has been completely rewritten to:
% 
% 1. no longer have problems when the user begins an environment
%    within the paragraph that uses \EWTECPARstart.
% 2. auto-detect and use the current font family
% 3. revise handling of the space at the end of the first word so that
%    interword glue will now work as normal.
% 4. produce correctly aligned edges for the (two) indented lines.
% 
% We generalize things via control macros - playing with these is fun too.
% 
% v1.0 added more control macros to make it easy for EWTECtools.sty users
% to change the font style.
% 
% the number of lines that are indented to clear it
% may need to increase if using decenders
\providecommand{\EWTECPARstartDROPLINES}{2}
% minimum number of lines left on a page to allow a \@EWTECPARstart
% Does not take into consideration rubber shrink, so it tends to
% be overly cautious
\providecommand{\EWTECPARstartMINPAGELINES}{2}
% v1.0 the height of the drop cap is adjusted to match the height of this text
% in the current font (when \EWTECPARstart is called).
\providecommand{\EWTECPARstartHEIGHTTEXT}{T}
% the depth the letter is lowered below the baseline
% the height (and size) of the letter is determined by the sum
% of this value and the height of the \EWTECPARstartHEIGHTTEXT in the current
% font. It is a good idea to set this value in terms of the baselineskip
% so that it can respond to changes therein.
\providecommand{\EWTECPARstartDROPDEPTH}{1.1\baselineskip}
% v1.0 the font the drop cap will be rendered in,
% can take zero or one argument.
\providecommand{\EWTECPARstartFONTSTYLE}{\bfseries}
% v1.0 any additional, non-font related commands needed to modify
% the drop cap letter, can take zero or one argument.
\providecommand{\EWTECPARstartCAPSTYLE}{\MakeUppercase}
% v1.0 the font that will be used to render the rest of the word,
% can take zero or one argument.
\providecommand{\EWTECPARstartWORDFONTSTYLE}{\relax}
% v1.0 any additional, non-font related commands needed to modify
% the rest of the word, can take zero or one argument.
\providecommand{\EWTECPARstartWORDCAPSTYLE}{\MakeUppercase}
% This is the horizontal separation distance from the drop letter to the main text.
% Lengths that depend on the font (e.g., ex, em, etc.) will be referenced
% to the font that is active when \EWTECPARstart is called. 
\providecommand{\EWTECPARstartSEP}{0.15em}
% v1.0 horizontal offset applied to the left of the drop cap.
\providecommand{\EWTECPARstartHOFFSET}{0em}
% v1.0 Italic correction command applied at the end of the drop cap.
\providecommand{\EWTECPARstartITLCORRECT}{\/}

% width of the letter output, set globally. Can be used in \EWTECPARstartSEP
% or \EWTECPARstartHOFFSET, but not the height lengths.
\newdimen\EWTECPARstartletwidth
\EWTECPARstartletwidth 0pt\relax

% definition of \EWTECPARstart
% THIS IS A CONTROLLED SPACING AREA, DO NOT ALLOW SPACES WITHIN THESE LINES
% 
% The token \@EWTECPARstartfont will be globally defined after the first use
% of \EWTECPARstart and will be a font command which creates the big letter
% The first argument is the first letter of the first word and the second
% argument is the rest of the first word(s).
\def\EWTECPARstart#1#2{\par{%
% if this page does not have enough space, break it and lets start
% on a new one
\@EWTECneedspace{\EWTECPARstartMINPAGELINES\baselineskip}{\relax}%
% v1.0 move this up here in case user uses \textbf for \EWTECPARstartFONTSTYLE
% which uses command \leavevmode which causes an unwanted \indent to be issued
\noindent
% calculate the desired height of the big letter
% it extends from the top of \EWTECPARstartHEIGHTTEXT in the current font
% down to \EWTECPARstartDROPDEPTH below the current baseline
\settoheight{\@EWTECtmpdimenA}{\EWTECPARstartHEIGHTTEXT}%
\addtolength{\@EWTECtmpdimenA}{\EWTECPARstartDROPDEPTH}%
% extract the name of the current font in bold
% and place it in \@EWTECPARstartFONTNAME
\def\@EWTECPARstartGETFIRSTWORD##1 ##2\relax{##1}%
{\EWTECPARstartFONTSTYLE{\selectfont\edef\@EWTECPARstartFONTNAMESPACE{\fontname\font\space}%
\xdef\@EWTECPARstartFONTNAME{\expandafter\@EWTECPARstartGETFIRSTWORD\@EWTECPARstartFONTNAMESPACE\relax}}}%
% define a font based on this name with a point size equal to the desired
% height of the drop letter
\font\@EWTECPARstartsubfont\@EWTECPARstartFONTNAME\space at \@EWTECtmpdimenA\relax%
% save this value as a counter (integer) value (sp points)
\@EWTECtmpcountA=\@EWTECtmpdimenA%
% now get the height of the actual letter produced by this font size
\settoheight{\@EWTECtmpdimenB}{\@EWTECPARstartsubfont\EWTECPARstartCAPSTYLE{#1}}%
% If something bogus happens like the first argument is empty or the
% current font is sge, do not allow a zero height.
\ifdim\@EWTECtmpdimenB=0pt\relax%
\typeout{** WARNING: EWTECPARstart drop letter has zero height! (line \the\inputlineno)}%
\typeout{ Forcing the drop letter font size to 10pt.}%
\@EWTECtmpdimenB=10pt%
\fi%
% and store it as a counter
\@EWTECtmpcountB=\@EWTECtmpdimenB%
% Since a font size doesn't exactly correspond to the height of the capital
% letters in that font, the actual height of the letter, \@EWTECtmpcountB,
% will be less than that desired, \@EWTECtmpcountA
% we need to raise the font size, \@EWTECtmpdimenA 
% by \@EWTECtmpcountA / \@EWTECtmpcountB
% But, TeX doesn't have floating point division, so we have to use integer
% division. Hence the use of the counters.
% We need to reduce the denominator so that the loss of the remainder will
% have minimal affect on the accuracy of the result
\divide\@EWTECtmpcountB by 200%
\divide\@EWTECtmpcountA by \@EWTECtmpcountB%
% Then reequalize things when we use TeX's ability to multiply by
% floating point values
\@EWTECtmpdimenB=0.005\@EWTECtmpdimenA%
\multiply\@EWTECtmpdimenB by \@EWTECtmpcountA%
% \@EWTECPARstartfont is globaly set to the calculated font of the big letter
% We need to carry this out of the local calculation area to to create the
% big letter.
\global\font\@EWTECPARstartfont\@EWTECPARstartFONTNAME\space at \@EWTECtmpdimenB%
% Now set \@EWTECtmpdimenA to the width of the big letter
% We need to carry this out of the local calculation area to set the
% hanging indent
\settowidth{\global\@EWTECtmpdimenA}{\@EWTECPARstartfont
\EWTECPARstartCAPSTYLE{#1\EWTECPARstartITLCORRECT}}}%
% end of the isolated calculation environment
\global\EWTECPARstartletwidth\@EWTECtmpdimenA\relax%
% add in the extra clearance we want
\advance\@EWTECtmpdimenA by \EWTECPARstartSEP\relax%
% add in the optional offset
\advance\@EWTECtmpdimenA by \EWTECPARstartHOFFSET\relax%
% v1.0 don't allow negative offsets to produce negative hanging indents
\@EWTECtmpdimenB\@EWTECtmpdimenA
\ifnum\@EWTECtmpdimenB < 0 \@EWTECtmpdimenB 0pt\fi
% \@EWTECtmpdimenA has the width of the big letter plus the
% separation space and \@EWTECPARstartfont is the font we need to use
% Now, we make the letter and issue the hanging indent command
% The letter is placed in a box of zero width and height so that other
% text won't be displaced by it.
\hangindent\@EWTECtmpdimenB\hangafter=-\EWTECPARstartDROPLINES%
\makebox[0pt][l]{\hspace{-\@EWTECtmpdimenA}%
\raisebox{-\EWTECPARstartDROPDEPTH}[0pt][0pt]{\hspace{\EWTECPARstartHOFFSET}%
\@EWTECPARstartfont\EWTECPARstartCAPSTYLE{#1\EWTECPARstartITLCORRECT}%
\hspace{\EWTECPARstartSEP}}}%
{\EWTECPARstartWORDFONTSTYLE{\EWTECPARstartWORDCAPSTYLE{\selectfont#2}}}}




% determines if the space remaining on a given page is equal to or greater
% than the specified space of argument one
% if not, execute argument two (only if the remaining space is greater than zero)
% and issue a \newpage
% 
% example: \@EWTECneedspace{2in}{\vfill}
% 
% Does not take into consideration rubber shrinkage, so it tends to
% be overly cautious
% Based on an example posted by Donald Arseneau
% Note this macro uses \@EWTECtmpdimenB internally for calculations,
% so DO NOT PASS \@EWTECtmpdimenB to this routine
% if you need a dimen register, import with \@EWTECtmpdimenA instead
\def\@EWTECneedspace#1#2{\penalty-100\begingroup%shield temp variable
\@EWTECtmpdimenB\pagegoal\advance\@EWTECtmpdimenB-\pagetotal% space left
\ifdim #1>\@EWTECtmpdimenB\relax% not enough space left
\ifdim\@EWTECtmpdimenB>\z@\relax #2\fi%
\newpage%
\fi\endgroup}



% EWTECbiography ENVIRONMENT
% Allows user to enter biography leaving place for picture (adapts to font size)
% As of v1.0, a new optional argument allows you to have a real graphic!
% v1.0 and later also fixes the "colliding biographies" which could happen when a 
% biography's text was shorter than the space for the photo.
% MDS 7/2001
% v1.0 prevent multiple biographies from making multiple TOC entries
\newif\if@EWTECbiographyTOCentrynotmade
\global\@EWTECbiographyTOCentrynotmadetrue

% biography counter so hyperref can jump directly to the biographies
% and not just the previous section
\newcounter{EWTECbiography}
\setcounter{EWTECbiography}{0}

% photo area size
\def\@EWTECBIOphotowidth{1.0in}    % width of the biography photo area
\def\@EWTECBIOphotodepth{1.25in}   % depth (height) of the biography photo area
% area cleared for photo
\def\@EWTECBIOhangwidth{1.14in}    % width cleared for the biography photo area
\def\@EWTECBIOhangdepth{1.25in}    % depth cleared for the biography photo area
                                  % actual depth will be a multiple of 
                                  % \baselineskip, rounded up
\def\@EWTECBIOskipN{4\baselineskip}% nominal value of the vskip above the biography

\newenvironment{EWTECbiography}[2][]{\normalfont\footnotesize%
\unitlength 1in\parskip=0pt\par\parindent 1em\interlinepenalty500%
% we need enough space to support the hanging indent
% the nominal value of the spacer
% and one extra line for good measure
\@EWTECtmpdimenA=\@EWTECBIOhangdepth%
\advance\@EWTECtmpdimenA by \@EWTECBIOskipN%
\advance\@EWTECtmpdimenA by 1\baselineskip%
% if this page does not have enough space, break it and lets start
% with a new one
\@EWTECneedspace{\@EWTECtmpdimenA}{\relax}%
% nominal spacer can strech, not shrink use 1fil so user can out stretch with \vfill
\vskip \@EWTECBIOskipN plus 1fil minus 0\baselineskip%
% the default box for where the photo goes
\def\@EWTECtempbiographybox{{\setlength{\fboxsep}{0pt}\framebox{%
\begin{minipage}[b][\@EWTECBIOphotodepth][c]{\@EWTECBIOphotowidth}\centering PLACE\\ PHOTO\\ HERE \end{minipage}}}}%
%
% detect if the optional argument was supplied, this requires the
% \@ifmtarg command as defined in the appendix section above
% and if so, override the default box with what they want
\@ifmtarg{#1}{\relax}{\def\@EWTECtempbiographybox{\mbox{\begin{minipage}[b][\@EWTECBIOphotodepth][c]{\@EWTECBIOphotowidth}%
\centering%
#1%
\end{minipage}}}}% end if optional argument supplied
% Make an entry into the table of contents only if we have not done so before
\if@EWTECbiographyTOCentrynotmade%
% link labels to the biography counter so hyperref will jump
% to the biography, not the previous section
\setcounter{EWTECbiography}{-1}%
\refstepcounter{EWTECbiography}%
\addcontentsline{toc}{section}{Biographies}%
\global\@EWTECbiographyTOCentrynotmadefalse%
\fi%
% one more biography
\refstepcounter{EWTECbiography}%
% Make an entry for this name into the table of contents 
\addcontentsline{toc}{subsection}{#2}%
% v1.0 properly handle if a new paragraph should occur while the
% hanging indent is still active. Do this by redefining \par so
% that it will not start a new paragraph. (But it will appear to the
% user as if it did.) Also, strip any leading pars, newlines, or spaces.
\let\@EWTECBIOORGparCMD=\par% save the original \par command
\edef\par{\hfil\break\indent}% the new \par will not be a "real" \par
\settoheight{\@EWTECtmpdimenA}{\@EWTECtempbiographybox}% get height of biography box
\@EWTECtmpdimenB=\@EWTECBIOhangdepth%
\@EWTECtmpcountA=\@EWTECtmpdimenB% countA has the hang depth
\divide\@EWTECtmpcountA by \baselineskip%  calculates lines needed to produce the hang depth
\advance\@EWTECtmpcountA by 1% ensure we overestimate
% set the hanging indent
\hangindent\@EWTECBIOhangwidth%
\hangafter-\@EWTECtmpcountA%
% reference the top of the photo area to the top of a capital T
\settoheight{\@EWTECtmpdimenB}{\mbox{T}}%
% set the photo box, give it zero width and height so as not to disturb anything
\noindent\makebox[0pt][l]{\hspace{-\@EWTECBIOhangwidth}\raisebox{\@EWTECtmpdimenB}[0pt][0pt]{%
\raisebox{-\@EWTECBIOphotodepth}[0pt][0pt]{\@EWTECtempbiographybox}}}%
% now place the author name and begin the bio text
\noindent\textbf{#2\ }\@EWTECgobbleleadPARNLSP}{\relax\let\par=\@EWTECBIOORGparCMD\par%
% 7/2001 v1.0 detect when the biography text is shorter than the photo area
% and pad the unused area - preventing a collision from the next biography entry
% MDS
\ifnum \prevgraf <\@EWTECtmpcountA\relax% detect when the biography text is shorter than the photo
    \advance\@EWTECtmpcountA by -\prevgraf% calculate how many lines we need to pad
    \advance\@EWTECtmpcountA by -1\relax% we compensate for the fact that we indented an extra line
    \@EWTECtmpdimenA=\baselineskip% calculate the length of the padding
    \multiply\@EWTECtmpdimenA by \@EWTECtmpcountA%
    \noindent\rule{0pt}{\@EWTECtmpdimenA}% insert an invisible support strut
\fi%
\par\normalfont}



% v1.0
% added biography without a photo environment
\newenvironment{EWTECbiographynophoto}[1]{%
% Make an entry into the table of contents only if we have not done so before
\if@EWTECbiographyTOCentrynotmade%
% link labels to the biography counter so hyperref will jump
% to the biography, not the previous section
\setcounter{EWTECbiography}{-1}%
\refstepcounter{EWTECbiography}%
\addcontentsline{toc}{section}{Biographies}%
\global\@EWTECbiographyTOCentrynotmadefalse%
\fi%
% one more biography
\refstepcounter{EWTECbiography}%
% Make an entry for this name into the table of contents 
\addcontentsline{toc}{subsection}{#1}%
\normalfont\footnotesize\interlinepenalty500%
\vskip 4\baselineskip plus 1fil minus 0\baselineskip%
\parskip=0pt\par%
\noindent\textbf{#1\ }\@EWTECgobbleleadPARNLSP}{\relax\par\normalfont}


% provide the user with some old font commands
% got this from article.cls
\DeclareOldFontCommand{\rm}{\normalfont\rmfamily}{\mathrm}
\DeclareOldFontCommand{\sf}{\normalfont\sffamily}{\mathsf}
\DeclareOldFontCommand{\tt}{\normalfont\ttfamily}{\mathtt}
\DeclareOldFontCommand{\bf}{\normalfont\bfseries}{\mathbf}
\DeclareOldFontCommand{\it}{\normalfont\itshape}{\mathit}
\DeclareOldFontCommand{\sl}{\normalfont\slshape}{\@nomath\sl}
\DeclareOldFontCommand{\sc}{\normalfont\scshape}{\@nomath\sc}
\DeclareRobustCommand*\cal{\@fontswitch\relax\mathcal}
\DeclareRobustCommand*\mit{\@fontswitch\relax\mathnormal}


% SPECIAL PAPER NOTICE COMMANDS
% 
% holds the special notice text
\def\@EWTECspecialpapernotice{\relax}
 
% for special papers, like invited papers, the user can do:
% \EWTECspecialpapernotice{(Invited Paper)} before \maketitle
\def\EWTECspecialpapernotice#1{
\def\@EWTECspecialpapernotice{{\\*[1.5ex]\sublargesize\textit{#1}}\vspace*{-2ex}}%
}




% PUBLISHER ID COMMANDS
% to insert a publisher's ID footer
% v1.0 \EWTECpubid has been changed so that the change in page size and style
% occurs in \maketitle. \EWTECpubid must now be issued prior to \maketitle
% use \EWTECpubidadjcol as before - in the second column of the title page
% These changes allow \maketitle to take the reduced page height into
% consideration when dynamically setting the space between the author 
% names and the maintext.
%
% the amount the main text is pulled up to make room for the
% publisher's ID footer
% The EWTEC uses about 1.3\baselineskip for proceedings, 
% dynamic title spacing will clean up the fraction
\def\@EWTECpubidpullup{1.3\baselineskip}




% holds the ID text
\def\@EWTECpubid{\relax}

% flag so \maketitle can tell if \EWTECpubid was called
\newif\if@EWTECusingpubid
\global\@EWTECusingpubidfalse
% issue this command in the page to have the ID at the bottom
% v1.0 use before \maketitle
\def\EWTECpubid#1{\def\@EWTECpubid{#1}\global\@EWTECusingpubidtrue}


% command which will pull up (shorten) the column it is executed in
% to make room for the publisher ID. Place in the second column of
% the title page when using \EWTECpubid
% Is smart enough not to do anything when in single column text or
% if the user hasn't called \EWTECpubid
% currently needed in for the second column of a page with the
% publisher ID. If not needed in future releases, please provide this
% command and define it as \relax for backward compatibility
% v1.6b do not allow command to operate if the peer review option has been 
% selected because \EWTECpubidadjcol will not be on the cover page.
% v1.0 do nothing if compsoc
\def\EWTECpubidadjcol{\ifCLASSOPTIONpeerreview\else
\if@twocolumn\if@EWTECusingpubid\enlargethispage{-\@EWTECpubidpullup}\fi\fi\fi}

% Special thanks to Peter Wilson, Daniel Luecking, and the other
% gurus at comp.text.tex, for helping me to understand how best to
% implement the EWTECpubid command in LaTeX.



%% Lockout some commands under various conditions

% general purpose bit bucket
\newsavebox{\@EWTECrubishbin}

% flags to prevent multiple warning messages
\newif\if@EWTECWARNthanks
\newif\if@EWTECWARNEWTECPARstart
\newif\if@EWTECWARNEWTECbiography
\newif\if@EWTECWARNEWTECbiographynophoto
\newif\if@EWTECWARNEWTECpubid
\newif\if@EWTECWARNEWTECpubidadjcol
\newif\if@EWTECWARNEWTECmembership
\newif\if@EWTECWARNEWTECaftertitletext
\@EWTECWARNthankstrue
\@EWTECWARNEWTECPARstarttrue
\@EWTECWARNEWTECbiographytrue
\@EWTECWARNEWTECbiographynophototrue
\@EWTECWARNEWTECpubidtrue
\@EWTECWARNEWTECpubidadjcoltrue
\@EWTECWARNEWTECmembershiptrue
\@EWTECWARNEWTECaftertitletexttrue


%% Lockout some commands when in various modes, but allow them to be restored if needed
%%
% save commands which might be locked out
% so that the user can later restore them if needed
\let\@EWTECSAVECMDthanks\thanks
\let\@EWTECSAVECMDEWTECPARstart\EWTECPARstart
\let\@EWTECSAVECMDEWTECbiography\EWTECbiography
\let\@EWTECSAVECMDendEWTECbiography\endEWTECbiography
\let\@EWTECSAVECMDEWTECbiographynophoto\EWTECbiographynophoto
\let\@EWTECSAVECMDendEWTECbiographynophoto\endEWTECbiographynophoto
\let\@EWTECSAVECMDEWTECpubid\EWTECpubid
\let\@EWTECSAVECMDEWTECpubidadjcol\EWTECpubidadjcol
\let\@EWTECSAVECMDEWTECmembership\EWTECmembership
\let\@EWTECSAVECMDEWTECaftertitletext\EWTECaftertitletext


% disable \EWTECPARstart when in draft mode
% This may have originally been done because the pre-v1.0 drop letter
% algorithm had problems with a non-unity baselinestretch
% At any rate, it seems too formal to have a drop letter in a draft
% paper.
\ifCLASSOPTIONdraftcls
\def\EWTECPARstart#1#2{#1#2\if@EWTECWARNEWTECPARstart\typeout{** ATTENTION: \noexpand\EWTECPARstart
 is disabled in draft mode (line \the\inputlineno).}\fi\global\@EWTECWARNEWTECPARstartfalse}
\fi


% provide a way to restore the commands that are locked out
\def\EWTECoverridecommandlockouts{%
\typeout{** ATTENTION: Overriding command lockouts (line \the\inputlineno).}%
\let\thanks\@EWTECSAVECMDthanks%
\let\EWTECPARstart\@EWTECSAVECMDEWTECPARstart%
\let\EWTECbiography\@EWTECSAVECMDEWTECbiography%
\let\endEWTECbiography\@EWTECSAVECMDendEWTECbiography%
\let\EWTECbiographynophoto\@EWTECSAVECMDEWTECbiographynophoto%
\let\endEWTECbiographynophoto\@EWTECSAVECMDendEWTECbiographynophoto%
\let\EWTECpubid\@EWTECSAVECMDEWTECpubid%
\let\EWTECpubidadjcol\@EWTECSAVECMDEWTECpubidadjcol%
\let\EWTECmembership\@EWTECSAVECMDEWTECmembership%
\let\EWTECaftertitletext\@EWTECSAVECMDEWTECaftertitletext}



% need a backslash character for typeout output
{\catcode`\|=0 \catcode`\\=12
|xdef|@EWTECbackslash{\}}


% hook to allow easy disabling of all legacy warnings
\def\@EWTEClegacywarn#1#2{\typeout{** ATTENTION: \@EWTECbackslash #1 is deprecated (line \the\inputlineno).
Use \@EWTECbackslash #2 instead.}}


% provide some legacy IEEEtran commands
\def\EWTECcompsoctitleabstractindextext{\@EWTEClegacywarn{EWTECcompsoctitleabstractindextext}{EWTECtitleabstractindextext}\EWTECtitleabstractindextext}
\def\EWTECdisplaynotcompsoctitleabstractindextext{\@EWTEClegacywarn{EWTECdisplaynotcompsoctitleabstractindextext}{EWTECdisplaynontitleabstractindextext}\EWTECdisplaynontitleabstractindextext}





\endinput

%%%%%%%%%%%%%%%%%%%%%%%%%%%%% End of EWTEC.cls  %%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Q. Why do Norwegian ships have barcodes?
% A. So they can scan `da' navy in 

